@@ -3,7 +3,7 @@
 usage()
 {
 	# Title
-	echo "Title: FFMPEG Single Pass DVD-Video"
+	echo "Title: DVD-Video Single Pass (FFMPEG)"
 
 	# Usable?
 	which ffmpeg > /dev/null
