@@ -3,12 +3,12 @@
 usage()
 {
 	# Title
-	echo "Title: FFMPEG MP3 Export"
+	echo "Title: MP3 (FFMPEG)"
 
 	# Usable?
 	which ffmpeg > /dev/null
 	mp3=0
-	[ $? -eq 0 ] && mp3=`ffmpeg -formats | egrep "(Encoders:)|(.*E.*mp3)" | grep mp3 | wc -l`
+	[ $? -eq 0 ] && mp3=`ffmpeg -formats 2> /dev/null | egrep "(Encoders:)|(.*E.*mp3)" | grep mp3 | wc -l`
 	[ "$mp3" -gt 0 ] && echo Status: Active || echo Status: Inactive
 
 	# Type
