@@ -3,7 +3,7 @@
 usage()
 {
 	# Title
-	echo "Title: FFMPEG VCD Export"
+	echo "Title: VCD (FFMPEG)"
 
 	# Usable?
 	which ffmpeg > /dev/null
