@@ -5,7 +5,7 @@
 usage()
 {
 	# Title
-	echo "Title: DivX using MEncoder"
+	echo "Title: MPEG-4 AVI (MEncoder)"
 
 	# Usable?
 	command -v mencoder 1> /dev/null 2>&1
@@ -15,9 +15,9 @@ usage()
 	echo Flags: single-pass file-producer
 
 	# Profiles
-	echo "Profile: 384x288 DivX 4/5 700bps, mp3 128bps"
-	echo "Profile: 640x480 DivX 4/5 2000bps, mp3 128bps"
-	echo "Profile: 640x480 DivX 4/5 7000bps, mp3 224bps"
+	echo "Profile: 384x288 700bps, mp3 128bps"
+	echo "Profile: 640x480 2000bps, mp3 128bps"
+	echo "Profile: 640x480 7000bps, mp3 224bps"
 }
 
 execute()
