@@ -22,7 +22,7 @@
 #endif
 
 // Project Includes
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include "audio_filters.h"
 #include "page_magick.h"
 
