@@ -142,7 +142,7 @@ private:
 	KinoAudioInput *wav;
 	GtkLabel *label_info;
 	GtkEntry *file_entry;
-	AudioResample *resampler;
+	AudioResample<int16_le_t,int16_ne_t> *resampler;
 	int fps;
 	int16_t temp[ 4 * DV_AUDIO_MAX_SAMPLES * 2 ];
 	bool wav_selected;
@@ -151,7 +151,7 @@ public:
 	WavSelect() : wav( NULL ), label_info( NULL ), file_entry( NULL ), wav_selected( false )
 	{
 		strcpy( wav_file, "" );
-		resampler = AudioResampleFactory::createAudioResample(
+		resampler = AudioResampleFactory<int16_le_t,int16_ne_t>::createAudioResample(
 		                AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY );
 	}
 
@@ -228,7 +228,7 @@ public:
 				printf( ">>> Underrun? unable to read %d bytes\n", bytes );
 			}
 
-			resampler->Resample( temp, wav->GetFrequency(), c, samples );
+			resampler->Resample( reinterpret_cast<int16_le_t *>(temp), wav->GetFrequency(), c, samples );
 
 			int16_t *p = resampler->output;
 			for ( int s = 0; s < resampler->size / c / 2; s ++ )
@@ -274,7 +274,7 @@ public:
 	{
 		window = glade_xml_get_widget( magick_glade, "window_dub" );
 		SetWavInfoLabel( GTK_LABEL( lookup_widget( window, "label_dub_info" ) ) );
-		SetWavFileEntry( GTK_ENTRY( lookup_widget( window, "entry_dub" ) ) );
+		SetWavFileEntry( GTK_ENTRY( lookup_widget( window, "entry_dub_file" ) ) );
 		WavFileSelected();
 	}
 
@@ -286,6 +286,11 @@ public:
 		return _( "Dub" );
 	}
 
+	bool IsBFrameConsumer() const
+	{
+		return false;
+	}
+
 	void GetFrame( int16_t **aframe, int16_t **bframe, int frequency, int channels, int& samples, double position, double frame_delta )
 	{
 		if ( position == 0 )
@@ -300,9 +305,22 @@ public:
 			WavRead( aframe, frequency, channels, samples * channels * 2 );
 	}
 
+	static void
+	on_button_sub_file_clicked( GtkButton *button, gpointer user_data)
+	{
+		char *filename = common->getFileToOpen( _("Choose an audio file"), false );
+		if ( filename && strcmp( filename, "" ) )
+		{
+			AudioDub *me = static_cast< AudioDub* >( user_data );
+			gtk_entry_set_text( me->getEntry(), filename );
+		}
+	}
+
 	void AttachWidgets( GtkBin *bin )
 	{
 		gtk_widget_reparent( ( GTK_BIN( window ) ) ->child, GTK_WIDGET( bin ) );
+		g_signal_connect( G_OBJECT( lookup_widget( window, "button_dub_file" ) ),
+			"clicked", G_CALLBACK( on_button_sub_file_clicked ), this );
 	}
 
 	void DetachWidgets( GtkBin *bin )
@@ -321,6 +339,10 @@ public:
 		initiated = false;
 	}
 
+	GtkEntry *getEntry() const
+	{
+		return GTK_ENTRY( lookup_widget( window, "entry_dub_file" ) );
+	}
 };
 
 /** Mix the audio with a wav file. This is a proper 'audio transition' in that it takes care of the switch
@@ -345,7 +367,7 @@ public:
 	{
 		window = glade_xml_get_widget( magick_glade, "window_mix" );
 		SetWavInfoLabel( GTK_LABEL( lookup_widget( window, "label_mix_info" ) ) );
-		SetWavFileEntry( GTK_ENTRY( lookup_widget( window, "entry_mix" ) ) );
+		SetWavFileEntry( GTK_ENTRY( lookup_widget( window, "entry_mix_file" ) ) );
 		WavFileSelected();
 	}
 
@@ -357,6 +379,11 @@ public:
 		return _( "Mix" );
 	}
 
+	bool IsBFrameConsumer() const
+	{
+		return false;
+	}
+
 	void Mix( int16_t **io, int16_t **with, int channels, int samples )
 	{
 		for ( int s = 0; s < samples; s ++ )
@@ -380,9 +407,22 @@ public:
 		}
 	}
 
+	static void
+	on_button_mix_file_clicked( GtkButton *button, gpointer user_data)
+	{
+		char *filename = common->getFileToOpen( _("Choose an audio file"), false );
+		if ( filename && strcmp( filename, "" ) )
+		{
+			AudioMix *me = static_cast< AudioMix* >( user_data );
+			gtk_entry_set_text( me->getEntry(), filename );
+		}
+	}
+	
 	void AttachWidgets( GtkBin *bin )
 	{
 		gtk_widget_reparent( ( GTK_BIN( window ) ) ->child, GTK_WIDGET( bin ) );
+		g_signal_connect( G_OBJECT( lookup_widget( window, "button_mix_file" ) ),
+			"clicked", G_CALLBACK( on_button_mix_file_clicked ), this );
 	}
 
 	void DetachWidgets( GtkBin *bin )
@@ -404,6 +444,11 @@ public:
 
 		initiated = false;
 	}
+
+	GtkEntry *getEntry() const
+	{
+		return GTK_ENTRY( lookup_widget( window, "entry_mix_file" ) );
+	}
 };
 
 /** Callback for selection change.
