@@ -15,111 +15,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*
-* Tag: $Name:  $
-*
-* Change log:
-* 
-* $Log: avi.cc,v $
-* Revision 1.27  2004/10/11 01:37:11  ddennedy
-* mutex safety locks in RIFF and AVI classes, type 2 AVI optimization, mencoder export script
-*
-* Revision 1.26  2004/01/05 03:43:11  ddennedy
-* metadata editing, deinterlace options, bugfixes and cleanups
-*
-* Revision 1.25  2003/11/25 23:00:52  ddennedy
-* cleanup and a few bugfixes
-*
-* Revision 1.24  2003/11/12 13:01:56  ddennedy
-* disable JUNK chunks in MOVI list, FileHandler max file size zero = infinity
-*
-* Revision 1.23  2003/11/10 01:02:51  ddennedy
-* bugfix: return error on AVI directory entries with size <0
-*
-* Revision 1.22  2003/10/28 18:52:32  ddennedy
-* fix prefs dialog crash, improve WAV import
-*
-* Revision 1.21  2003/10/21 16:34:32  ddennedy
-* GNOME2 port phase 1: initial checkin
-*
-* Revision 1.19.2.9  2003/08/26 20:39:00  ddennedy
-* relocate mutex unlock and add assert includes
-*
-* Revision 1.19.2.8  2003/07/24 14:13:57  ddennedy
-* support for distinct audio stream in type2 AVI and Quicktime; support for more DV FOURCCs
-*
-* Revision 1.19.2.7  2003/06/10 23:53:35  ddennedy
-* Daniel Kobras' WriteFrame error handling and automatic OpenDML, bugfixes in scene list updates, export AV/C Record
-*
-* Revision 1.19.2.6  2003/03/05 15:02:12  ddennedy
-* yet anther AV/C bugfix, yet another AVI improvement
-*
-* Revision 1.19.2.5  2003/02/20 21:59:55  ddennedy
-* bugfixes to capture and AVI
-*
-* Revision 1.19.2.4  2003/01/13 05:15:31  ddennedy
-* added More Info panel and supporting methods
-*
-* Revision 1.19.2.3  2002/12/31 22:40:49  ddennedy
-* bugfix recent versions Quicktime4Linux build options, extend dvsd fourcc check on AVI to the BITMAPINFOHEADER for compatibility with mencoder
-*
-* Revision 1.19.2.2  2002/11/25 04:48:30  ddennedy
-* bugfix to report errors when loading files
-*
-* Revision 1.19.2.1  2002/11/24 23:36:55  ddennedy
-* bugfix in AVI writing
-*
-* Revision 1.19  2002/10/08 12:08:01  ddennedy
-* more sane frame count, greater potential compatibility
-*
-* Revision 1.18  2002/10/08 08:33:02  ddennedy
-* fix number of frames for small dv2
-*
-* Revision 1.17  2002/10/08 07:46:41  ddennedy
-* AVI bugfixes, compatibility, optimization, warn bad file in capture and export dv file, allow no mplex
-*
-* Revision 1.15  2002/06/10 10:39:51  ddennedy
-* minor fixes for large files
-*
-* Revision 1.14  2002/05/17 08:04:24  ddennedy
-* revert const-ness of Frame references in Frame, FileHandler, and AVI classes
-*
-* Revision 1.13  2002/05/15 04:39:35  ddennedy
-* bugfixes to dv2 AVI write, audio export, Xv init
-*
-* Revision 1.12  2002/04/29 05:09:21  ddennedy
-* raw dv file support, Frame::ExtractAudio uses libdv, audioScrub prefs
-*
-* Revision 1.11  2002/04/15 19:12:32  schirmacher
-* removed debugging code causing performance losses and crashes with dv2 files
-*
-* Revision 1.10  2002/04/09 06:53:42  ddennedy
-* cleanup, new libdv 0.9.5, large AVI, dnd storyboard
-*
-* Revision 1.8  2002/03/25 21:34:25  arne
-* Support for large (64 bit) files mostly completed
-*
-* Revision 1.7  2002/03/10 21:28:29  arne
-* release 1.1b1, 64 bit support for type 1 avis
-*
-* Revision 1.6  2002/03/10 13:29:41  arne
-* more changes for 64 bit access
-*
-* Revision 1.5  2002/03/09 17:59:28  arne
-* moved index routines to AVIFile
-*
-* Revision 1.4  2002/03/09 10:26:26  arne
-* improved constructors and assignment operator
-*
-* Revision 1.3  2002/03/09 08:55:57  arne
-* moved a few variables to AVIFile
-*
-* Revision 1.2  2002/03/04 19:22:43  arne
-* updated to latest Kino avi code
-*
-* Revision 1.1.1.1  2002/03/03 19:08:08  arne
-* import of version 1.01
-*
 */
 
 #ifdef HAVE_CONFIG_H
@@ -154,7 +49,8 @@ using std::endl;
 
 #define PADDING_SIZE (512)
 #define PADDING_1GB (0x40000000)
-#define IX00_INDEX_SIZE (4028)
+#define IX00_INDEX_SIZE (17895)
+#define IDX1_INDEX_SIZE (20000)
 
 #define AVIF_HASINDEX 0x00000010
 #define AVIF_MUSTUSEINDEX 0x00000020
@@ -292,8 +188,6 @@ AVIFile& AVIFile::operator=( const AVIFile& avi )
 
 AVIFile::~AVIFile()
 {
-	// cerr << "0x" << hex << (long)this << dec << " AVIFile::~AVIFile()" << endl;
-
 	for ( int i = 0; i < 2; ++i )
 	{
 		delete ix[ i ];
@@ -372,7 +266,7 @@ void AVIFile::Init( int format, int sampleFrequency, int indexType )
 	{
 		indx[ i ] ->wLongsPerEntry = 4;
 		indx[ i ] ->bIndexSubType = 0;
-		indx[ i ] ->bIndexType = AVI_INDEX_OF_INDEXES;
+		indx[ i ] ->bIndexType = KINO_AVI_INDEX_OF_INDEXES;
 		indx[ i ] ->nEntriesInUse = 0;
 		indx[ i ] ->dwReserved[ 0 ] = 0;
 		indx[ i ] ->dwReserved[ 1 ] = 0;
@@ -427,12 +321,14 @@ int AVIFile::GetDVFrameInfo( off_t &offset, int &size, int frameNum )
 		if ( i != current_ix00 )
 		{
 			fail_if( lseek( fd, indx[ 0 ] ->aIndex[ i ].qwOffset + RIFF_HEADERSIZE, SEEK_SET ) == ( off_t ) - 1 );
+			fail_if( ( unsigned int )( indx[ 0 ] ->aIndex[ i ].dwSize - RIFF_HEADERSIZE ) > sizeof( AVIStdIndex ) );
 			fail_neg( read( fd, ix[ 0 ], indx[ 0 ] ->aIndex[ i ].dwSize - RIFF_HEADERSIZE ) );
 			current_ix00 = i;
 		}
 
 		if ( frameNum < ix[ 0 ] ->nEntriesInUse )
 		{
+			fail_if( frameNum > IX00_INDEX_SIZE );
 			offset = ix[ 0 ] ->qwBaseOffset + ix[ 0 ] ->aIndex[ frameNum ].dwOffset;
 			size = ix[ 0 ] ->aIndex[ frameNum ].dwSize;
 			return 0;
@@ -654,16 +550,16 @@ void AVIFile::PrintDirectoryEntryData( const RIFFDirEntry &entry ) const
 		lastStreamType = avi_stream_header.fccType;
 
 		cout << "    fccType:         '"
-		<< ( char ) ( ( avi_stream_header.fccType >> 0 ) & 0x000000ff )
-		<< ( char ) ( ( avi_stream_header.fccType >> 8 ) & 0x000000ff )
-		<< ( char ) ( ( avi_stream_header.fccType >> 16 ) & 0x000000ff )
-		<< ( char ) ( ( avi_stream_header.fccType >> 24 ) & 0x000000ff )
+		<< ((char *)&avi_stream_header.fccType)[0]
+		<< ((char *)&avi_stream_header.fccType)[1]
+		<< ((char *)&avi_stream_header.fccType)[2]
+		<< ((char *)&avi_stream_header.fccType)[3]
 		<< '\'' << endl
 		<< "    fccHandler:      '"
-		<< ( char ) ( ( avi_stream_header.fccHandler >> 0 ) & 0x000000ff )
-		<< ( char ) ( ( avi_stream_header.fccHandler >> 8 ) & 0x000000ff )
-		<< ( char ) ( ( avi_stream_header.fccHandler >> 16 ) & 0x000000ff )
-		<< ( char ) ( ( avi_stream_header.fccHandler >> 24 ) & 0x000000ff )
+		<< ((char *)&avi_stream_header.fccHandler)[0]
+		<< ((char *)&avi_stream_header.fccHandler)[1]
+		<< ((char *)&avi_stream_header.fccHandler)[2]
+		<< ((char *)&avi_stream_header.fccHandler)[3]
 		<< '\'' << endl
 		<< "    dwFlags:         " << ( int ) avi_stream_header.dwFlags << endl
 		<< "    wPriority:       " << ( int ) avi_stream_header.wPriority << endl
@@ -691,10 +587,10 @@ void AVIFile::PrintDirectoryEntryData( const RIFFDirEntry &entry ) const
 		<< "    bIndexType:     " << ( int ) avi_super_index.bIndexType << endl
 		<< "    nEntriesInUse:  " << ( int ) avi_super_index.nEntriesInUse << endl
 		<< "    dwChunkId:      '"
-		<< ( char ) ( ( avi_super_index.dwChunkId >> 0 ) & 0x000000ff )
-		<< ( char ) ( ( avi_super_index.dwChunkId >> 8 ) & 0x000000ff )
-		<< ( char ) ( ( avi_super_index.dwChunkId >> 16 ) & 0x000000ff )
-		<< ( char ) ( ( avi_super_index.dwChunkId >> 24 ) & 0x000000ff )
+		<< ((char *)&avi_super_index.dwChunkId)[0]
+		<< ((char *)&avi_super_index.dwChunkId)[1]
+		<< ((char *)&avi_super_index.dwChunkId)[2]
+		<< ((char *)&avi_super_index.dwChunkId)[3]
 		<< '\'' << endl
 		<< "    dwReserved[0]:  " << ( int ) avi_super_index.dwReserved[ 0 ] << endl
 		<< "    dwReserved[1]:  " << ( int ) avi_super_index.dwReserved[ 1 ] << endl
@@ -771,10 +667,10 @@ void AVIFile::PrintDirectoryEntryData( const RIFFDirEntry &entry ) const
 		<< "    bIndexType:     " << ( int ) avi_std_index.bIndexType << endl
 		<< "    nEntriesInUse:  " << ( int ) avi_std_index.nEntriesInUse << endl
 		<< "    dwChunkId:      '"
-		<< ( char ) ( ( avi_std_index.dwChunkId >> 0 ) & 0x000000ff )
-		<< ( char ) ( ( avi_std_index.dwChunkId >> 8 ) & 0x000000ff )
-		<< ( char ) ( ( avi_std_index.dwChunkId >> 16 ) & 0x000000ff )
-		<< ( char ) ( ( avi_std_index.dwChunkId >> 24 ) & 0x000000ff )
+		<< ((char *)&avi_std_index.dwChunkId)[0]
+		<< ((char *)&avi_std_index.dwChunkId)[1]
+		<< ((char *)&avi_std_index.dwChunkId)[2]
+		<< ((char *)&avi_std_index.dwChunkId)[3]
 		<< '\'' << endl
 		<< "    qwBaseOffset:   0x" << setw( 12 ) << hex << avi_std_index.qwBaseOffset << endl
 		<< "    dwReserved:     " << dec << ( int ) avi_std_index.dwReserved << endl;
@@ -792,7 +688,7 @@ void AVIFile::PrintDirectoryEntryData( const RIFFDirEntry &entry ) const
 
 		int i;
 		int numEntries = entry.length / sizeof( int ) / 4;
-		int *idx1 = new int[ numEntries * 4 ];
+		DWORD *idx1 = new DWORD[ numEntries * 4 ];
 		// FOURCC movi_list = FindDirectoryEntry(make_fourcc("movi"));
 
 		fail_if( lseek( fd, entry.offset, SEEK_SET ) == ( off_t ) - 1 );
@@ -802,10 +698,10 @@ void AVIFile::PrintDirectoryEntryData( const RIFFDirEntry &entry ) const
 		{
 
 			cout << ' ' << setw( 4 ) << setfill( ' ' ) << i << setfill( '0' ) << ": dwChunkId : '"
-			<< ( char ) ( ( idx1[ i * 4 + 0 ] >> 0 ) & 0x000000ff )
-			<< ( char ) ( ( idx1[ i * 4 + 0 ] >> 8 ) & 0x000000ff )
-			<< ( char ) ( ( idx1[ i * 4 + 0 ] >> 16 ) & 0x000000ff )
-			<< ( char ) ( ( idx1[ i * 4 + 0 ] >> 24 ) & 0x000000ff )
+			<< ((char *)&idx1[ i * 4 + 0 ])[0]
+			<< ((char *)&idx1[ i * 4 + 0 ])[1]
+			<< ((char *)&idx1[ i * 4 + 0 ])[2]
+			<< ((char *)&idx1[ i * 4 + 0 ])[3]
 			<< '\'' << endl
 			<< "       dwType    : 0x" << setw( 8 ) << hex << idx1[ i * 4 + 1 ] << endl
 			<< "       dwOffset  : 0x" << setw( 8 ) << idx1[ i * 4 + 2 ] << endl
@@ -819,7 +715,7 @@ void AVIFile::PrintDirectoryEntryData( const RIFFDirEntry &entry ) const
 	{
 		int i;
 		int numEntries = entry.length / sizeof( int );
-		int *dmlh = new int[ numEntries ];
+		DWORD *dmlh = new DWORD[ numEntries ];
 
 		fail_if( lseek( fd, entry.offset, SEEK_SET ) == ( off_t ) - 1 );
 		fail_neg( read( fd, dmlh, entry.length ) );
@@ -843,7 +739,7 @@ void AVIFile::ParseList( int parent )
 {
 	FOURCC type;
 	FOURCC name;
-	int length;
+	DWORD length;
 	int list;
 	off_t pos;
 	off_t listEnd;
@@ -900,7 +796,7 @@ void AVIFile::ParseRIFF()
 
 	avih_chunk = FindDirectoryEntry( make_fourcc( "avih" ) );
 	if ( avih_chunk != -1 )
-		ReadChunk( avih_chunk, ( void* ) & mainHdr );
+		ReadChunk( avih_chunk, ( void* ) & mainHdr, sizeof( MainAVIHeader ) );
 }
 
 
@@ -909,21 +805,20 @@ void AVIFile::ReadIndex()
 	indx_chunk[ 0 ] = FindDirectoryEntry( make_fourcc( "indx" ) );
 	if ( indx_chunk[ 0 ] != -1 )
 	{
-		ReadChunk( indx_chunk[ 0 ], ( void* ) indx[ 0 ] );
+		ReadChunk( indx_chunk[ 0 ], ( void* ) indx[ 0 ], sizeof( AVISuperIndex ) );
 		index_type = AVI_LARGE_INDEX;
 
 		/* recalc number of frames from each index */
 		mainHdr.dwTotalFrames = 0;
 		for ( int i = 0;
 		        i < indx[ 0 ] ->nEntriesInUse;
-		        mainHdr.dwTotalFrames += indx[ 0 ] ->aIndex[ i++ ].dwDuration )
-			;
-		return ;
+		        mainHdr.dwTotalFrames += indx[ 0 ] ->aIndex[ i++ ].dwDuration );
+		return;
 	}
 	idx1_chunk = FindDirectoryEntry( make_fourcc( "idx1" ) );
 	if ( idx1_chunk != -1 )
 	{
-		ReadChunk( idx1_chunk, ( void* ) idx1 );
+		ReadChunk( idx1_chunk, ( void* ) idx1, sizeof( AVISimpleIndex ) );
 		idx1->nEntriesInUse = GetDirectoryEntry( idx1_chunk ).length / 16;
 		index_type = AVI_SMALL_INDEX;
 
@@ -979,7 +874,7 @@ void AVIFile::FlushIndx( int stream )
 
 	ix[ stream ] ->wLongsPerEntry = 2;
 	ix[ stream ] ->bIndexSubType = 0;
-	ix[ stream ] ->bIndexType = AVI_INDEX_OF_CHUNKS;
+	ix[ stream ] ->bIndexType = KINO_AVI_INDEX_OF_CHUNKS;
 	ix[ stream ] ->nEntriesInUse = 0;
 	ix[ stream ] ->dwChunkId = indx[ stream ] ->dwChunkId;
 	ix[ stream ] ->qwBaseOffset = offset + length;
@@ -1030,7 +925,7 @@ void AVIFile::UpdateIndx( int stream, int chunk, int duration )
 
 void AVIFile::UpdateIdx1( int chunk, int flags )
 {
-	if ( idx1->nEntriesInUse < 20000 )
+	if ( idx1->nEntriesInUse < IDX1_INDEX_SIZE )
 	{
 		FOURCC type;
 		FOURCC name;
@@ -1058,14 +953,14 @@ bool AVIFile::verifyStreamFormat( FOURCC type )
 
 	while ( ( i = FindDirectoryEntry( strh, j++ ) ) != -1 )
 	{
-		ReadChunk( i, ( void* ) & avi_stream_header );
+		ReadChunk( i, ( void* ) & avi_stream_header, sizeof( AVIStreamHeader ) );
 		if ( avi_stream_header.fccHandler == type )
 			return true;
 	}
 	j = 0;
 	while ( ( i = FindDirectoryEntry( strf, j++ ) ) != -1 )
 	{
-		ReadChunk( i, ( void* ) & bih );
+		ReadChunk( i, ( void* ) & bih, sizeof( BITMAPINFOHEADER ) );
 		if ( ( FOURCC ) bih.biCompression == type )
 			return true;
 	}
@@ -1081,7 +976,7 @@ bool AVIFile::verifyStream( FOURCC type )
 
 	while ( ( i = FindDirectoryEntry( strh, j++ ) ) != -1 )
 	{
-		ReadChunk( i, ( void* ) & avi_stream_header );
+		ReadChunk( i, ( void* ) & avi_stream_header, sizeof( AVIStreamHeader ) );
 		if ( avi_stream_header.fccType == type )
 			return true;
 	}
@@ -1773,7 +1668,7 @@ void AVIFile::setFccHandler( FOURCC type, FOURCC handler )
 
 			while ( ( k = FindDirectoryEntry( strf, j++ ) ) != -1 )
 			{
-				ReadChunk( k, ( void* ) & bih );
+				ReadChunk( k, ( void* ) & bih, sizeof( BITMAPINFOHEADER ) );
 				bih.biCompression = handler;
 			}
 		}
@@ -1790,7 +1685,7 @@ bool AVIFile::getStreamFormat( void* data, FOURCC type )
 
 	while ( ( result == false ) && ( i = FindDirectoryEntry( strh, j++ ) ) != -1 )
 	{
-		ReadChunk( i, ( void* ) & avi_stream_header );
+		ReadChunk( i, ( void* ) & avi_stream_header, sizeof( AVIStreamHeader ) );
 		if ( avi_stream_header.fccType == type )
 		{
 			FOURCC chunkID;
