@@ -20,8 +20,6 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtk.h>
-
 #include "callbacks.h"
 #include "support.h"
 #include "commands.h"
@@ -104,7 +102,6 @@ on_exit_activate ( GtkWidget *menuitem,
                    gpointer user_data )
 {
 	kinoDeactivate();
-	gtk_widget_grab_focus( lookup_widget( menuitem, "eventbox_edit_drawingarea" ) );
 }
 
 
@@ -558,38 +555,6 @@ on_command_reference_activate ( GtkMenuItem *menuitem,
 }
 
 
-static GtkWidget *kino_more_info = NULL;
-
-void
-on_button_more_info_clicked ( GtkButton *button,
-                              gpointer user_data )
-{
-	GtkArrow * a = GTK_ARROW( lookup_widget( GTK_WIDGET( button ), "arrow_more_info" ) );
-	GtkBin *bin = GTK_BIN( lookup_widget( GTK_WIDGET( button ), "frame_more_info" ) );
-	if ( a->arrow_type == GTK_ARROW_RIGHT )
-	{
-		kino_more_info = lookup_widget( GTK_WIDGET( button ), "window_more_info" );
-		gtk_arrow_set( a, GTK_ARROW_DOWN, GTK_SHADOW_OUT );
-		if ( kino_more_info )
-			gtk_widget_reparent( ( GTK_BIN( kino_more_info ) ) ->child, GTK_WIDGET( bin ) );
-		setMoreInfo( 1 );
-		windowMoved();
-	}
-	else
-	{
-		gtk_arrow_set( a, GTK_ARROW_RIGHT, GTK_SHADOW_OUT );
-		if ( kino_more_info )
-		{
-			gtk_widget_reparent( ( GTK_BIN( bin ) ) ->child, GTK_WIDGET( kino_more_info ) );
-			gtk_widget_hide( kino_more_info );
-		}
-		setMoreInfo( 0 );
-		windowMoved();
-	}
-	gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( button ), "eventbox_edit_drawingarea" ) );
-}
-
-
 void
 on_time_format_smpte_activate ( GtkMenuItem *menuitem,
                                 gpointer user_data )
@@ -753,3 +718,12 @@ on_preferences_dialog_help_button_clicked
 	snprintf( s, 13, "prefs.html#%d", page );
 	showHelp( s );
 }
+
+void
+on_expander_properties_activate        (GtkExpander     *expander,
+                                        gpointer         user_data)
+{
+	setMoreInfo( gtk_expander_get_expanded( expander ) ? 0 : 1 );
+	windowMoved();
+	gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( expander ), "eventbox_edit_drawingarea" ) );
+}
