@@ -45,7 +45,7 @@ extern "C"
 
 #include <sys/stat.h>
 #include <sys/time.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <math.h>
 
 #include "callbacks.h"
@@ -87,62 +87,6 @@ extern "C"
 		}
 	}
 
-	// XXX: this is a workaround to a bug in libglade
-	static void set_toolbar_tips( GtkWidget *widget )
-	{
-		GtkTooltips *toolbar_tips;
-		toolbar_tips = gtk_tooltips_new();
-
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_new" ),
-			_("New project"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_open" ),
-			_("Open a video or project"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_save" ),
-			_("Save project"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_publish_project" ),
-			_("Publish project"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_save_still_frame" ),
-			_("Save still frame"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_publish_still" ),
-			_("Publish still frame"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_undo" ),
-			_("Undo"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_redo" ),
-			_("Redo"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_cut" ),
-			_("Cut scene"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_copy" ),
-			_("Copy scene"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_paste" ),
-			_("Paste scene"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_insert" ),
-			_("Insert a file before the current scene"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_append" ),
-			_("Insert a file after the current scene"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_split" ),
-			_("Split scene"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_join" ),
-			_("Join current and next scenes"), NULL );
-		gtk_tooltips_set_tip( GTK_TOOLTIPS( toolbar_tips ),
-			lookup_widget( widget, "button_viewsize" ),
-			_("Cycle through Zoom 50%, 100% and Fit views"), NULL );
-	}
-				  
 	void kinoInitialise( GtkWidget * widget )
 	{
 		common = new KinoCommon( widget );
@@ -166,7 +110,6 @@ extern "C"
 		                   ( GtkDestDefaults ) ( GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT |
 		                                         GTK_DEST_DEFAULT_DROP ), file_targets, 1,
 		                   ( GdkDragAction ) ( GDK_ACTION_COPY | GDK_ACTION_MOVE ) );
-		set_toolbar_tips( widget );
 		gtk_window_set_default_size( GTK_WINDOW( widget ),
 			Preferences::getInstance().windowWidth, Preferences::getInstance().windowHeight );
 		gtk_paned_set_position( GTK_PANED( lookup_widget( widget , "hpaned1" ) ),
@@ -187,7 +130,7 @@ extern "C"
 
 	void kinoPostInit()
 	{
-		common->setPreviewSize( Preferences::getInstance().previewSize, true );
+		common->setPreviewSize( float( Preferences::getInstance().previewSize ) / 10.0, true );
 		notebookChangePage( PAGE_EDITOR );
 	}
 
@@ -200,21 +143,12 @@ extern "C"
 				&Preferences::getInstance().windowHeight );
 			Preferences::getInstance().storyboardPosition = gtk_paned_get_position( GTK_PANED(
 				lookup_widget( common->getWidget() , "hpaned1" ) ) );
-
 			Preferences::getInstance().Save();
-			delete common;
-			gtk_exit( 0 );
+			gtk_main_quit();
 		}
 		return TRUE;
 	}
 
-	void refresh( )
-	{
-		cout << "Refresh\n";
-		//common->moveToFrame( );
-		//gtk_widget_queue_draw( lookup_widget( common->getWidget(), "drawingarea1") );
-	}
-
 	void bulkLoad( int argc, char * argv[] )
 	{
 		common->bulkLoad( argc, argv );
