@@ -36,8 +36,8 @@ AspectRatioCalculator::AspectRatioCalculator( int widgetWidth, int widgetHeight,
 	double ratioHeight = ( double ) widgetHeight / ( double ) imageHeight;
 	double ratioConstant = ratioHeight < ratioWidth ?
 	                       ratioHeight : ratioWidth;
-	width = ( int ) ( imageWidth * ratioConstant );
-	height = ( int ) ( imageHeight * ratioConstant );
+	width = ( int ) ( imageWidth * ratioConstant + 0.5 );
+	height = ( int ) ( imageHeight * ratioConstant + 0.5 );
 	if ( width > maxImageWidth )
 		width = maxImageWidth;
 	if ( height > maxImageHeight )
@@ -98,13 +98,13 @@ AspectRatioCalculator::AspectRatioCalculator( int widgetWidth, int widgetHeight,
 
 	if ( ratioHeight < ratioWidth )
 	{
-		width = ( int ) ( imageWidth * ratioHeight );
-		height = ( int ) ( imageHeight * ratioHeight );
+		width = ( int ) ( imageWidth * ratioHeight + 0.5 );
+		height = ( int ) ( imageHeight * ratioHeight + 0.5 );
 	}
 	else
 	{
-		width = ( int ) ( imageWidth * ratioWidth );
-		height = ( int ) ( imageHeight * ratioWidth );
+		width = ( int ) ( imageWidth * ratioWidth + 0.5 );
+		height = ( int ) ( imageHeight * ratioWidth + 0.5 );
 	}
 
 	// cerr << "Final   : " << width << "x" << height << endl;
