@@ -25,7 +25,7 @@
 #endif
 #include <sys/time.h>
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include "page_export.h"
 #include "kino_common.h"
 
