@@ -438,14 +438,14 @@ AVIHandler::~AVIHandler()
 {
 	if ( audioBuffer != NULL )
 	{
-		delete audioBuffer;
+		delete[] audioBuffer;
 		audioBuffer = NULL;
 	}
 	for ( int c = 0; c < 4; c++ )
 	{
 		if ( audioChannels[ c ] != NULL )
 		{
-			delete audioChannels[ c ];
+			delete[] audioChannels[ c ];
 			audioChannels[ c ] = NULL;
 		}
 	}
@@ -474,8 +474,7 @@ void AVIHandler::SetSampleFrame( const Frame& sample )
 	sample.GetVAUXPack( 0x61, pack );
 	dvinfo.dwDVVAuxCtl = *( DWORD* ) ( pack.data + 1 );
 
-#ifdef WITH_LIBDV
-
+#ifdef HAVE_LIBDV
 	if ( sample.decoder->std == e_dv_std_smpte_314m )
 		fccHandler = make_fourcc( "dv25" );
 #endif
@@ -686,10 +685,6 @@ bool AVIHandler::GetOpenDML() const
 
 #ifdef HAVE_LIBQUICKTIME
 
-#ifndef HAVE_LIBDV
-#define DV_AUDIO_MAX_SAMPLES 1944
-#endif
-
 QtHandler::QtHandler() : fd( NULL )
 {
 	extension = ".mov";
@@ -818,14 +813,14 @@ int QtHandler::Close()
 	}
 	if ( audioBuffer != NULL )
 	{
-		delete audioBuffer;
+		delete[] audioBuffer;
 		audioBuffer = NULL;
 	}
 	if ( audioChannelBuffer != NULL )
 	{
 		for ( int c = 0; c < channels; c++ )
-			delete audioChannelBuffer[ c ];
-		delete audioChannelBuffer;
+			delete[] audioChannelBuffer[ c ];
+		delete[] audioChannelBuffer;
 		audioChannelBuffer = NULL;
 	}
 	return 0;
