@@ -55,12 +55,10 @@ using std::endl;
 #include "frame.h"
 #include "preferences.h"
 
-extern Preferences prefs;
-
 VideoInfo::VideoInfo() : width( 0 ), height( 0 ), isPAL( false )
 {}
 
-#ifndef WITH_LIBDV
+#ifndef HAVE_LIBDV
 bool Frame::maps_initialized = false;
 int Frame::palmap_ch1[ 2000 ];
 int Frame::palmap_ch2[ 2000 ];
@@ -75,6 +73,8 @@ int Frame::ntscmap_2ch2[ 2000 ];
 short Frame::compmap[ 4096 ];
 #endif
 
+pthread_mutex_t avcodec_mutex = PTHREAD_MUTEX_INITIALIZER;
+
 
 /** constructor
  
@@ -83,29 +83,31 @@ short Frame::compmap[ 4096 ];
  
 */
 
-Frame::Frame() : bytesInFrame( 0 )
+Frame::Frame() : bytesInFrame( 0 ), tempImage( 0 )
 {
-	memset( data, 0, 144000 );
-
 #if defined(HAVE_LIBAVCODEC)
-
+	pthread_mutex_lock( &avcodec_mutex );
 	avcodec_init();
-	avcodec_get_context_defaults( &libavcodec );
-	avcodec_open( &libavcodec, &dvvideo_decoder );
+	libavcodec = avcodec_alloc_context();
+	libavcodec->thread_count = 2;
+	avcodec_open( libavcodec, &dvvideo_decoder );
+	pthread_mutex_unlock( &avcodec_mutex );
+	avcodecEncoder = NULL;
+	data = ( unsigned char* ) av_mallocz( 144000 );
+#else
+	data = ( unsigned char* ) calloc( 1, 144000 );
 #endif
 
-#ifdef WITH_LIBDV
-
+#ifdef HAVE_LIBDV
 	decoder = dv_decoder_new( FALSE,
 	                          Preferences::getInstance().dvDecoderClampLuma,
 	                          Preferences::getInstance().dvDecoderClampChroma );
 	decoder->audio->arg_audio_emphasis = 2;
 	this->SetPreferredQuality( );
 	dv_set_audio_correction ( decoder, DV_AUDIO_CORRECT_AVERAGE );
-	libdv_log = fopen( "/dev/null", "w" );
-	dv_set_error_log( decoder, libdv_log );
+	dv_set_error_log( decoder, NULL );
+	encoder = NULL;
 #else
-#define DV_AUDIO_MAX_SAMPLES 1944
 
 	if ( maps_initialized == false )
 	{
@@ -169,12 +171,29 @@ Frame::Frame() : bytesInFrame( 0 )
 Frame::~Frame()
 {
 #if defined(HAVE_LIBAVCODEC)
-	avcodec_close( &libavcodec );
+	pthread_mutex_lock( &avcodec_mutex );
+	avcodec_close( libavcodec );
+	av_free( libavcodec );
+	if ( avcodecEncoder )
+	{
+		avcodec_close( avcodecEncoder );
+		av_free( avcodecEncoder );
+	}
+	pthread_mutex_unlock( &avcodec_mutex );
+	av_free( data );
+	if ( tempImage )
+		av_free( tempImage );
+#else
+	free( data );
+	if ( tempImage )
+		delete[] tempImage;
 #endif
 
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	dv_decoder_free( decoder );
 	fclose( libdv_log );
+	if ( encoder )
+		dv_encoder_free( encoder );
 #endif
 
 	for ( int n = 0; n < 4; n++ )
@@ -192,24 +211,10 @@ Frame::~Frame()
 
 bool Frame::GetSSYBPack( int packNum, Pack &pack ) const
 {
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	pack.data[ 0 ] = packNum;
-#ifdef HAVE_LIBDV_1_0
-
 	dv_get_ssyb_pack( decoder, packNum, &pack.data[ 1 ] );
-#else
-
-	int id;
-	if ( ( id = decoder->ssyb_pack[ packNum ] ) != 0xff )
-	{
-		pack.data[ 1 ] = decoder->ssyb_data[ id ][ 0 ];
-		pack.data[ 2 ] = decoder->ssyb_data[ id ][ 1 ];
-		pack.data[ 3 ] = decoder->ssyb_data[ id ][ 2 ];
-		pack.data[ 4 ] = decoder->ssyb_data[ id ][ 3 ];
-	}
-#endif
 	return true;
-
 #else
 	/* number of DIF sequences is different for PAL and NTSC */
 
@@ -269,7 +274,7 @@ bool Frame::GetSSYBPack( int packNum, Pack &pack ) const
     \return true for success, false if no pack could be found */
 bool Frame::GetVAUXPack( int packNum, Pack &pack ) const
 {
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	pack.data[ 0 ] = packNum;
 	dv_get_vaux_pack( decoder, packNum, &pack.data[ 1 ] );
 	//cerr << "VAUX: 0x"
@@ -338,7 +343,7 @@ bool Frame::GetVAUXPack( int packNum, Pack &pack ) const
     \return true for success, false if no pack could be found */
 bool Frame::GetAAUXPack( int packNum, Pack &pack ) const
 {
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	bool done = false;
 	switch ( packNum )
 	{
@@ -352,23 +357,15 @@ bool Frame::GetAAUXPack( int packNum, Pack &pack ) const
 		done = true;
 		break;
 
-#ifdef HAVE_LIBDV_1_0
-
 	case 0x52:
-		memcpy( pack.data, decoder->audio->aaux_as1, 5 );
+		memcpy( pack.data, &decoder->audio->aaux_as1, 5 );
 		done = true;
 		break;
 
 	case 0x53:
-		memcpy( pack.data, decoder->audio->aaux_asc1, 5 );
-done = true:
-		       break;
-#else
-
-	default:
+		memcpy( pack.data, &decoder->audio->aaux_asc1, 5 );
+		done = true;
 		break;
-#endif
-
 	}
 	if ( done )
 		return true;
@@ -420,7 +417,7 @@ done = true:
 
 bool Frame::GetRecordingDate( struct tm &recDate ) const
 {
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	return dv_get_recording_datetime_tm( decoder, ( struct tm * ) &recDate );
 #else
 
@@ -475,7 +472,7 @@ bool Frame::GetRecordingDate( struct tm &recDate ) const
 string Frame::GetRecordingDate( void ) const
 {
 	string recDate;
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 
 	char s[ 64 ];
 	if ( dv_get_recording_datetime( decoder, s ) )
@@ -518,7 +515,7 @@ string Frame::GetRecordingDate( void ) const
 
 bool Frame::GetTimeCode( TimeCode &timeCode ) const
 {
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	int timestamp[ 4 ];
 
 	dv_get_timestamp_int( decoder, timestamp );
@@ -558,7 +555,7 @@ bool Frame::GetTimeCode( TimeCode &timeCode ) const
 
 bool Frame::GetAudioInfo( AudioInfo &info ) const
 {
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	info.frequency = dv_get_frequency( decoder );
 	info.samples = dv_get_num_samples( decoder );
 	info.frames = IsPAL() ? 50 : 60;
@@ -681,7 +678,7 @@ bool Frame::IsPAL( void ) const
 	unsigned char dsf = data[ 3 ] & 0x80;
 	bool pal = ( dsf == 0 ) ? false : true;
 
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	if ( !pal )
 		pal = dv_is_PAL( decoder );
 #endif
@@ -698,7 +695,7 @@ bool Frame::IsPAL( void ) const
 
 bool Frame::IsNewRecording() const
 {
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 	return dv_is_new_recording( decoder, data );
 #else
 
@@ -743,7 +740,7 @@ bool Frame::IsNormalSpeed() const
 
 bool Frame::IsComplete( void ) const
 {
-	return bytesInFrame == GetFrameSize();
+	return bytesInFrame >= GetFrameSize();
 }
 
 
@@ -762,7 +759,7 @@ int Frame::ExtractAudio( void *sound ) const
 {
 	AudioInfo info;
 
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 
 	if ( GetAudioInfo( info ) == true )
 	{
@@ -844,21 +841,16 @@ int Frame::ExtractAudio( void *sound ) const
 	default:
 		info.samples = 0;
 	}
-}
-else
-{
-	info.samples = 0;
-}
 
 #endif
 	return info.samples * info.channels * 2;
 }
 
-#ifdef WITH_LIBDV
+#ifdef HAVE_LIBDV
 
 void Frame::SetPreferredQuality( )
 {
-	switch ( ( int ) Preferences::getInstance().displayQuality )
+	switch ( Preferences::getInstance().displayQuality )
 	{
 	case 5:
 		dv_set_quality( decoder, DV_QUALITY_FASTEST );
@@ -974,39 +966,32 @@ void Frame::Deinterlace( uint8_t *pdst, uint8_t *psrc, int stride, int height )
 int Frame::ExtractRGB( void * rgb )
 {
 #if defined(HAVE_LIBAVCODEC)
-	if ( IsPAL() )
+	AVFrame *frame = avcodec_alloc_frame();
+	AVPicture dest;
+	int got_picture;
+
+	avcodec_decode_video( libavcodec, frame, &got_picture, data, GetFrameSize() );
+	if ( got_picture )
 	{
-		AVFrame frame;
-		int got_picture;
-
-		avcodec_decode_video( &libavcodec, &frame, &got_picture, data, GetFrameSize() );
-
-		AVPicture dest;
-		dest.data[ 0 ] = static_cast<uint8_t*>( rgb );
-		dest.linesize[ 0 ] = GetWidth() * 3;
-
-		img_convert( &dest, PIX_FMT_RGB24, reinterpret_cast<AVPicture*>( &frame ), libavcodec.pix_fmt, GetWidth(), GetHeight() );
+		avpicture_fill( &dest, static_cast<uint8_t*>( rgb ), PIX_FMT_RGB24, GetWidth(), GetHeight() );
+		img_convert( &dest, PIX_FMT_RGB24, reinterpret_cast<AVPicture*>( frame ), libavcodec->pix_fmt, GetWidth(), GetHeight() );
 	}
-	else
-	{
-#endif
-		guchar *pixels[ 3 ];
-		gint pitches[ 3 ];
+	av_free( frame );
+#else
+	unsigned char *pixels[ 3 ];
+	int pitches[ 3 ];
 
-		pixels[ 0 ] = ( guchar* ) rgb;
-		pixels[ 1 ] = NULL;
+	pixels[ 0 ] = ( unsigned char* ) rgb;
+	pixels[ 1 ] = NULL;
 
 
-		pixels[ 2 ] = NULL;
+	pixels[ 2 ] = NULL;
 
-		pitches[ 0 ] = 720 * 3;
-		pitches[ 1 ] = 0;
-		pitches[ 2 ] = 0;
+	pitches[ 0 ] = 720 * 3;
+	pitches[ 1 ] = 0;
+	pitches[ 2 ] = 0;
 
-		dv_decode_full_frame( decoder, data, e_dv_color_rgb, pixels, pitches );
-#if defined(HAVE_LIBAVCODEC)
-
-	}
+	dv_decode_full_frame( decoder, data, e_dv_color_rgb, pixels, pitches );
 #endif
 	return 0;
 }
@@ -1034,58 +1019,22 @@ int Frame::ExtractPreviewRGB( void *rgb )
 int Frame::ExtractYUV( void *yuv )
 {
 #if defined(HAVE_LIBAVCODEC)
-	AVFrame frame;
+	AVFrame *frame = avcodec_alloc_frame();;
+	AVPicture output;
 	int got_picture;
 
-	avcodec_decode_video( &libavcodec, &frame, &got_picture, data, GetFrameSize() );
-
-	uint8_t* dest = static_cast<uint8_t*>( yuv );
-	int width = GetWidth(), height = GetHeight();
-
-	if ( libavcodec.pix_fmt == PIX_FMT_YUV420P )   // PAL
+	avcodec_decode_video( libavcodec, frame, &got_picture, data, GetFrameSize() );
+	if ( got_picture )
 	{
-		for ( int y = 0; y < height; ++y )
-		{
-			uint8_t* Y = frame.data[ 0 ] + y * frame.linesize[ 0 ];
-			uint8_t* Cb = frame.data[ 1 ] + ( y / 2 ) * frame.linesize[ 1 ];
-			uint8_t* Cr = frame.data[ 2 ] + ( y / 2 ) * frame.linesize[ 2 ];
-
-			for ( int x = 0; x < width; x += 2 )
-			{
-				*reinterpret_cast<uint32_t*>( dest ) = Y[ 0 ] + ( Cb[ 0 ] << 8 ) + ( Y[ 1 ] << 16 ) + ( Cr[ 0 ] << 24 );
-
-				dest += 4;
-				Y += 2;
-				++Cb;
-				++Cr;
-			}
-		}
-	}
-	else // libavcodec.pix_fmt == PIX_FMT_YUV411P // NTSC
-	{
-		for ( int y = 0; y < height; ++y )
-		{
-			uint8_t* Y = frame.data[ 0 ] + y * frame.linesize[ 0 ];
-			uint8_t* Cb = frame.data[ 1 ] + y * frame.linesize[ 1 ];
-			uint8_t* Cr = frame.data[ 2 ] + y * frame.linesize[ 2 ];
-
-			for ( int x = 0; x < width; x += 4 )
-			{
-				*reinterpret_cast<uint32_t*>( dest ) = Y[ 0 ] + ( Cb[ 0 ] << 8 ) + ( Y[ 1 ] << 16 ) + ( Cr[ 0 ] << 24 );
-				*reinterpret_cast<uint32_t*>( dest + 4 ) = Y[ 2 ] + ( Cb[ 0 ] << 8 ) + ( Y[ 3 ] << 16 ) + ( Cr[ 0 ] << 24 );
-
-				dest += 8;
-				Y += 4;
-				++Cb;
-				++Cr;
-			}
-		}
+		avpicture_fill( &output, static_cast<uint8_t*>( yuv ), PIX_FMT_YUV422, GetWidth(), GetHeight() );
+		img_convert( &output, PIX_FMT_YUV422, (AVPicture *)frame, libavcodec->pix_fmt, GetWidth(), GetHeight() );
 	}
+	av_free( frame );
 #else
-	guchar *pixels[ 3 ];
-	gint pitches[ 3 ];
+	unsigned char *pixels[ 3 ];
+	int pitches[ 3 ];
 
-	pixels[ 0 ] = ( guchar* ) yuv;
+	pixels[ 0 ] = ( unsigned char* ) yuv;
 	pitches[ 0 ] = decoder->width * 2;
 
 	dv_decode_full_frame( decoder, data, e_dv_color_yuv, pixels, pitches );
@@ -1097,14 +1046,14 @@ int Frame::ExtractYUV( void *yuv )
 int Frame::ExtractYUV420( uint8_t *yuv, uint8_t *output[ 3 ] )
 {
 #if defined(HAVE_LIBAVCODEC)
-	AVFrame frame;
+	AVFrame *frame = avcodec_alloc_frame();
 	int got_picture;
 
-	avcodec_decode_video( &libavcodec, &frame, &got_picture, data, GetFrameSize() );
+	avcodec_decode_video( libavcodec, frame, &got_picture, data, GetFrameSize() );
 
 	int width = GetWidth(), height = GetHeight();
 
-	if ( libavcodec.pix_fmt == PIX_FMT_YUV420P )   // PAL
+	if ( libavcodec->pix_fmt == PIX_FMT_YUV420P )   // PAL
 	{
 		int h2 = height / 2;
 		int w2 = width / 2;
@@ -1112,63 +1061,63 @@ int Frame::ExtractYUV420( uint8_t *yuv, uint8_t *output[ 3 ] )
 		uint8_t *Y = output[ 0 ];
 		uint8_t *Cb = output[ 1 ];
 		uint8_t *Cr = output[ 2 ];
-		uint8_t *fY = frame.data[ 0 ];
-		uint8_t *fCb = frame.data[ 1 ];
-		uint8_t *fCr = frame.data[ 2 ];
+		uint8_t *fY = frame->data[ 0 ];
+		uint8_t *fCb = frame->data[ 1 ];
+		uint8_t *fCr = frame->data[ 2 ];
 
 		for ( int y = 0; y < height; y ++ )
 		{
 			memcpy( Y, fY, width );
 			Y += width;
-			fY += frame.linesize[ 0 ];
+			fY += frame->linesize[ 0 ];
 			if ( y < h2 )
 			{
 				memcpy( Cb, fCb, w2 );
 				memcpy( Cr, fCr, w2 );
 				Cb += w2;
 				Cr += w2;
-				fCb += frame.linesize[ 1 ];
-				fCr += frame.linesize[ 2 ];
+				fCb += frame->linesize[ 1 ];
+				fCr += frame->linesize[ 2 ];
 			}
 		}
 	}
 	else // libavcodec.pix_fmt == PIX_FMT_YUV411P // NTSC
 	{
-//		int h2 = height / 2;
 		int w4 = width / 4;
 
 		uint8_t *Y = output[ 0 ];
 		uint8_t *Cb = output[ 1 ];
 		uint8_t *Cr = output[ 2 ];
-		uint8_t *fY = frame.data[ 0 ];
-		uint8_t *fCb = frame.data[ 1 ];
-		uint8_t *fCr = frame.data[ 2 ];
+		uint8_t *fY = frame->data[ 0 ];
+		uint8_t *fCb = frame->data[ 1 ];
+		uint8_t *fCr = frame->data[ 2 ];
 
 		for ( int y = 0; y < height; y ++ )
 		{
 			memcpy( Y, fY, width );
 			Y += width;
-			fY += frame.linesize[ 0 ];
+			fY += frame->linesize[ 0 ];
 			if ( y % 2 == 0 )
 			{
 				for ( int x = 0; x < w4; x ++ )
 				{
 					*Cb ++ = fCb[ x ];
-					*Cb ++ = fCb[ frame.linesize[ 1 ] + x ];
+					*Cb ++ = fCb[ frame->linesize[ 1 ] + x ];
 					*Cr ++ = fCr[ x ];
-					*Cr ++ = fCr[ frame.linesize[ 2 ] + x ];
+					*Cr ++ = fCr[ frame->linesize[ 2 ] + x ];
 				}
-				fCb += 2 * frame.linesize[ 1 ];
-				fCr += 2 * frame.linesize[ 2 ];
+				fCb += 2 * frame->linesize[ 1 ];
+				fCr += 2 * frame->linesize[ 2 ];
 			}
 		}
 	}
+	av_free( frame );
 #else
-	guchar *pixels[ 3 ];
-	gint pitches[ 3 ];
+	unsigned char *pixels[ 3 ];
+	int pitches[ 3 ];
 	int width = GetWidth(), height = GetHeight();
 
-	pixels[ 0 ] = ( guchar* ) yuv;
+	pixels[ 0 ] = ( unsigned char* ) yuv;
 	pitches[ 0 ] = decoder->width * 2;
 
 	dv_decode_full_frame( decoder, data, e_dv_color_yuv, pixels, pitches );
@@ -1289,198 +1238,127 @@ void Frame::SetTimeCode( int frame )
 	dv_encode_timecode( data, IsPAL(), frame );
 }
 
+bool Frame::CreateEncoder( bool isPAL, bool isWide )
+{
+#if defined(HAVE_LIBAVCODEC)
+	if ( avcodecEncoder == NULL )
+	{
+		avcodecEncoder = avcodec_alloc_context();
+		if ( avcodecEncoder )
+		{
+			pthread_mutex_lock( &avcodec_mutex );
+			avcodec_open( avcodecEncoder, &dvvideo_encoder );
+			pthread_mutex_unlock( &avcodec_mutex );
+			if ( isPAL )
+ 				avcodecEncoder->sample_aspect_ratio = isWide ? ( AVRational ){ 118, 81 } : ( AVRational ){ 59, 54 };
+			else
+ 				avcodecEncoder->sample_aspect_ratio = isWide ? ( AVRational ){ 40, 33 } : ( AVRational ){ 10, 11 };
+			avcodecEncoder->thread_count = 2;
+			avcodecEncoder->width = FRAME_MAX_WIDTH;
+			avcodecEncoder->height = isPAL ? 576 : 480;
+			avcodecEncoder->time_base= isPAL ? ( AVRational ){ 1, 25 } : ( AVRational ){ 1001, 30000 };
+			avcodecEncoder->pix_fmt = isPAL ? PIX_FMT_YUV420P : PIX_FMT_YUV411P;
+			tempImage = ( uint8_t* ) av_malloc( 
+				avpicture_get_size( avcodecEncoder->pix_fmt, avcodecEncoder->width, avcodecEncoder->height ) );
+		}
+		else
+		{
+			return false;
+		}
+	}
+#endif
+	if ( encoder == NULL )
+	{
+		if ( isPAL )
+			encoder = dv_encoder_new( FALSE, FALSE, FALSE );
+		else
+			encoder = dv_encoder_new( FALSE,
+									Preferences::getInstance().dvDecoderClampLuma,
+									Preferences::getInstance().dvDecoderClampChroma );
+		if ( encoder )
+		{
+			encoder->isPAL = isPAL;
+			encoder->is16x9 = isWide;
+			encoder->vlc_encode_passes = 3;
+			encoder->static_qno = 0;
+			encoder->force_dct = DV_DCT_AUTO;
+
+			tempImage = new uint8_t[ FRAME_MAX_WIDTH * FRAME_MAX_HEIGHT * 4 ];
+		}
+	}
+	return ( encoder != NULL );
+}
 
 bool Frame::EncodeAudio( AudioInfo &info, int16_t **channels )
 {
-	dv_encoder_t * encoder = dv_encoder_new( FALSE, FALSE, FALSE );
-#ifdef LIBDV_HAS_SAMPLE_CALCULATOR
+	int result = -1;
 
-	encoder->samples_this_frame = info.samples;
-#endif
-
-	int result = dv_encode_full_audio( encoder, channels, info.channels, info.frequency, data );
-	dv_encoder_free( encoder );
+	if ( CreateEncoder( IsPAL(), IsWide() ) )
+	{
+		encoder->samples_this_frame = info.samples;
+		result = dv_encode_full_audio( encoder, channels, info.channels, info.frequency, data );
+	}
 	return ( result != -1 );
 }
 
 int Frame::CalculateNumberSamples( int frequency, int iteration )
 {
-#ifdef LIBDV_HAS_SAMPLE_CALCULATOR
-	dv_encoder_t * encoder = dv_encoder_new( FALSE, FALSE, FALSE );
-	int samples = dv_calculate_samples( encoder, frequency, iteration );
-	dv_encoder_free( encoder );
+	int samples = 0;
 
-#else
-	int samples = info->frequency / ( info->isPAL ? 25 : 30 );
-#endif
+	if ( CreateEncoder( IsPAL(), IsWide() ) )
+		samples = dv_calculate_samples( encoder, frequency, iteration );
 	
 	return samples;
 }
 
+void Frame::EncodeRGB( uint8_t *rgb )
+{
+	if ( CreateEncoder( IsPAL(), IsWide() ) )
+	{
+#if defined(HAVE_LIBAVCODEC)
+		AVFrame *input = avcodec_alloc_frame();
+		AVFrame *output = avcodec_alloc_frame();
+		if ( input && output )
+		{
+			int width = avcodecEncoder->width;
+			int height = avcodecEncoder->height;
+			size_t size = height > 480 ? 144000 : 120000;
+
+			avpicture_fill( ( AVPicture* )output, tempImage, avcodecEncoder->pix_fmt, width, height );
+			avpicture_fill( ( AVPicture* )input, rgb, PIX_FMT_RGB24, width, height );
+
+			img_convert( ( AVPicture* )output, avcodecEncoder->pix_fmt, ( AVPicture* )input, PIX_FMT_RGB24, width, height );
+
+			bytesInFrame = avcodec_encode_video( avcodecEncoder, data, size, output );
+			ExtractHeader();
+
+			av_free( output );
+			av_free( input );
+		}
+#else
+		if ( Preferences::getInstance().dvTwoPassEncoder )
+		{
+			dv_encode_full_frame( encoder, &rgb, e_dv_color_rgb, data );
+			decoder->quality = DV_QUALITY_BEST;
+			ExtractHeader( );
+			ExtractRGB( tempImage );
+			int size = GetWidth( ) * GetHeight( ) * 3;
+			for ( int i = 0; i < size; i ++ )
+				rgb[ i ] = std::min( std::max( ( int ) rgb[ i ] - ( ( int ) tempImage[ i ] - ( int ) rgb[ i ] ), 0 ), 255 );
+			dv_encode_full_frame( encoder, &rgb, e_dv_color_rgb, data );
+			SetPreferredQuality();
+			ExtractHeader();
+		}
+		else
+		{
+			dv_encode_full_frame( encoder, &rgb, e_dv_color_rgb, data );
+		}
+#endif
+	}
+}
 
 #endif
 
-/** Constructor for the resampler.
-*/
-#define BUFFER_LEN 20480
-
-AudioResample::AudioResample( int rate ) : output_rate( rate )
-{
-	input = new int16_t[ BUFFER_LEN ];
-	output = new int16_t[ BUFFER_LEN ];
-}
-
-/** Destructor for the resampler.
-*/
-
-AudioResample::~AudioResample()
-{
-	delete input;
-	delete output;
-}
-
-/** Frame handler.
-*/
-
-void AudioResample::Resample( Frame &frame )
-{
-	//  cout << "Resample -----------------" << endl;
-	if ( output_rate != 0 )
-	{
-		frame.ExtractAudio( input );
-		AudioInfo info;
-		frame.GetAudioInfo( info );
-		/*
-		cout << "Audio info: " << endl
-		     << "  dec-..->frequency: " 
-		     << info.frequency << endl
-		     << "  samples: " 
-		     << info.samples << endl;
-		*/
-		if ( info.frequency && output_rate != info.frequency )
-		{
-			Resample( input,
-			          info.frequency,
-			          info.channels,
-			          info.samples );
-		}
-		else
-		{
-			memcpy( output, input, info.samples * 4 );
-			size = info.samples * 4;
-		}
-	}
-	else
-	{
-		size = 0;
-	}
-	// cout << "size: " << size << endl;
-}
-
-/** Constructor for fast internal resampler
- */
-
-InternalAudioResample::InternalAudioResample( ) : AudioResample( 0 )
-{}
-
-InternalAudioResample::InternalAudioResample( int output_rate ) : AudioResample( output_rate )
-{}
-
-/** Destructor for fast internal resampler
- */
-
-InternalAudioResample::~InternalAudioResample()
-{}
-
-/** Simple up and down resampler for people unable to handle 48khz audio.
-    Also fixes mixed projects with 32khz and 48khz audio sampling (yippee!).  
-*/
-
-void InternalAudioResample::Resample( int16_t *input, int input_rate, int channels, int samples )
-{
-	float ratio = ( float ) output_rate / ( float ) input_rate;
-	size = ( int ) ( ( float ) samples * ratio );
-
-	int rounding = 1 << 15;
-	unsigned int xfactor = ( samples << 16 ) / size;
-	unsigned int xmax = xfactor * size;
-	unsigned int i = 0;
-	unsigned int o = 0;
-	size *= 2 * channels;
-
-	for ( unsigned int xft = 0; xft < xmax; xft += xfactor )
-	{
-		i = ( ( xft + rounding ) >> 16 ) * channels;
-		memcpy( &output[ o ], &input[ i ], 2 * channels );
-		o += channels;
-	}
-
-}
-
-
-/** Constructor for Secret Rabbit Code (libsamplerate) resampler
- */
-
-SrcAudioResample::SrcAudioResample( int converter ) : AudioResample( 0 )
-{
-	int srcError = 0;
-	state = src_new( converter, 2, &srcError );
-	if ( srcError != 0 )
-		cerr << "SRC: " << src_strerror( srcError ) << endl;
-}
-
-SrcAudioResample::SrcAudioResample( int converter, int output_rate ) : AudioResample( output_rate )
-{
-	int srcError = 0;
-	state = src_new( converter, 2, &srcError );
-}
-
-/** Destructor for fast internal resampler
- */
-
-SrcAudioResample::~SrcAudioResample()
-{
-	src_delete( state );
-}
-
-/** Simple up and down resampler for people unable to handle 48khz audio.
-    Also fixes mixed projects with 32khz and 48khz audio sampling (yippee!).  
-*/
-
-void SrcAudioResample::Resample( int16_t *input, int input_rate, int channels, int samples )
-{
-	SRC_DATA data;
-	static float input_buffer[ BUFFER_LEN ];
-	static float output_buffer[ BUFFER_LEN ];
-
-	for ( int i = 0; i < samples * channels; ++i )
-		input_buffer[ i ] = ( float ) input[ i ] / 32768.0;
-
-	data.data_in = input_buffer;
-	data.data_out = output_buffer;
-	data.src_ratio = ( float ) output_rate / ( float ) input_rate;
-	data.input_frames = samples;
-	data.output_frames = BUFFER_LEN / channels;
-	data.end_of_input = 0;
-	int result = src_process ( state, &data );
-	if ( result != 0 )
-		cerr << "SRC: " << src_strerror( result ) << endl;
-	size = data.output_frames_gen * channels * 2;
-	for ( int i = 0; i < data.output_frames_gen * channels; ++i )
-	{
-		float sample = output_buffer[ i ];
-		if ( sample > 1.0 )
-			sample = 1.0;
-		if ( sample < -1.0 )
-			sample = -1.0;
-		if ( sample >= 0 )
-			output[ i ] = ( long int )( 32767.0 * sample );
-		else
-			output[ i ] = ( long int )( 32768.0 * sample );
-	}
-}
-
-
 class KinoFramePool : public FramePool
 {
 private:
