@@ -27,7 +27,6 @@ using std::cerr;
 using std::endl;
 
 #include <pthread.h>
-#include <libdv/dv.h>
 
 #include "framedisplayer.h"
 #include "preferences.h"
@@ -64,7 +63,7 @@ void FrameDisplayer::CloseSound()
 {
 	if ( audio_device_avail )
 	{
-		dv_oss_close( audio_device );
+		kino_sound_close( audio_device );
 		audio_device_avail = FALSE;
 		audio_device = NULL;
 	}
@@ -77,20 +76,20 @@ void FrameDisplayer::PutSound( Frame &frame )
 	if ( prefs.enableAudio )
 	{
 		if ( audio_device == NULL )
-			audio_device = dv_oss_new();
+			audio_device = kino_sound_new();
 		if ( audio_device != NULL )
 		{
 			if ( !audio_device_avail &&
-					( audio_sampling_rate = dv_oss_init( frame.decoder->audio, audio_device ) ) != 0 )
+					( audio_sampling_rate = kino_sound_init( frame.decoder->audio, audio_device, prefs.audioDevice ) ) != 0 )
 				audio_device_avail = TRUE;
 			if ( audio_device_avail )
 			{
 				if ( resampler == NULL )
-					resampler = AudioResampleFactory::createAudioResample(
+					resampler = AudioResampleFactory<int16_ne_t,int16_ne_t>::createAudioResample(
 									AUDIO_RESAMPLE_SRC_SINC_FASTEST, audio_sampling_rate );
 				resampler->Resample( frame );
 				if ( resampler->size )
-					dv_oss_player( audio_device, resampler->output, resampler->size );
+					kino_sound_player( audio_device, resampler->output, resampler->size );
 			}
 		}
 	}
