@@ -73,9 +73,9 @@ static GtkWidgetClass *parent_class = NULL;
 
 /* ================================================================= */
 
-guint gtk_enhanced_scale_get_type ()
+GType gtk_enhanced_scale_get_type ()
 {
-	static guint enhanced_scale_type = 0;
+	static GType enhanced_scale_type = 0;
 
 	if ( !enhanced_scale_type )
 	{
@@ -1189,12 +1189,7 @@ static void gtk_enhanced_scale_adjustment_value_changed( GtkAdjustment *adjustme
 		if ( adjustment == GTK_ADJUSTMENT( enhanced_scale->adjustment[i] ) )
 		{
 			gtk_enhanced_scale_slider_update( enhanced_scale, i );
-			if ( i > 0 )
-				/* selection changed, need to redraw all */
-				gtk_enhanced_scale_draw ( GTK_WIDGET( enhanced_scale ), NULL );
-			else
-				/* only need to update position slider */
-				gtk_enhanced_scale_draw_slider( enhanced_scale, i );
+			gtk_enhanced_scale_draw ( GTK_WIDGET( enhanced_scale ), NULL );
 			break;
 		}
 	}
