@@ -93,6 +93,7 @@ using std::endl;
 
 
 IEEE1394Reader::IEEE1394Reader( int c, int bufSize ) :
+	currentFrame( NULL ),
 	channel( c ),
 	isRunning( false )
 {
@@ -206,6 +207,7 @@ void IEEE1394Reader::Flush()
 {
 	Frame * frame = NULL;
 
+	pthread_mutex_lock( &mutex );
 	for ( int i = outFrames.size(); i > 0; --i )
 	{
 		frame = outFrames[ 0 ];
@@ -217,6 +219,7 @@ void IEEE1394Reader::Flush()
 		inFrames.push_back( currentFrame );
 		currentFrame = NULL;
 	}
+	pthread_mutex_unlock( &mutex );
 }
 
 bool IEEE1394Reader::WaitForAction( )
@@ -313,14 +316,11 @@ void raw1394Reader::StopThread()
 {
 	if ( isRunning )
 	{
-		pthread_mutex_lock( &mutex );
 		isRunning = false;
 		pthread_join( thread, NULL );
-		pthread_mutex_unlock( &mutex );
 		StopReceive();
 		Close();
 		Flush();
-		TriggerAction( );
 	}
 }
 
@@ -342,16 +342,12 @@ bool raw1394Reader::Open()
 	try
 	{
 
-#ifdef LIBRAW1394_OLD
-		handle = raw1394_get_handle();
-#else
-
 		handle = raw1394_new_handle();
-#endif
-
 		if ( handle == 0 )
 			return false;
 		fail_neg( numcards = raw1394_get_port_info( handle, pinf, 16 ) );
+		if ( numcards == 0 )
+			return false;
 		fail_neg( raw1394_set_port( handle, port ) );
 
 		oldhandler = raw1394_set_iso_handler( handle, channel, HandlerProxy );
@@ -655,14 +651,13 @@ void dv1394Reader::StopThread()
 {
 	if ( isRunning )
 	{
-		pthread_mutex_lock( &mutex );
 		isRunning = false;
 		pthread_join( thread, NULL );
-		pthread_mutex_unlock( &mutex );
 		StopReceive();
 		Close();
 		Flush();
 	}
+	TriggerAction( );
 }
 
 
@@ -681,10 +676,7 @@ bool dv1394Reader::Open()
 
 	m_dv1394_fd = open( Preferences::getInstance().dvCaptureDevice, O_RDWR );
 	if ( m_dv1394_fd == -1 )
-	{
-		perror( "dv1394 open" );
 		return false;
-	}
 
 	if ( ioctl( m_dv1394_fd, DV1394_INIT, &init ) )
 	{
@@ -871,20 +863,20 @@ AVC::AVC( int p ) : port( p )
 	try
 	{
 
-#ifdef LIBRAW1394_OLD
-		avc_handle = raw1394_get_handle();
-#else
-
 		avc_handle = raw1394_new_handle();
-#endif
-
 		if ( avc_handle == 0 )
-			return ;
+			return;
 		fail_neg( numcards = raw1394_get_port_info( avc_handle, pinf, 16 ) );
-		fail_neg( raw1394_set_port( avc_handle, port ) );
-
-		raw1394_set_bus_reset_handler( avc_handle, this->ResetHandler );
-
+		if ( numcards == 0 )
+		{
+			raw1394_destroy_handle( avc_handle );
+			avc_handle = NULL;
+		}
+		else
+		{
+			fail_neg( raw1394_set_port( avc_handle, port ) );
+			raw1394_set_bus_reset_handler( avc_handle, this->ResetHandler );
+		}
 	}
 	catch ( string exc )
 	{
@@ -893,7 +885,7 @@ AVC::AVC( int p ) : port( p )
 		avc_handle = NULL;
 		cerr << exc << endl;
 	}
-	return ;
+	return;
 }
 
 
