@@ -22,11 +22,15 @@
 #endif
 
 #include <glade/glade.h>
+#include <string.h>
+#include <stdio.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
 #include "image_create.h"
 #include "page_magick.h"
 #include "message.h"
-#include <string.h>
-#include <stdio.h>
 
 extern "C"
 {
@@ -48,12 +52,18 @@ extern "C"
 class ImageCreateColour : public GDKAudioImport
 {
 protected:
-	static uint8_t start_r, start_g, start_b, start_a;
-	static int frames;
+	GdkColor start;
+	int frames;
 	GtkWidget *picker;
 	GtkWidget *frame_counter;
 
 public:
+	ImageCreateColour()
+	{
+		start.red = start.green = start.blue = 0;
+		frames = 25;
+	}
+
 	char *GetDescription( ) const
 	{
 		return _( "Fixed Colour" );
@@ -66,9 +76,9 @@ public:
 			uint8_t * p = pixels;
 			while ( p < ( pixels + width * height * 3 ) )
 			{
-				*p ++ = start_r;
-				*p ++ = start_g;
-				*p ++ = start_b;
+				*p ++ = start.red >> 8;
+				*p ++ = start.green >> 8;
+				*p ++ = start.blue >> 8;
 			}
 		}
 	}
@@ -80,7 +90,7 @@ public:
 
 	void AddFrameCollector( GtkWidget *table, int row )
 	{
-		GtkWidget * label = gtk_label_new( _( "Frames " ) );
+		GtkWidget * label = gtk_label_new( _( "Frames:" ) );
 		gtk_widget_show( label );
 
 		GtkObject *frame_counter_adj = gtk_adjustment_new( frames, 0, 999999, 1, 10, 10 );
@@ -88,8 +98,8 @@ public:
 		gtk_widget_show( frame_counter );
 		gtk_widget_set_usize( frame_counter, 60, -2 );
 
-		gtk_table_attach( GTK_TABLE( table ), label, 0, 1, row, row + 1, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
-		gtk_table_attach( GTK_TABLE( table ), frame_counter, 1, 2, row, row + 1, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+		gtk_table_attach( GTK_TABLE( table ), label, 0, 1, row, row + 1, ( GtkAttachOptions ) ( GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+		gtk_table_attach( GTK_TABLE( table ), frame_counter, 1, 2, row, row + 1, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 	}
 
 	void InterpretFrameCollector( )
@@ -101,18 +111,20 @@ public:
 	void AttachWidgets( GtkBin *bin )
 	{
 		GtkWidget * table = gtk_table_new ( 2, 2, FALSE );
+		gtk_table_set_row_spacings( GTK_TABLE( table ), 6 );
+		gtk_table_set_col_spacings( GTK_TABLE( table ), 6 );
 
-		GtkWidget *label = gtk_label_new( _( "Colour " ) );
+		GtkWidget *label = gtk_label_new( _( "Colour:" ) );
 		gtk_widget_show( label );
 
-		picker = gnome_color_picker_new();
-		gnome_color_picker_set_i8( GNOME_COLOR_PICKER( picker ), start_r, start_g, start_b, start_a );
+		picker = gtk_color_button_new();
+		gtk_color_button_set_color( GTK_COLOR_BUTTON( picker ), &start );
 		gtk_widget_show( picker );
 
 		AddFrameCollector( table, 0 );
 
 		gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 1, 2, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
-		gtk_table_attach( GTK_TABLE( table ), picker, 1, 2, 1, 2, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+		gtk_table_attach( GTK_TABLE( table ), picker, 1, 2, 1, 2, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 
 		gtk_widget_show( table );
 		gtk_container_add( GTK_CONTAINER( bin ), table );
@@ -123,7 +135,7 @@ public:
 		if ( bin->child != NULL )
 		{
 			InterpretFrameCollector( );
-			gnome_color_picker_get_i8( GNOME_COLOR_PICKER( picker ), &start_r, &start_g, &start_b, &start_a );
+			gtk_color_button_get_color( GTK_COLOR_BUTTON( picker ), &start );
 			gtk_container_remove( GTK_CONTAINER( bin ), bin->child );
 		}
 	}
@@ -131,7 +143,7 @@ public:
 	void InterpretWidgets( GtkBin *bin )
 	{
 		InterpretFrameCollector( );
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( picker ), &start_r, &start_g, &start_b, &start_a );
+		gtk_color_button_get_color( GTK_COLOR_BUTTON( picker ), &start );
 	}
 
 	void CreateAudio( int16_t **buffer, short int *channels, int *frequency, int *samples )
@@ -139,12 +151,6 @@ public:
 }
 ;
 
-uint8_t ImageCreateColour::start_r = 0;
-uint8_t ImageCreateColour::start_g = 0;
-uint8_t ImageCreateColour::start_b = 0;
-uint8_t ImageCreateColour::start_a = 0;
-int ImageCreateColour::frames = 25;
-
 /** Create noise.
 */
 
@@ -172,6 +178,8 @@ public:
 	void AttachWidgets( GtkBin *bin )
 	{
 		GtkWidget * table = gtk_table_new ( 2, 2, FALSE );
+		gtk_table_set_row_spacings( GTK_TABLE( table ), 6 );
+		gtk_table_set_col_spacings( GTK_TABLE( table ), 6 );
 		AddFrameCollector( table, 0 );
 		gtk_widget_show( table );
 		gtk_container_add( GTK_CONTAINER( bin ), table );
@@ -198,11 +206,16 @@ public:
 class ImageCreateColourRange : public ImageCreateColour
 {
 protected:
-	static uint8_t end_r, end_g, end_b, end_a;
+	GdkColor end;
 	GtkWidget *start_picker;
 	GtkWidget *end_picker;
 
 public:
+	ImageCreateColourRange()
+	{
+		end.red = end.green = end.blue = 0;
+	}
+
 	char *GetDescription( ) const
 	{
 		return _( "Colour Range" );
@@ -210,9 +223,9 @@ public:
 
 	void CreateFrame( uint8_t *pixels, int width, int height, double position, double frame_delta )
 	{
-		uint8_t r = start_r + ( uint8_t ) ( ( end_r - start_r ) * position );
-		uint8_t g = start_g + ( uint8_t ) ( ( end_g - start_g ) * position );
-		uint8_t b = start_b + ( uint8_t ) ( ( end_b - start_b ) * position );
+		uint8_t r = start.red + guint16( ( end.red - start.red ) * position ) >> 8 ;
+		uint8_t g = start.green + guint16( ( end.green - start.green ) * position ) >> 8;
+		uint8_t b = start.blue + guint16( ( end.blue - start.blue ) * position ) >> 8;
 		uint8_t *p = pixels;
 		while ( p < ( pixels + width * height * 3 ) )
 		{
@@ -225,27 +238,29 @@ public:
 	void AttachWidgets( GtkBin *bin )
 	{
 		GtkWidget * table = gtk_table_new( 2, 4, FALSE );
+		gtk_table_set_row_spacings( GTK_TABLE( table ), 6 );
+		gtk_table_set_col_spacings( GTK_TABLE( table ), 6 );
 
-		GtkWidget *start_label = gtk_label_new( _( "From " ) );
+		GtkWidget *start_label = gtk_label_new( _( "From:" ) );
 		gtk_widget_show( start_label );
 
-		start_picker = gnome_color_picker_new();
-		gnome_color_picker_set_i8( GNOME_COLOR_PICKER( start_picker ), start_r, start_g, start_b, start_a );
+		start_picker = gtk_color_button_new();
+		gtk_color_button_set_color( GTK_COLOR_BUTTON( start_picker ), &start );
 		gtk_widget_show( start_picker );
 
-		GtkWidget *end_label = gtk_label_new( _( " to " ) );
+		GtkWidget *end_label = gtk_label_new( _( "To:" ) );
 		gtk_widget_show( end_label );
 
-		end_picker = gnome_color_picker_new();
-		gnome_color_picker_set_i8( GNOME_COLOR_PICKER( end_picker ), end_r, end_g, end_b, end_a );
+		end_picker = gtk_color_button_new();
+		gtk_color_button_set_color( GTK_COLOR_BUTTON( end_picker ), &end );
 		gtk_widget_show( end_picker );
 
 		AddFrameCollector( table, 0 );
 
 		gtk_table_attach( GTK_TABLE( table ), start_label, 0, 1, 1, 2, ( GtkAttachOptions ) ( GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
-		gtk_table_attach( GTK_TABLE( table ), start_picker, 1, 2, 1, 2, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+		gtk_table_attach( GTK_TABLE( table ), start_picker, 1, 2, 1, 2, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 		gtk_table_attach( GTK_TABLE( table ), end_label, 2, 3, 1, 2, ( GtkAttachOptions ) ( GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
-		gtk_table_attach( GTK_TABLE( table ), end_picker, 3, 4, 1, 2, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+		gtk_table_attach( GTK_TABLE( table ), end_picker, 3, 4, 1, 2, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 
 		gtk_widget_show( table );
 		gtk_container_add( GTK_CONTAINER( bin ), table );
@@ -256,8 +271,8 @@ public:
 		if ( bin->child != NULL )
 		{
 			InterpretFrameCollector( );
-			gnome_color_picker_get_i8( GNOME_COLOR_PICKER( start_picker ), &start_r, &start_g, &start_b, &start_a );
-			gnome_color_picker_get_i8( GNOME_COLOR_PICKER( end_picker ), &end_r, &end_g, &end_b, &end_a );
+			gtk_color_button_get_color( GTK_COLOR_BUTTON( start_picker ), &start );
+			gtk_color_button_get_color( GTK_COLOR_BUTTON( end_picker ), &end );
 			gtk_container_remove( GTK_CONTAINER( bin ), bin->child );
 		}
 	}
@@ -265,16 +280,11 @@ public:
 	void InterpretWidgets( GtkBin *bin )
 	{
 		InterpretFrameCollector( );
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( start_picker ), &start_r, &start_g, &start_b, &start_a );
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( end_picker ), &end_r, &end_g, &end_b, &end_a );
+		gtk_color_button_get_color( GTK_COLOR_BUTTON( start_picker ), &start );
+		gtk_color_button_get_color( GTK_COLOR_BUTTON( end_picker ), &end );
 	}
 };
 
-uint8_t ImageCreateColourRange::end_r = 255;
-uint8_t ImageCreateColourRange::end_g = 255;
-uint8_t ImageCreateColourRange::end_b = 255;
-uint8_t ImageCreateColourRange::end_a = 0;
-
 /** Create a number of images that from gradiated colours.
 */
 
@@ -282,12 +292,7 @@ class ImageCreateGradiate : public GDKImageCreate
 {
 private:
 	GtkWidget *window;
-	uint8_t start_left_r, start_left_g, start_left_b, start_left_a;
-	uint8_t start_right_r, start_right_g, start_right_b, start_right_a;
-	uint8_t end_left_r, end_left_g, end_left_b, end_left_a;
-	uint8_t end_right_r, end_right_g, end_right_b, end_right_a;
-	uint8_t start_r, start_g, start_b, start_a;
-	uint8_t end_r, end_g, end_b, end_a;
+	GdkColor start_left, start_right, end_left, end_right, start, end;
 	int type;
 	int frames;
 
@@ -295,8 +300,10 @@ public:
 	ImageCreateGradiate()
 	{
 		window = glade_xml_get_widget( magick_glade, "image_create_gradiate" );
-		gnome_color_picker_set_i8( GNOME_COLOR_PICKER( lookup_widget( window, "colorpicker_start_right" ) ), 255, 255, 255, 0 );
-		gnome_color_picker_set_i8( GNOME_COLOR_PICKER( lookup_widget( window, "colorpicker_end_right" ) ), 255, 255, 255, 0 );
+		start_right.red = start_right.green = start_right.blue = 1 << 16;
+		gtk_color_button_set_color( GTK_COLOR_BUTTON( lookup_widget( window, "colorpicker_start_right" ) ), &start_right );
+		end_right.red = end_right.green = end_right.blue = 1 << 16;
+		gtk_color_button_set_color( GTK_COLOR_BUTTON( lookup_widget( window, "colorpicker_end_right" ) ), &end_right );
 	}
 
 	virtual ~ImageCreateGradiate()
@@ -311,9 +318,9 @@ public:
 
 	void LeftMiddle( uint8_t *pixels, int width, int height, double position )
 	{
-		double rr = ( double ) ( end_r - start_r ) / ( double ) ( width ) * 2;
-		double rg = ( double ) ( end_g - start_g ) / ( double ) ( width ) * 2;
-		double rb = ( double ) ( end_b - start_b ) / ( double ) ( width ) * 2;
+		double rr = ( double ) ( end.red - start.red ) / ( double ) ( width ) * 2;
+		double rg = ( double ) ( end.green - start.green ) / ( double ) ( width ) * 2;
+		double rb = ( double ) ( end.blue - start.blue ) / ( double ) ( width ) * 2;
 		uint8_t *p = pixels;
 		for ( int y = 0; y < height; y ++ )
 		{
@@ -321,16 +328,16 @@ public:
 			{
 				if ( x < width / 2 )
 				{
-					*p ++ = ( guint8 ) ( start_r + rr * x );
-					*p ++ = ( guint8 ) ( start_g + rg * x );
-					*p ++ = ( guint8 ) ( start_b + rb * x );
+					*p ++ = guint16( start.red + rr * x ) >> 8;
+					*p ++ = guint16( start.green + rg * x ) >> 8;
+					*p ++ = guint16( start.blue + rb * x ) >> 8;
 				}
 				else
 				{
 					int o = width / 2 - ( x - width / 2 );
-					*p ++ = ( guint8 ) ( start_r + rr * o );
-					*p ++ = ( guint8 ) ( start_g + rg * o );
-					*p ++ = ( guint8 ) ( start_b + rb * o );
+					*p ++ = guint16( start.red + rr * o ) >> 8;
+					*p ++ = guint16( start.green + rg * o ) >> 8;
+					*p ++ = guint16( start.blue + rb * o ) >> 8;
 				}
 			}
 		}
@@ -338,43 +345,43 @@ public:
 
 	void LeftRight( uint8_t *pixels, int width, int height, double position )
 	{
-		double rr = ( double ) ( end_r - start_r ) / ( double ) ( width );
-		double rg = ( double ) ( end_g - start_g ) / ( double ) ( width );
-		double rb = ( double ) ( end_b - start_b ) / ( double ) ( width );
+		double rr = ( double ) ( end.red - start.red ) / ( double ) ( width );
+		double rg = ( double ) ( end.green - start.green ) / ( double ) ( width );
+		double rb = ( double ) ( end.blue - start.blue ) / ( double ) ( width );
 		uint8_t *p = pixels;
 		for ( int y = 0; y < height; y ++ )
 		{
 			for ( int x = 0; x < width; x ++ )
 			{
-				*p ++ = ( guint8 ) ( start_r + rr * x );
-				*p ++ = ( guint8 ) ( start_g + rg * x );
-				*p ++ = ( guint8 ) ( start_b + rb * x );
+				*p ++ = guint16( start.red + rr * x ) >> 8;
+				*p ++ = guint16( start.green + rg * x ) >> 8;
+				*p ++ = guint16( start.blue + rb * x ) >> 8;
 			}
 		}
 	}
 
 	void TopBottom( uint8_t *pixels, int width, int height, double position )
 	{
-		double rr = ( double ) ( end_r - start_r ) / ( double ) ( height );
-		double rg = ( double ) ( end_g - start_g ) / ( double ) ( height );
-		double rb = ( double ) ( end_b - start_b ) / ( double ) ( height );
+		double rr = ( double ) ( end.red - start.red ) / ( double ) ( height );
+		double rg = ( double ) ( end.green - start.green ) / ( double ) ( height );
+		double rb = ( double ) ( end.blue - start.blue ) / ( double ) ( height );
 		uint8_t *p = pixels;
 		for ( int y = 0; y < height; y ++ )
 		{
 			for ( int x = 0; x < width; x ++ )
 			{
-				*p ++ = ( guint8 ) ( start_r + rr * y );
-				*p ++ = ( guint8 ) ( start_g + rg * y );
-				*p ++ = ( guint8 ) ( start_b + rb * y );
+				*p ++ = guint16( start.red + rr * y ) >> 8;
+				*p ++ = guint16( start.green + rg * y ) >> 8;
+				*p ++ = guint16( start.blue + rb * y ) >> 8;
 			}
 		}
 	}
 
 	void TopMiddle( uint8_t *pixels, int width, int height, double position )
 	{
-		double rr = ( double ) ( end_r - start_r ) / ( double ) ( height ) * 2;
-		double rg = ( double ) ( end_g - start_g ) / ( double ) ( height ) * 2;
-		double rb = ( double ) ( end_b - start_b ) / ( double ) ( height ) * 2;
+		double rr = ( double ) ( end.red - start.red ) / ( double ) ( height ) * 2;
+		double rg = ( double ) ( end.green - start.green ) / ( double ) ( height ) * 2;
+		double rb = ( double ) ( end.blue - start.blue ) / ( double ) ( height ) * 2;
 		uint8_t *p = pixels;
 		for ( int y = 0; y < height; y ++ )
 		{
@@ -382,16 +389,16 @@ public:
 			{
 				if ( y < height / 2 )
 				{
-					*p ++ = ( guint8 ) ( start_r + rr * y );
-					*p ++ = ( guint8 ) ( start_g + rg * y );
-					*p ++ = ( guint8 ) ( start_b + rb * y );
+					*p ++ = guint16( start.red + rr * y ) >> 8;
+					*p ++ = guint16( start.green + rg * y ) >> 8;
+					*p ++ = guint16( start.blue + rb * y ) >> 8;
 				}
 				else
 				{
 					int o = height / 2 - ( y - height / 2 );
-					*p ++ = ( guint8 ) ( start_r + rr * o );
-					*p ++ = ( guint8 ) ( start_g + rg * o );
-					*p ++ = ( guint8 ) ( start_b + rb * o );
+					*p ++ = guint16( start.red + rr * o ) >> 8;
+					*p ++ = guint16( start.green + rg * o ) >> 8;
+					*p ++ = guint16( start.blue + rb * o ) >> 8;
 				}
 			}
 		}
@@ -399,13 +406,13 @@ public:
 
 	void CreateFrame( uint8_t *pixels, int width, int height, double position, double frame_delta )
 	{
-		start_r = start_left_r + ( uint8_t ) ( ( end_left_r - start_left_r ) * position );
-		start_g = start_left_g + ( uint8_t ) ( ( end_left_g - start_left_g ) * position );
-		start_b = start_left_b + ( uint8_t ) ( ( end_left_b - start_left_b ) * position );
+		start.red = start_left.red + guint16( ( end_left.red - start_left.red ) * position );
+		start.green = start_left.green + guint16( ( end_left.green - start_left.green ) * position );
+		start.blue = start_left.blue + guint16( ( end_left.blue - start_left.blue ) * position );
 
-		end_r = start_right_r + ( uint8_t ) ( ( end_right_r - start_right_r ) * position );
-		end_g = start_right_g + ( uint8_t ) ( ( end_right_g - start_right_g ) * position );
-		end_b = start_right_b + ( uint8_t ) ( ( end_right_b - start_right_b ) * position );
+		end.red = start_right.red + guint16( ( end_right.red - start_right.red ) * position );
+		end.green = start_right.green + guint16( ( end_right.green - start_right.green ) * position );
+		end.blue = start_right.blue + guint16( ( end_right.blue - start_right.blue ) * position );
 
 		if ( type == 0 )
 			LeftMiddle( pixels, width, height, position );
@@ -436,14 +443,14 @@ public:
 		GtkEntry *entry = GTK_ENTRY( lookup_widget( window, "spinbutton_frames" ) );
 		frames = atoi( gtk_entry_get_text( entry ) );
 
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( lookup_widget( window, "colorpicker_start_left" ) ),
-		                           &start_left_r, &start_left_g, &start_left_b, &start_left_a );
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( lookup_widget( window, "colorpicker_start_right" ) ),
-		                           &start_right_r, &start_right_g, &start_right_b, &start_right_a );
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( lookup_widget( window, "colorpicker_end_left" ) ),
-		                           &end_left_r, &end_left_g, &end_left_b, &end_left_a );
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( lookup_widget( window, "colorpicker_end_right" ) ),
-		                           &end_right_r, &end_right_g, &end_right_b, &end_right_a );
+		gtk_color_button_get_color( GTK_COLOR_BUTTON( lookup_widget( window, "colorpicker_start_left" ) ),
+		                           &start_left );
+		gtk_color_button_get_color( GTK_COLOR_BUTTON( lookup_widget( window, "colorpicker_start_right" ) ),
+		                           &start_right );
+		gtk_color_button_get_color( GTK_COLOR_BUTTON( lookup_widget( window, "colorpicker_end_left" ) ),
+		                           &end_left );
+		gtk_color_button_get_color( GTK_COLOR_BUTTON( lookup_widget( window, "colorpicker_end_right" ) ),
+		                           &end_right );
 	}
 
 	int GetNumberOfFrames( )
@@ -510,31 +517,66 @@ public:
 		else if ( still != NULL )
 		{
 			GdkPixbuf *image = gdk_pixbuf_scale_simple( still, width, height, GDK_INTERP_HYPER );
-			memcpy( pixels, gdk_pixbuf_get_pixels( image ), width * height * 3 );
+			if ( gdk_pixbuf_get_has_alpha( image ) ) {
+			// This is a hack! The correct calls would be:
+			// gdk_pixbuf_new/gdk_pixbuf_copy_area
+				uint8_t *jp = gdk_pixbuf_get_pixels( image ), *jz = pixels;
+				for ( int i = 0; i < width * height; i++ ) {
+					memcpy( jz, jp, 3 );
+					jp += 4; jz += 3;
+				}
+			}
+			else
+				memcpy( pixels, gdk_pixbuf_get_pixels( image ), width * height * 3 );
 			g_object_unref( still );
 			g_object_unref( image );
 		}
 	}
 
+	static void
+	on_button_file_clicked( GtkButton *button, gpointer user_data )
+	{
+		char *filename = common->getFileToOpen( _("Select an Image"), false );
+		if ( filename && strcmp( filename, "" ) )
+		{
+			ImageCreateFromFile *me = static_cast< ImageCreateFromFile* >( user_data );
+			gtk_entry_set_text( me->getEntry(), filename );
+		}
+	}
+	
 	void AttachWidgets( GtkBin *bin )
 	{
 		GtkWidget * table = gtk_table_new ( 2, 2, FALSE );
+		gtk_table_set_row_spacings( GTK_TABLE( table ), 6 );
+		gtk_table_set_col_spacings( GTK_TABLE( table ), 6 );
 
-		GtkWidget *label = gtk_label_new( _( "File " ) );
+		GtkWidget *label = gtk_label_new( _( "File:" ) );
 		gtk_widget_show( label );
 
-		file_entry = gnome_file_entry_new( NULL, _( "Select an Image" ) );
-		gtk_entry_set_text( GTK_ENTRY( gnome_file_entry_gtk_entry( GNOME_FILE_ENTRY( file_entry ) ) ), file );
+		GtkWidget *hbox = gtk_hbox_new( FALSE, 6 );
+		file_entry = gtk_entry_new();
+		gtk_entry_set_text( GTK_ENTRY( file_entry ), file );
+		gtk_box_pack_start( GTK_BOX( hbox ), file_entry, TRUE, TRUE, 0 );
+		GtkWidget *button = gtk_button_new();
+		GtkWidget *image = gtk_image_new_from_stock( GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON );
+		gtk_container_add( GTK_CONTAINER( button ), image );
+		gtk_button_set_relief( GTK_BUTTON( button ), GTK_RELIEF_NONE );
+		g_signal_connect( G_OBJECT( button ), "clicked", G_CALLBACK( on_button_file_clicked ), this );
+
+		gtk_box_pack_start( GTK_BOX( hbox ), button, FALSE, TRUE, 0 );
+		gtk_widget_show( hbox );
 		gtk_widget_show( file_entry );
+		gtk_widget_show( button );
+		gtk_widget_show( image );
 
 		AddFrameCollector( table, 0 );
 		gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 1, 2, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
-		gtk_table_attach( GTK_TABLE( table ), file_entry, 1, 2, 1, 2, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+		gtk_table_attach( GTK_TABLE( table ), hbox, 1, 2, 1, 2, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL | GTK_SHRINK ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 
-		GtkWidget *tip_label = gtk_label_new( _( "TIP: use a format specifier in the file name to import from an image sequence. For example: gap-%06d.png." ) );
-		gtk_label_set_line_wrap( GTK_LABEL( tip_label ), TRUE );
+		GtkWidget *tip_label = gtk_label_new( _( "TIP: use a format specifier in the file name\nto import from an image sequence.\nFor example: gap-%06d.png." ) );
+		gtk_label_set_line_wrap( GTK_LABEL( tip_label ), FALSE );
 		gtk_widget_show( tip_label );
-		gtk_table_attach( GTK_TABLE( table ), tip_label, 0, 2, 2, 3, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+		gtk_table_attach( GTK_TABLE( table ), tip_label, 0, 2, 2, 3, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL | GTK_SHRINK ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 
 		gtk_widget_show( table );
 		gtk_container_add( GTK_CONTAINER( bin ), table );
@@ -548,8 +590,7 @@ public:
 			// of InterpretWidgets ... since Interpret may throw exceptions, it can't be called directly
 			// here...)
 			InterpretFrameCollector( );
-			GtkEntry *entry = GTK_ENTRY( gnome_file_entry_gtk_entry( GNOME_FILE_ENTRY( file_entry ) ) );
-			strcpy( file, gtk_entry_get_text( entry ) );
+			strcpy( file, gtk_entry_get_text( GTK_ENTRY( file_entry ) ) );
 			gtk_container_remove( GTK_CONTAINER( bin ), bin->child );
 		}
 	}
@@ -557,13 +598,17 @@ public:
 	void InterpretWidgets( GtkBin *bin )
 	{
 		InterpretFrameCollector( );
-		GtkEntry *entry = GTK_ENTRY( gnome_file_entry_gtk_entry( GNOME_FILE_ENTRY( file_entry ) ) );
-		strcpy( file, gtk_entry_get_text( entry ) );
+		strcpy( file, gtk_entry_get_text( GTK_ENTRY( file_entry ) ) );
 
 		if ( !strcmp( file, "" ) )
 			throw _( "No image file name specified - aborting." );
 		count = 0;
 	}
+
+	GtkEntry *getEntry() const
+	{
+		return GTK_ENTRY( file_entry );
+	}
 };
 
 char ImageCreateFromFile::file[ PATH_MAX + NAME_MAX ] = "";
