@@ -258,7 +258,7 @@ private:
 	GtkWidget *window;
 	int type;
 	int sensitivity;
-	uint8_t replace_r, replace_g, replace_b, replace_a;
+	GdkColor color;
 
 public:
 	ImageTransitionDifferences()
@@ -298,9 +298,9 @@ public:
 
 				if ( ( !differs && type == 0 ) || ( differs && type == 1 ) )
 				{
-					*p ++ = replace_r;
-					*p ++ = replace_g;
-					*p ++ = replace_b;
+					*p ++ = color.red >> 8;
+					*p ++ = color.green >> 8;
+					*p ++ = color.blue >> 8;
 				}
 				else
 				{
@@ -324,11 +324,12 @@ public:
 
 	void InterpretWidgets( GtkBin *bin )
 	{
-		GtkMenu * menu = GTK_MENU( gtk_option_menu_get_menu( GTK_OPTION_MENU( lookup_widget( window, "optionmenu_action" ) ) ) );
+		GtkMenu *menu = GTK_MENU( gtk_option_menu_get_menu( GTK_OPTION_MENU( lookup_widget( window, "optionmenu_action" ) ) ) );
 		GtkWidget *active_item = gtk_menu_get_active( menu );
 		type = g_list_index ( GTK_MENU_SHELL ( menu ) ->children, active_item );
 
-		gnome_color_picker_get_i8( GNOME_COLOR_PICKER( lookup_widget( window, "colorpicker" ) ), &replace_r, &replace_g, &replace_b, &replace_a );
+		GtkColorButton *colorButton = GTK_COLOR_BUTTON( lookup_widget( window, "colorpicker" ) );
+		gtk_color_button_get_color( colorButton, &color );
 
 		GtkRange *range = GTK_RANGE( lookup_widget( window, "hscale_sensitivity" ) );
 		GtkAdjustment *adjust = gtk_range_get_adjustment( range );
