@@ -29,10 +29,12 @@ using std::endl;
 #include <string>
 
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <dirent.h>
 #include <libgen.h>
 #include <string.h>
 #include <stdarg.h>
+#include <time.h>
 #include <libxml/nanohttp.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
@@ -538,6 +540,96 @@ PageMagick *KinoCommon::getPageMagick( )
 	return magickPage;
 }
 
+/** Give option to import a file by transcoding to DV.
+*/
+
+std::string KinoCommon::importFile( const char *filename )
+{
+	std::string importedFile( filename );
+
+	if ( modal_confirm( GTK_STOCK_OK, NULL, 
+		_("This is not a DV file. Do you want to import it?") )
+		== GTK_RESPONSE_ACCEPT )
+	{
+		char * args[ 7 ];
+		int pid, status = -1;
+		GError *gerror = NULL;
+		gfloat val = 0.0;
+		gboolean visible = TRUE;
+		GtkWidget *dialog = lookup_widget( widget, "import_window" );
+		GtkProgressBar *progressBar = GTK_PROGRESS_BAR( lookup_widget( widget, "progressbar_import" ) );
+
+		gtk_progress_bar_update( progressBar, val );
+		gtk_widget_show_all( dialog );
+
+		// Check if media is loaded
+		if ( g_currentFrame == -1 )
+		{
+			// Use Preferences/Defaults
+			if ( Preferences::getInstance().defaultNormalisation == NORM_UNSPECIFIED )
+			{
+				modal_message( _( "The playlist is empty and the default preferences for video creation have not been specified - aborting." ) );
+				return importedFile;
+			}
+			args[ 3 ] = const_cast<char*>(
+				Preferences::getInstance().defaultNormalisation == NORM_PAL ? "pal" : "ntsc" );
+			args[ 4 ] = const_cast<char*>(
+				Preferences::getInstance().defaultAspect == ASPECT_169 ? "16:9" : "4:3" );
+			switch ( Preferences::getInstance().defaultAudio )
+			{
+				case AUDIO_32KHZ:
+					args[ 5 ] = "32000";
+					break;
+				case AUDIO_44KHZ:
+					args[ 5 ] = "44100";
+					break;
+				case AUDIO_48KHZ:
+					args[ 5 ] = "48000";
+					break;
+			}
+		}
+		else
+		{
+			// Use first frame
+			Frame& frame = *GetFramePool()->GetFrame();
+			AudioInfo ainfo;
+			std::ostringstream strstream;
+
+			this->getPlayList() ->GetFrame( 0, frame );
+			frame.GetAudioInfo( ainfo );
+			strstream << ainfo.frequency;
+			args[ 3 ] = const_cast<char*>( frame.IsPAL() ? "pal" : "ntsc" );
+			args[ 4 ] = const_cast<char*>( frame.IsWide() ? "16:9" : "4:3" );
+			args[ 5 ] = const_cast<char*>( strstream.str().c_str() );
+			GetFramePool()->DoneWithFrame( &frame );
+		}
+		importedFile += ".dv";
+		args[ 0 ] = DATADIR "/kino/scripts/import/media.sh";
+		args[ 1 ] = const_cast<char*>( filename );
+		args[ 2 ] = const_cast<char*>( importedFile.c_str() );
+		args[ 6 ] = NULL;
+		g_spawn_async_with_pipes( ".", args, NULL, G_SPAWN_DO_NOT_REAP_CHILD,
+			NULL, NULL, &pid, NULL, NULL, NULL, &gerror );
+		
+		// Check for cancellation or child exit
+ 		while ( ! WIFEXITED( status ) && visible )
+		{
+ 			timespec ts = { 0, 100000000L };
+			while ( gtk_events_pending() )
+				gtk_main_iteration();
+			nanosleep( &ts, NULL );
+			gtk_progress_bar_update( progressBar, val > 1.0 ? 1.0 : val );
+			// We do not know how long it will take, just show something is
+			// happening by incrementing progress
+			val = ( val >= 1.0 ) ? 0.0 : ( val + 0.001 );
+ 			g_object_get( G_OBJECT( dialog ), "visible", &visible, NULL );
+			waitpid( pid, &status, WNOHANG );
+		}
+		gtk_widget_hide( dialog );
+	}
+	return importedFile;
+}
+
 /** Inserts a file at the current position.
 */
 
@@ -556,8 +648,23 @@ void KinoCommon::insertFile( )
 			{
 				hasListChanged = TRUE;
 				getPlayList() ->SetDirty( true );
+				break;
+			}
+			// Else, ask to import
+		case UNKNOWN_FORMAT:
+		{
+			const std::string& importedFile = importFile( filename );
+			if ( loadMediaObject( const_cast<char*>( importedFile.c_str() ), g_currentFrame == -1 ? 0 : g_currentFrame ) )
+			{
+				hasListChanged = TRUE;
+				getPlayList() ->SetDirty( true );
+			}
+			else
+			{
+				modal_message( _( "Failed to load media file." ) );
 			}
 			break;
+		}
 		case PLAYLIST:
 			if ( loadPlayList( filename, g_currentFrame ) )
 			{
@@ -566,9 +673,6 @@ void KinoCommon::insertFile( )
 				getPageEditor() ->snapshot();
 			}
 			break;
-		case UNKNOWN_FORMAT:
-			modal_message( _( "Invalid file specified." ) );
-			break;
 		}
 	}
 
@@ -595,8 +699,25 @@ void KinoCommon::appendFile( )
 				g_currentFrame++;
 				hasListChanged = TRUE;
 				getPlayList() ->SetDirty( true );
+				break;
+			}
+			// Else, ask to import
+		case UNKNOWN_FORMAT:
+		{
+			const std::string& importedFile = importFile( filename );
+			if ( loadMediaObject( const_cast<char*>( importedFile.c_str() ), g_currentFrame + 1 ) )
+			{
+				g_currentFrame++;
+				hasListChanged = TRUE;
+				getPlayList() ->SetDirty( true );
+				break;
+			}
+			else
+			{
+				modal_message( _( "Failed to load media file." ) );
 			}
 			break;
+		}
 		case PLAYLIST:
 			// Insert the new smil
 			if ( loadPlayList( filename, g_currentFrame + 1 ) )
@@ -607,9 +728,6 @@ void KinoCommon::appendFile( )
 				getPageEditor() ->snapshot();
 			}
 			break;
-		case UNKNOWN_FORMAT:
-			modal_message( _( "Invalid file specified." ) );
-			break;
 		}
 	}
 
@@ -625,6 +743,7 @@ void KinoCommon::loadFile( )
 {
 	changePageRequest( PAGE_EDITOR );
 	char * filename = this->getFileToOpen( _( "Choose a DV or SMIL file" ) );
+	bool askNewFile = true;
 
 	if ( filename && strcmp( filename, "" ) )
 	{
@@ -633,6 +752,7 @@ void KinoCommon::loadFile( )
 		case AVI:
 		case RAW_DV:
 		case QT:
+			askNewFile = false;
 			if ( newFile( ) )
 			{
 				GetEditorBackup() ->Clear();
@@ -640,6 +760,23 @@ void KinoCommon::loadFile( )
 				{
 					g_currentFrame = 0;
 					hasListChanged = TRUE;
+					break;
+				}
+				// Else, ask to import
+			}
+		case UNKNOWN_FORMAT:
+			if ( ( askNewFile && newFile( ) ) || ! askNewFile )
+			{
+				const std::string& importedFile = importFile( filename );
+				GetEditorBackup() ->Clear();
+				if ( loadMediaObject( const_cast<char*>( importedFile.c_str() ), 0 ) )
+				{
+					g_currentFrame = 0;
+					hasListChanged = TRUE;
+				}
+				else
+				{
+					modal_message( _( "Failed to load media file." ) );
 				}
 			}
 			break;
@@ -658,9 +795,6 @@ void KinoCommon::loadFile( )
 				}
 			}
 			break;
-		case UNKNOWN_FORMAT:
-			modal_message( _( "Invalid file specified." ) );
-			break;
 		}
 	}
 	setWindowTitle();
@@ -785,13 +919,16 @@ gboolean generate_file_preview( GtkWidget *preview, const char *filename )
 			// causing nothing to show
 			Frame& frame = *GetFramePool()->GetFrame();
 			int frameNum = mediaFile->GetTotalFrames() < 61 ? ( mediaFile->GetTotalFrames() / 2 ) : 60;
-			unsigned char *pixels = (unsigned char*)malloc( 720*576*4 );
+			unsigned char *pixels = new unsigned char[ FRAME_MAX_WIDTH * FRAME_MAX_HEIGHT * 4 ];
+
 			mediaFile->GetFrame( frame, frameNum );
-			GdkDisplayer display( preview, frame.GetWidth(), frame.GetHeight(), frame.IsWide() );
+			GdkDisplayer* display = new GdkDisplayer( preview, frame.GetWidth(), frame.GetHeight(), frame.IsWide() );
 			frame.ExtractPreviewRGB( pixels );
-			display.put( pixels );
-			free( pixels );
+			display->put( pixels );
+
 			GetFramePool()->DoneWithFrame( &frame );
+			delete display;
+			delete[] pixels;
 			delete mediaFile;
 			return true;
 		}
@@ -833,7 +970,7 @@ void update_preview_cb (GtkFileChooser *file_chooser, gpointer data)
 	\return a string inidicating the selected file (an empty string denotes no selection)
 */
 
-char *KinoCommon::getFileToOpen( char *title )
+char *KinoCommon::getFileToOpen( char *title, bool isDVFile )
 {
 	GtkWidget *dialog;
 	GtkDrawingArea *preview;
@@ -845,53 +982,55 @@ char *KinoCommon::getFileToOpen( char *title )
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 				NULL );
+	if ( isDVFile )
+	{
+		preview = ( GtkDrawingArea* )gtk_drawing_area_new();
+		gtk_widget_set_size_request( GTK_WIDGET(preview), 160, 120 );
+		gtk_file_chooser_set_preview_widget( GTK_FILE_CHOOSER(dialog),
+					GTK_WIDGET(preview) );
+		g_signal_connect( dialog, "update-preview",
+					G_CALLBACK(update_preview_cb), preview );
+	
+		filter = gtk_file_filter_new();
+		gtk_file_filter_set_name( filter, "All Files" );
+		gtk_file_filter_add_pattern( filter, "*" );
+		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+	
+		filter = gtk_file_filter_new();
+		gtk_file_filter_set_name( filter, "SMIL Files (*.smil)" );
+		gtk_file_filter_add_pattern( filter, "*.smil" );
+		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+	
+		filter = gtk_file_filter_new();
+		gtk_file_filter_set_name( filter, "Digital Video Files (*.dv, *.dif)" );
+		gtk_file_filter_add_pattern( filter, "*.dv" );
+		gtk_file_filter_add_pattern( filter, "*.dif" );
+		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+	
+		filter = gtk_file_filter_new();
+		gtk_file_filter_set_name( filter, "AVI Files (*.avi)" );
+		gtk_file_filter_add_pattern( filter, "*.avi" );
+		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
 	
-	preview = ( GtkDrawingArea* )gtk_drawing_area_new();
-	gtk_widget_set_size_request( GTK_WIDGET(preview), 160, 120 );
-	gtk_file_chooser_set_preview_widget( GTK_FILE_CHOOSER(dialog),
-				GTK_WIDGET(preview) );
-	g_signal_connect( dialog, "update-preview",
-				G_CALLBACK(update_preview_cb), preview );
-
-	filter = gtk_file_filter_new();
-	gtk_file_filter_set_name( filter, "All Files" );
-	gtk_file_filter_add_pattern( filter, "*" );
-	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
-
-	filter = gtk_file_filter_new();
-	gtk_file_filter_set_name( filter, "SMIL Files (*.smil)" );
-	gtk_file_filter_add_pattern( filter, "*.smil" );
-	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
-
-	filter = gtk_file_filter_new();
-	gtk_file_filter_set_name( filter, "Digital Video Files (*.dv, *.dif)" );
-	gtk_file_filter_add_pattern( filter, "*.dv" );
-	gtk_file_filter_add_pattern( filter, "*.dif" );
-	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
-
-	filter = gtk_file_filter_new();
-	gtk_file_filter_set_name( filter, "AVI Files (*.avi)" );
-	gtk_file_filter_add_pattern( filter, "*.avi" );
-	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
-
 #ifdef HAVE_LIBQUICKTIME
-	filter = gtk_file_filter_new();
-	gtk_file_filter_set_name( filter, "Quicktime Files (*.mov)" );
-	gtk_file_filter_add_pattern( filter, "*.mov" );
-	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+		filter = gtk_file_filter_new();
+		gtk_file_filter_set_name( filter, "Quicktime Files (*.mov)" );
+		gtk_file_filter_add_pattern( filter, "*.mov" );
+		gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
 #endif
-
+	}
+	
 	gtk_window_set_modal( GTK_WINDOW( dialog ), TRUE );
 	if ( last_directory == "" )
 	{
 		string directory = getPlayList() ->GetProjectDirectory( );
 		if ( directory != "" )
-			gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( directory + "/." ).c_str() );
+			gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER( dialog ), ( char * ) ( directory + "/." ).c_str() );
 		last_directory = directory;
 	}
 	else
 	{
-		gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( last_directory + "/." ).c_str() );
+		gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER( dialog ), ( char * ) ( last_directory + "/." ).c_str() );
 	}
 	if (gtk_dialog_run( GTK_DIALOG( dialog ) ) == GTK_RESPONSE_ACCEPT) {
 		const gchar *filename = gtk_file_chooser_get_filename(
@@ -925,12 +1064,12 @@ char *KinoCommon::getFileToSave( char *title )
 	{
 		string directory = getPlayList() ->GetProjectDirectory( );
 		if ( directory != "" )
-			gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( directory + "/." ).c_str() );
+			gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER( dialog ), ( char * ) ( directory + "/." ).c_str() );
 		last_directory = directory;
 	}
 	else
 	{
-		gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( last_directory + "/." ).c_str() );
+		gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER( dialog ), ( char * ) ( last_directory + "/." ).c_str() );
 	}
 	if (gtk_dialog_run (GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
 		char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
@@ -950,7 +1089,7 @@ char *KinoCommon::getFileToSave( char *title )
 
 #else /* HAVE_GTK24 */
 
-char *KinoCommon::getFileToOpen( char *title )
+char *KinoCommon::getFileToOpen( char *title, bool isDVFile )
 {
 	GtkWidget *dialog = gtk_file_selection_new( title );
 	gtk_window_set_modal( GTK_WINDOW( dialog ), TRUE );
@@ -1101,7 +1240,6 @@ bool KinoCommon::loadMediaObject( char *file, int before )
 		}
 		else
 		{
-			modal_message( _( "Failed to load media file." ) );
 			result = false;
 		}
 	}
@@ -1424,7 +1562,7 @@ void KinoCommon::showFrameMoreInfo( Frame &frame, FileHandler *media )
 {
 	if ( showMoreInfo )
 	{
-		GtkLabel *label = GTK_LABEL( lookup_widget( widget, "label_more_info" ) );
+		GtkLabel *label = GTK_LABEL( lookup_widget( widget, "label_properties" ) );
 		char s[ 2048 ];
 
 		if ( media != NULL )
@@ -1864,13 +2002,14 @@ void KinoCommon::setPreviewSize( float factor, bool noWarning )
 	// handle the cycle case
 	if ( factor < 0 )
 	{
-		factor = Preferences::getInstance().previewSize;
+		factor = float( Preferences::getInstance().previewSize ) / 10.0;
 		factor += 0.5;
 		if ( factor > 1.0 )
 			factor = 0.0;
 	}
+		
 	// save the new size
-	Preferences::getInstance().previewSize = factor;
+	Preferences::getInstance().previewSize = int( factor * 10 );
 
 	// handle fixed size factors
 	if ( Preferences::getInstance().displayFixed != ( factor > 0 ) )
@@ -1954,65 +2093,35 @@ void KinoCommon::setPreviewSize( float factor, bool noWarning )
 	}
 }
 
-void KinoCommon::loadSplash( GtkWidget *drawable )
-{
-	if ( widget->window && GDK_IS_DRAWABLE( widget->window ) )
-	{
-		gdk_draw_rectangle ( widget->window, widget->style->black_gc, TRUE,
-		                     widget->allocation.x, widget->allocation.y,
-		                     widget->allocation.width, widget->allocation.height );
-	}
-}
-
 /** Load the splash image into the video preview area.
  
     \param widget the GtkDrawingArea into which to render the image.
 */
 void KinoCommon::loadSplash( GtkDrawingArea *drawable )
 {
-#if 1
-	clearPreview( drawable );
-#elif 0
-
-	unsigned char *background;
-	int width = ( ( GtkWidget* ) drawable ) ->allocation.width;
-	int height = ( ( GtkWidget* ) drawable ) ->allocation.height;
-	static bool warnOnce = true;
-	GdkGC *gc = gdk_gc_new( ( ( GtkWidget* ) drawable ) ->window );
-
-	background = ( unsigned char * ) malloc( width * height * 3 );
-	fail_null( background );
-	memset( background, 0, width * height * 3 );
-	GdkPixbuf *bgImage = gdk_pixbuf_new_from_data( background, GDK_COLORSPACE_RGB, FALSE, 8,
-						 width, height, width * 3, NULL, NULL );
-	fail_null( bgImage );
-	GdkPixbuf *splash = create_pixbuf( "kino/about.jpeg" );
-	if ( splash != NULL )
+	if ( drawable && ( ( GtkWidget* ) drawable )->window )
 	{
-		AspectRatioCalculator calc( width, height, gdk_pixbuf_get_width( splash ),
-									gdk_pixbuf_get_height( splash ), gdk_pixbuf_get_width( splash ),
-									gdk_pixbuf_get_height( splash ) );
-		GdkPixbuf *image = gdk_pixbuf_scale_simple( splash, calc.width, calc.height, GDK_INTERP_BILINEAR );
-		fail_null( image );
-
-		gdk_pixbuf_composite( image, bgImage, calc.x, calc.y, calc.width, calc.height,
-							  0, 0, 1.0, 1.0, GDK_INTERP_NEAREST, 255 );
-		gdk_draw_pixbuf( ( ( GtkWidget * ) drawable ) ->window, gc, bgImage,
-						 0, 0, 0, 0, -1, -1, GDK_RGB_DITHER_NORMAL, 0, 0 );
-
-		g_object_unref( splash );
-		g_object_unref( image );
+		GdkGC *gc = gdk_gc_new( ( ( GtkWidget* ) drawable ) ->window );
+		if ( gc )
+		{
+			GdkPixbuf *splash = create_pixbuf( "about.jpeg" );
+		
+			if ( splash )
+			{
+				int width = ( ( GtkWidget* ) drawable ) ->allocation.width;
+				int height = ( ( GtkWidget* ) drawable ) ->allocation.height;
+				GdkPixbuf *image = gdk_pixbuf_scale_simple( splash, width, height, GDK_INTERP_BILINEAR );
+				if ( image )
+				{
+					gdk_draw_pixbuf( ( ( GtkWidget * ) drawable ) ->window, gc, image,
+									0, 0, 0, 0, -1, -1, GDK_RGB_DITHER_NORMAL, 0, 0 );
+					g_object_unref( image );
+				}
+				g_object_unref( splash );
+			}
+			g_object_unref( gc );
+		}
 	}
-	else if ( warnOnce )
-	{
-		warnOnce = false;
-		modal_message( _( "Support pixmaps not found.\nPlease completely install Kino." ) );
-	}
-
-	g_object_unref( bgImage );
-	g_object_unref( gc );
-	free( background );
-#endif
 }
 
 
