@@ -20,11 +20,13 @@
 #ifndef _KINO_COMMON_H
 #define _KINO_COMMON_H
 
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include <gdk/gdkkeysyms.h>
 #include <limits.h>
 #include <stdlib.h>
-
-#include <gnome.h>
 #include <stdint.h>
+
 #include "playlist.h"
 #include "frame.h"
 #include "preferences.h"
@@ -177,6 +179,7 @@ public:
 
 	// File Load and Save dialogs
 	void bulkLoad( int, char *[] );
+	std::string importFile( const char *filename );
 	void insertFile( );
 	void appendFile( );
 	void loadFile( );
@@ -243,12 +246,11 @@ public:
 	void commitComponentState( component_enum = ( component_enum ) 0 );
 
 	// File Dialogs
-	char *getFileToOpen( char * );
+	char *getFileToOpen( char *, bool isDVFile = true );
 	char *getFileToSave( char * );
 
 	// misc
 	void setPreviewSize( float factor, bool noWarning = false );
-	void loadSplash( GtkWidget * );
 	void loadSplash( GtkDrawingArea * );
 	void clearPreview( GtkDrawingArea * );
 	void setWindowTitle( );
