@@ -23,7 +23,7 @@
 
 #include <iostream>
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <math.h>
 #include <limits.h>
 #include <unistd.h>
@@ -144,7 +144,7 @@ void PageCapture::start()
 	validComponents = 0;
 	gui_state_was = -1;
 
-	gtk_toggle_button_set_active( avcButton, false );
+	gtk_toggle_button_set_active( avcButton, Preferences::getInstance().enableAVC );
 	GtkLabel *label = GTK_LABEL( lookup_widget( common->getWidget(), "position_label_total" ) );
 	gtk_label_set_text( label, "" );
 
@@ -183,6 +183,7 @@ void PageCapture::start()
 	displayer = new FrameDisplayer;
 
 	// Set up the preview rendering
+	g_nav_ctl.capture_active = TRUE;
 	pthread_create( &capturethread, NULL, captureThread, this );
 	pthread_create( &avcthread, NULL, avcThread, this );
 	pthread_create( &videothread, NULL, videoThread, lookup_widget( common->getWidget(), "capture_drawingarea" ) );
@@ -270,6 +271,8 @@ void PageCapture::CheckDevices( )
 	}
 	else
 	{
+		avc_enabled = Preferences::getInstance().enableAVC;
+		gtk_toggle_button_set_active( this->avcButton, avc_enabled );
 		avc->Noop();
 	}
 }
@@ -282,7 +285,6 @@ void PageCapture::applyAVCState( quadlet_t newAVCState )
 	{
 		if ( gui_state_was != 0 )
 		{
-			gtk_toggle_button_set_active( avcButton, FALSE );
 			gtk_widget_set_sensitive( GTK_WIDGET( avcButton ), false );
 			gtk_widget_set_sensitive( GTK_WIDGET( recordButton ), false );
 			gtk_widget_set_sensitive( GTK_WIDGET( stopButton ), false );
@@ -299,7 +301,6 @@ void PageCapture::applyAVCState( quadlet_t newAVCState )
 	{
 		if ( gui_state_was != 1 )
 		{
-			gtk_toggle_button_set_active( avcButton, FALSE );
 			gtk_widget_set_sensitive( GTK_WIDGET( avcButton ), false );
 			gtk_widget_set_sensitive( GTK_WIDGET( recordButton ), true );
 			gtk_widget_set_sensitive( GTK_WIDGET( stopButton ), true );
@@ -457,28 +458,27 @@ void PageCapture::clean()
 	
 	if ( g_nav_ctl.capture_active == TRUE )
 	{
-
 		// Stop the capture
 		stopCapture();
 
 		// Stop the video
-		if ( Preferences::getInstance( ).phyID >= 0 )
+		if ( avc_enabled && Preferences::getInstance( ).phyID >= 0 )
 			videoStop();
 
 		// Start the deactivation process for the backround processes
 		g_nav_ctl.active = FALSE;
 		g_nav_ctl.capture_active = FALSE;
-		reader->TriggerAction( );
+
+		// Join with the capture thread to make sure we're definitely finished
+		reader->TriggerAction();
+		pthread_join( capturethread, NULL );
+		pthread_join( avcthread, NULL );
 
 		// Stop the video thread
 		gdk_threads_leave();
 		pthread_join( videothread, NULL );
 		gdk_threads_enter();
 
-		// Join with the capture thread to make sure we're definitely finished
-		pthread_join( capturethread, NULL );
-		pthread_join( avcthread, NULL );
-
 		// Stop the reading thread
 		reader->StopThread();
 	}
@@ -1293,7 +1293,7 @@ void PageCapture::stopCapture()
 		if ( common->g_currentFrame == -1 )
 			common->g_currentFrame = 0;
 	}
-
+	
 }
 
 
@@ -1471,8 +1471,6 @@ extern "C"
 	{
 		Frame * frame = NULL;
 
-		g_nav_ctl.capture_active = TRUE;
-
 		// Make sure we can tell the difference between a used and unused frame
 		for ( int index = 0; index < BUFFERED_FRAMES; index ++ )
 			frameBuffer[ index ] = NULL;
@@ -1557,7 +1555,6 @@ extern "C"
 	{
 		int lastPosition = -1;
 
-		g_nav_ctl.capture_active = TRUE;
 		GtkWidget *drawingarea = ( GtkWidget* ) p;
 		prevFramesWritten = 0;
 
@@ -1593,9 +1590,9 @@ extern "C"
 			gdk_flush();
 			gdk_threads_leave();
 			
+			pthread_mutex_lock( &writerlock );
 			if ( writer )
 			{
-				pthread_mutex_lock( &writerlock );
 				int framesWritten = writer->GetFramesWritten();
 				string filename = writer->GetFilename();
 				pthread_mutex_unlock( &writerlock );
@@ -1609,6 +1606,10 @@ extern "C"
 				}
 				prevFramesWritten = framesWritten;
 			}
+			else
+			{
+				pthread_mutex_unlock( &writerlock );
+			}
 		}
 
 		return NULL;
@@ -1616,8 +1617,6 @@ extern "C"
 
 	static void *avcThread( gpointer p )
 	{
-		g_nav_ctl.capture_active = TRUE;
-
 		while ( g_nav_ctl.capture_active )
 		{
 			// Check that device is still valid
@@ -1734,7 +1733,7 @@ extern "C"
 	                                           gpointer user_data)
 	{
 		avcStatus = !avcStatus;
-		common->getPageCapture( ) ->avc_enabled = !common->getPageCapture( ) ->avc_enabled;
+		Preferences::getInstance().enableAVC = common->getPageCapture( ) ->avc_enabled = !common->getPageCapture( ) ->avc_enabled;
 		std::cerr << ">> AV/C " << ( common->getPageCapture( ) ->avc_enabled ? _( "Enabled" ) : _( "Disabled" ) ) << std::endl;
 		TriggerAction( );
 	}
