@@ -226,6 +226,7 @@ void PageEditor::clean()
 	}
 	for ( int i = 0; i < PLAYBACK_FRAMES; i ++ )
 		GetFramePool( ) ->DoneWithFrame( frameContent[ i ] );
+	gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( lookup_widget( common->getWidget(), "menuitem_editor" ) ), FALSE );
 	cerr << ">> Left Editor" << endl;
 }
 
@@ -1417,6 +1418,7 @@ extern "C"
 		pthread_mutex_unlock( &condition_queue_mutex );
 	}
 
+#if 0 //not being used at the moment
 	static void WaitForAudioAction( int lastPosition )
 	{
 		if ( tail == -1 || frameNumber[ tail ] == lastPosition )
@@ -1426,6 +1428,7 @@ extern "C"
 			pthread_mutex_unlock( &condition_audio_mutex );
 		}
 	}
+#endif
 
 	static void TriggerAudioAction( )
 	{
