@@ -25,7 +25,7 @@
 using std::cerr;
 using std::endl;
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -203,7 +203,7 @@ Export1394::doExport( PlayList * playlist, int begin, int end, int every,
 
 		int16_t *audio_buffers[ 4 ];
 		AudioInfo info;
-		AudioResample *resampler = NULL;
+		AudioResample<int16_ne_t,int16_ne_t> *resampler = NULL;
 
 		for ( i = 0; i < 4; i++ )
 			audio_buffers[ i ] = ( int16_t * ) calloc( 2 * DV_AUDIO_MAX_SAMPLES, sizeof( int16_t ) );
@@ -245,7 +245,7 @@ Export1394::doExport( PlayList * playlist, int begin, int end, int every,
 				if ( resampler == NULL )
 				{
 					frame.GetAudioInfo( info );
-					resampler = AudioResampleFactory::createAudioResample(
+					resampler = AudioResampleFactory<int16_ne_t,int16_ne_t>::createAudioResample(
 					                AUDIO_RESAMPLE_SRC_SINC_MEDIUM_QUALITY, info.frequency );
 				}
 				resampler->Resample( frame );
