@@ -26,7 +26,7 @@
 using std::cerr;
 using std::endl;
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -153,7 +153,7 @@ ExportAudio::doExport( PlayList * playlist, int begin, int end, int every,
 	}
 
 	// Create the resampler and output objects
-	AudioResample *resampler = AudioResampleFactory::createAudioResample(
+	AudioResample<int16_ne_t,int16_le_t> *resampler = AudioResampleFactory<int16_ne_t,int16_le_t>::createAudioResample(
 	                               AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, resampleRate );
 	KinoAudioPipe *output = KinoAudioFactory::CreateAudioPipe( type );
 
@@ -197,7 +197,7 @@ ExportAudio::doExport( PlayList * playlist, int begin, int end, int every,
 
 				playlist->GetFrame( i, frame );
 				resampler->Resample( frame );
-				if ( !output->OutputAudioFrame( resampler->output, resampler->size ) )
+				if ( !output->OutputAudioFrame( reinterpret_cast<int16_t *>(resampler->output), resampler->size ) )
 				{
 					modal_message( _( "Error during audio export - aborting." ) );
 					status = EXPORT_RESULT_FAILURE;
