@@ -29,7 +29,7 @@
 using std::cerr;
 using std::endl;
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -49,7 +49,9 @@ using std::endl;
 */
 
 ExportMJPEG::ExportMJPEG( PageExport *_exportPage, KinoCommon *_common ) :
-		Export( _exportPage, _common )
+		Export( _exportPage, _common ),
+		prefs( Preferences::getInstance() ),
+		hasYuvDeinterlace( false )
 {
 	cerr << "> Creating ExportMJPEG Page" << endl;
 
@@ -81,6 +83,46 @@ ExportMJPEG::ExportMJPEG( PageExport *_exportPage, KinoCommon *_common ) :
 	authorCheck
 	= GTK_TOGGLE_BUTTON( lookup_widget( common->getWidget(),
 	        			"checkbutton_export_mjpeg_author" ) );
+	mjpegAspect
+	= GTK_MENU( gtk_option_menu_get_menu( GTK_OPTION_MENU( lookup_widget( exportPage->getWidget(),
+	                                      "optionmenu_export_aspect_ratio" ) ) ) );
+	mjpegXMLScript
+	= GTK_ENTRY( lookup_widget( exportPage->getWidget(),
+	                            "entry_export_mjpeg_script" ) );
+
+	cerr << "> Initializing MJPEG Export Page settings from Preferences" << endl;
+	gtk_entry_set_text( mjpegXMLScript, prefs.exportMjpegXMLScript  );
+	gtk_option_menu_set_history( GTK_OPTION_MENU( lookup_widget( exportPage->getWidget(),
+								"optionmenu_export_mjpeg_format" ) ), prefs.exportMjpegFormat );
+	gtk_option_menu_set_history( GTK_OPTION_MENU( lookup_widget( exportPage->getWidget(),
+								"optionmenu_export_mjpeg_deinterlace" ) ), prefs.exportMjpegDeinterlace );
+	gtk_option_menu_set_history( GTK_OPTION_MENU( lookup_widget( exportPage->getWidget(),
+								"optionmenu_export_aspect_ratio" ) ) , prefs.exportMjpegAspect );
+	gtk_toggle_button_set_active( splitCheck, prefs.exportMjpegSceneSplit );
+	gtk_toggle_button_set_active( cleanupCheck, prefs.exportMjpegCleanup );
+	gtk_toggle_button_set_active( authorCheck , prefs.exportMjpegOutputDVDAuthorXML );
+
+	if ( system( "yuvdeinterlace -h 2> /dev/null" ) == 0 )
+	{
+		hasYuvDeinterlace = true;
+		GtkWidget *widget = gtk_menu_item_new_with_label( _("YUV Deinterlace") );
+		gtk_widget_show( widget );
+		gtk_menu_append( deinterlaceMenu, widget );
+		widget = gtk_menu_item_new_with_label( _("YUV Deinterlace Film-like") );
+		gtk_widget_show( widget );
+		gtk_menu_append( deinterlaceMenu, widget );
+	}
+	else if ( system( "yuvdenoise -h 2> /dev/null" ) == 0 )
+	{
+		GtkWidget *widget = gtk_menu_item_new_with_label( _("YUV Denoise (Fast)") );
+		gtk_widget_show( widget );
+		gtk_menu_append( deinterlaceMenu, widget );
+		widget = gtk_menu_item_new_with_label( _("YUV Denoise (Slow)") );
+		gtk_widget_show( widget );
+		gtk_menu_append( deinterlaceMenu, widget );
+	}
+	gtk_option_menu_set_menu( GTK_OPTION_MENU( lookup_widget( common->getWidget(),
+		"optionmenu_export_mjpeg_deinterlace" ) ), GTK_WIDGET( deinterlaceMenu ) );
 }
 
 /** Destructor for page.
@@ -99,6 +141,15 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 {
 	cerr << ">>> ExportMJPEG::startExport" << endl;
 
+	// Set defaults on own controls
+	strcpy( prefs.exportMjpegXMLScript , gtk_entry_get_text( mjpegXMLScript ) );
+	prefs.exportMjpegFormat = g_list_index ( GTK_MENU_SHELL ( mjpegFormat ) ->children, gtk_menu_get_active( mjpegFormat ) );
+	prefs.exportMjpegDeinterlace = g_list_index ( GTK_MENU_SHELL ( deinterlaceMenu ) ->children, gtk_menu_get_active( deinterlaceMenu ) );
+	prefs.exportMjpegAspect = g_list_index ( GTK_MENU_SHELL ( mjpegAspect ) ->children, gtk_menu_get_active( mjpegAspect ) );
+	prefs.exportMjpegSceneSplit = gtk_toggle_button_get_active( splitCheck );
+	prefs.exportMjpegCleanup = gtk_toggle_button_get_active( cleanupCheck );
+	prefs.exportMjpegOutputDVDAuthorXML = gtk_toggle_button_get_active( authorCheck );
+
 	// TODO: Fix this buffer stuff.
 	gchar *filename;
 	enum export_result status = EXPORT_RESULT_SUCCESS;
@@ -130,7 +181,7 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 	int frequency = info.frequency;
 
 	// Force audio resampling to that of the first frame
-	AudioResample *resampler = AudioResampleFactory::createAudioResample(
+	AudioResample<int16_ne_t,int16_le_t> *resampler = AudioResampleFactory<int16_ne_t,int16_le_t>::createAudioResample(
 	                               AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, frequency );
 
 	// vars for collecting audio and video pipe commands
@@ -142,6 +193,8 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 	gchar *videopipe = NULL;
 	gchar *multiplex = NULL;
 	gchar *cleanup = NULL;
+	gchar *authorScript = NULL;
+	gchar *authorCommand = NULL;
 
 	// list to collect the names of the generated mpeg2 files
 	// this collection only proceeds if we are authoring an
@@ -157,27 +210,30 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 	int deinterlaceRequest = 0;
 	const char *audioencode = "";
 	const char *multiplexer = "";
+	int aspectRatio = 0;
+	bool isY4Minterlaced = true;
 
 	videopipeInput = gtk_entry_get_text( mjpegVideo );
 	GtkWidget *active_item = gtk_menu_get_active( mjpegFormat );
-	videoformat
-	= g_list_index ( GTK_MENU_SHELL ( mjpegFormat ) ->children, active_item );
+	videoformat = g_list_index ( GTK_MENU_SHELL ( mjpegFormat ) ->children, active_item );
 	audioencode = gtk_entry_get_text( mjpegAudio );
 	multiplexer = gtk_entry_get_text( mjpegMultiplexer );
 	active_item = gtk_menu_get_active( deinterlaceMenu );
-	deinterlaceRequest
-	= g_list_index ( GTK_MENU_SHELL ( deinterlaceMenu ) ->children, active_item );
+	deinterlaceRequest = g_list_index ( GTK_MENU_SHELL ( deinterlaceMenu ) ->children, active_item );
 	split = gtk_toggle_button_get_active( splitCheck );
 	Usercleanup = gtk_toggle_button_get_active( cleanupCheck );
 	/* only necessary to check this option if we are creating DVD video */
 	if( videoformat == 6 )
 	{
 		author = gtk_toggle_button_get_active( authorCheck );
+		authorScript = g_strdup( gtk_entry_get_text( mjpegXMLScript ));
 	}
+	active_item = gtk_menu_get_active( mjpegAspect );
+	aspectRatio = g_list_index ( GTK_MENU_SHELL ( mjpegAspect ) ->children, active_item );
 	
 	/* force deinterlace on MPEG-1 formats if not specified by user */
 	if ( videoformat < 3 && deinterlaceRequest == 0 )
-		deinterlaceRequest = 1;
+		deinterlaceRequest = 3;
 
 	char deinterlace[ 30 ] = "";
 	char interlace = '0';
@@ -185,17 +241,21 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 
 	switch ( deinterlaceRequest )
 	{
-	case 0:
+	case 0: // None
 		interlace = '1';
 		break;
-	case 1:
-		strcpy( deinterlace, "yuvdenoise -F -f |" );
+	case 1: // Internal
+		type = PIPE_VIDEO_DEINTERLACED_MJPEG;
+		isY4Minterlaced = false;
 		break;
-	case 2:
-		strcpy( deinterlace, "yuvdenoise -F |" );
+	case 2: // Already deinterlaced
+		isY4Minterlaced = false;
 		break;
 	case 3:
-		type = PIPE_VIDEO_DEINTERLACED_MJPEG;
+		strcpy( deinterlace, hasYuvDeinterlace ? "yuvdeinterlace |" : "yuvdenoise -F -f |" );
+		break;
+	case 4:
+		strcpy( deinterlace, hasYuvDeinterlace ? "yuvdeinterlace -f |" : "yuvdenoise -F |" );
 		break;
 	}
 
@@ -240,14 +300,14 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 		// Yuck (!) - builds the video pipe depending on data collected above...
 		if ( strcmp( scale, "" ) )
 			videopipe = g_strdup_printf(
-			         "%s yuvscaler -v 0 -O %s -n %c | %s -f %d -I %c -n %c -a %c %s -o \'%s\'.mpv",
+			         "%s yuvscaler -v 0 -O %s -n %c | %s -f %d -I %c -n %c -a %d %s -o \'%s\'.mpv",
 			         deinterlace,
 			         scale, isPAL ? 'p' : 'n', videopipeInput, videoformat, interlace,
-			         isPAL ? 'p' : 'n', isWide ? '3' : '2', bitrate, filename );
+			         isPAL ? 'p' : 'n', aspectRatio ? aspectRatio : (isWide ? 3 : 2), bitrate, filename );
 		else
-			videopipe = g_strdup_printf( "%s %s -f %d -I %c -n %c -a %c %s -o \'%s\'.mpv",
+			videopipe = g_strdup_printf( "%s %s -f %d -I %c -n %c -a %d %s -o \'%s\'.mpv",
 			         deinterlace, videopipeInput, videoformat, interlace,
-			         isPAL ? 'p' : 'n', isWide ? '3' : '2', bitrate, filename );
+			         isPAL ? 'p' : 'n', aspectRatio ? aspectRatio : (isWide ? 3 : 2), bitrate, filename );
 	}
 	else
 	{
@@ -319,7 +379,7 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 		cerr << ">>> Generated audio pipe '" << audiopipe << "'" << endl;
 
 		mpeg->OpenAudio( audiopipe, channels, frequency, 2 );
-		mpeg->OpenVideoPipe( videopipe, width, height );
+		mpeg->OpenVideoPipe( videopipe, width, height, isY4Minterlaced );
 
 		int imagesize = width * height * 3;
 
@@ -333,7 +393,7 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 			playlist->GetFrame( i, *frame );
 
 			resampler->Resample( *frame );
-			if ( !mpeg->OutputAudioFrame( resampler->output, resampler->size ) )
+			if ( !mpeg->OutputAudioFrame( reinterpret_cast<int16_t *>(resampler->output), resampler->size ) )
 			{
 				modal_message( _( "Error writing to KINO/MJPEG audio filter - aborting." ) );
 				status = EXPORT_RESULT_FAILURE;
@@ -390,18 +450,28 @@ ExportMJPEG::doExport( PlayList * playlist, int begin, int end, int every,
 	}
 
 	if ( author )
+	{
      	createAuthorXml( filename, nameList, split, isPAL );
+		if(strlen(authorScript))
+		{
+			cerr << ">>> Executing script: '" << authorScript << "' on file '" << filename << "'" << endl;
+			authorCommand = g_strdup_printf( "%s %s-dvdauthor.xml", authorScript, filename );
+			mpeg->ExecuteCommand( authorCommand );
+		}
+	}
 
 	g_free( filename );
 	g_free( audiopipe );
 	g_free( videopipe );
 	g_free( multiplex );
 	g_free( cleanup );
+	g_free( authorCommand );
+	g_free( authorScript );
 	delete mpeg;
 	delete video;
 	delete wav;
 	delete resampler;
-	delete pixels;
+	delete[] pixels;
 
 	GetFramePool()->DoneWithFrame( frame );
 	
