@@ -24,10 +24,11 @@
 #include <iostream>
 #include <sstream>
 #include <string>
+#include <algorithm>
 using std::cerr;
 using std::endl;
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -211,6 +212,11 @@ public:
 	{
 		stop( );
 	}
+
+	static bool compare( const DVPipeTool* x, const DVPipeTool* y )
+	{
+		return ( x->m_description < y->m_description );
+	}
 };
 
 static void on_tool_change( GtkOptionMenu *optionmenu, gpointer user_data )
@@ -276,6 +282,7 @@ void ExportPipe::loadTools( string directory )
 		}
 		closedir( dir );
 	}
+	std::sort( m_tools.begin(), m_tools.end(), DVPipeTool::compare );
 }
 
 void ExportPipe::activateTool( int index )
@@ -408,7 +415,7 @@ enum export_result ExportPipe::doExport( PlayList *playlist, int begin, int end,
 			info.frequency = 48000;
 
 		// Create the resampler
-		AudioResample *resampler = AudioResampleFactory::createAudioResample( AUDIO_RESAMPLE_SRC_SINC_MEDIUM_QUALITY, info.frequency );
+		AudioResample<int16_ne_t,int16_le_t> *resampler = AudioResampleFactory<int16_ne_t,int16_le_t>::createAudioResample( AUDIO_RESAMPLE_SRC_SINC_MEDIUM_QUALITY, info.frequency );
 
 		// Evaluate argument for tool
 		string normalisation = frame.IsPAL( ) ? "pal" : "ntsc";
@@ -454,7 +461,7 @@ enum export_result ExportPipe::doExport( PlayList *playlist, int begin, int end,
 				// Resample
 				resampler->Resample( frame );
 				info.samples = resampler->size / info.channels / 2;
-				int16_t *p = resampler->output;
+				int16_t *p = reinterpret_cast<int16_t *>(resampler->output);
 				for ( int s = 0; s < info.samples; s++ )
 					for ( int c = 0; c < info.channels; c++ )
 						audio_buffers[ c ][ s ] = *p++;
