@@ -607,7 +607,7 @@ public:
 	virtual void Initialise( PageMagickInfo * )
 	{ }
 	;
-	virtual void GetFrame( int16_t **audio, int i, int& samples )
+	virtual void GetFrame( int16_t **audio, int i, int& samples, int locked_samples )
 	{ }
 	;
 	virtual void Close()
@@ -694,7 +694,7 @@ void PageMagickOverwrite::GetFrame( uint8_t *pixels, int16_t **audio, int i )
 	infoFrame->GetAudioInfo( ainfo );
 	if ( ainfo.channels )
 	{
-		AudioResample * resampler = AudioResampleFactory::createAudioResample(
+		AudioResample<int16_ne_t,int16_ne_t> * resampler = AudioResampleFactory<int16_ne_t,int16_ne_t>::createAudioResample(
 		                                AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, info->frequency );
 		resampler->Resample( *infoFrame );
 		info->samples_this_frame = resampler->size / ( 2 * ainfo.channels );
@@ -718,7 +718,7 @@ void PageMagickOverwrite::GetFrame( uint8_t *pixels, int width, int height, int1
 	infoFrame->GetAudioInfo( ainfo );
 	if ( ainfo.channels )
 	{
-		AudioResample *resampler = AudioResampleFactory::createAudioResample(
+		AudioResample<int16_ne_t,int16_ne_t> *resampler = AudioResampleFactory<int16_ne_t,int16_ne_t>::createAudioResample(
 	                               AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, info->frequency );
 		resampler->Resample( *infoFrame );
 		info->samples_this_frame = resampler->size / ( 2 * ainfo.channels );
@@ -776,7 +776,7 @@ PageMagickCreate::PageMagickCreate() : image( NULL )
 
 PageMagickCreate::~PageMagickCreate()
 {
-	delete image;
+	delete[] image;
 }
 
 void PageMagickCreate::Initialise( PageMagickInfo *info )
@@ -786,13 +786,14 @@ void PageMagickCreate::Initialise( PageMagickInfo *info )
 	info->increment = 1;
 	info->reverse = false;
 
+/* Commented to simplify UI to always create before current frame
 	GtkToggleButton *frameToggle = GTK_TOGGLE_BUTTON( lookup_widget( common->getPageMagick() ->window, "radiobutton_magick_create_before" ) );
 	if ( gtk_toggle_button_get_active( frameToggle ) )
 	{
 		GtkEntry * spin = GTK_ENTRY( lookup_widget( common->getPageMagick() ->window, "spinbutton_magick_create_before" ) );
 		info->begin = atoi( gtk_entry_get_text( spin ) );
 	}
-
+*/
 	info->anteFrame = info->begin - 1;
 	info->postFrame = info->begin;
 
@@ -879,14 +880,15 @@ void PageMagickTransition::Initialise( PageMagickInfo *info )
 
 	if ( gtk_toggle_button_get_active( toggle ) )
 	{
-		GnomeColorPicker * colourPicker = GNOME_COLOR_PICKER( lookup_widget( info->GetCommon() ->getPageMagick() ->window, "colorpicker_magick_transition" ) );
-		guint8 r, g, b, a;
-		gnome_color_picker_get_i8( colourPicker, &r, &g, &b, &a );
+		GdkColor color;
+		GtkColorButton * colorButton = GTK_COLOR_BUTTON( lookup_widget( info->GetCommon() ->getPageMagick() ->window, "colorpicker_magick_transition" ) );
+		gtk_color_button_get_color( colorButton, &color );
+		
 		for ( uint8_t * p = keyFrame; p < ( keyFrame + info->width * info->height * 3 ); )
 		{
-			*p ++ = r;
-			*p ++ = g;
-			*p ++ = b;
+			*p ++ = color.red >> 8;
+			*p ++ = color.green >> 8;
+			*p ++ = color.blue >> 8;
 		}
 	}
 	else
@@ -997,7 +999,7 @@ private:
 	GDKAudioFilter *filter;
 public:
 	void Initialise( PageMagickInfo *info );
-	void GetFrame( int16_t **audio, int i, int& samples );
+	void GetFrame( int16_t **audio, int i, int& samples, int locked_samples );
 };
 
 void PageMagickAudioFilter::Initialise( PageMagickInfo *info )
@@ -1010,7 +1012,7 @@ void PageMagickAudioFilter::Initialise( PageMagickInfo *info )
 		throw _( "Invalid audio filter selected" );
 }
 
-void PageMagickAudioFilter::GetFrame( int16_t **audio, int i, int& samples )
+void PageMagickAudioFilter::GetFrame( int16_t **audio, int i, int& samples, int locked_samples )
 {
 	// Sanity checks ...
 	if ( !filter )
@@ -1033,7 +1035,7 @@ public:
 	PageMagickAudioTransition();
 	virtual ~PageMagickAudioTransition();
 	void Initialise( PageMagickInfo *info );
-	void GetFrame( int16_t **audio, int i, int& samples );
+	void GetFrame( int16_t **audio, int i, int& samples, int locked_samples );
 };
 
 PageMagickAudioTransition::PageMagickAudioTransition()
@@ -1045,7 +1047,7 @@ PageMagickAudioTransition::PageMagickAudioTransition()
 PageMagickAudioTransition::~PageMagickAudioTransition()
 {
 	for ( int index = 0; index < 4; index ++ )
-		delete audio_buffers[ index ];
+		delete[] audio_buffers[ index ];
 }
 
 void PageMagickAudioTransition::Initialise( PageMagickInfo *info )
@@ -1059,35 +1061,43 @@ void PageMagickAudioTransition::Initialise( PageMagickInfo *info )
 		throw _( "Invalid audio transition selected" );
 }
 
-void PageMagickAudioTransition::GetFrame( int16_t **audio, int i, int& samples )
+void PageMagickAudioTransition::GetFrame( int16_t **audio, int i, int& samples, int locked_samples )
 {
 	// Sanity checks ...
 	if ( !transition )
 		throw _( "Invalid audio filter selected" );
 
-	// Pick up the b-frame audio (ugly.. moved by image transition when appropriate)
-	// should also be resampled to the a-frames frequency - this is going to go haywire in
-	// mixed sample rate projects :-/
-	// In truth, even the aframes should be resampled to original aframes frequency... (fun, fun, fun)
-	Frame* infoFrame = GetFramePool()->GetFrame();
-	AudioInfo ainfo;
-	common->getPlayList()->GetFrame( info->GetPostFrame() - 1, *( infoFrame ) );
-	infoFrame->GetAudioInfo( ainfo );
-	if ( ainfo.channels )
+	if ( transition->IsBFrameConsumer() )
 	{
-		AudioResample * resampler = AudioResampleFactory::createAudioResample(
-		                                AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, info->frequency );
-		resampler->Resample( *infoFrame );
-		int16_t *p = resampler->output;
-		if ( resampler->size / info->channels / 2 < samples )
-			samples = resampler->size / info->channels / 2;
-		for ( int s = 0; s < samples; s++ )
-			for ( int c = 0; c < info->channels; c++ )
-				audio_buffers[ c ][ s ] = *p++;
-		delete resampler;
+		// Pick up the b-frame audio (ugly.. moved by image transition when appropriate)
+		// should also be resampled to the a-frames frequency - this is going to go haywire in
+		// mixed sample rate projects :-/
+		// In truth, even the aframes should be resampled to original aframes frequency... (fun, fun, fun)
+		Frame* infoFrame = GetFramePool()->GetFrame();
+		AudioInfo ainfo;
+		common->getPlayList()->GetFrame( info->GetPostFrame() - 1, *( infoFrame ) );
+		infoFrame->GetAudioInfo( ainfo );
+		if ( ainfo.channels )
+		{
+			AudioResample<int16_ne_t,int16_ne_t> * resampler = AudioResampleFactory<int16_ne_t,int16_ne_t>::createAudioResample(
+											AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, info->frequency );
+			resampler->Resample( *infoFrame );
+			int16_t *p = resampler->output;
+			if ( resampler->size / info->channels / 2 < samples )
+				samples = resampler->size / info->channels / 2;
+			for ( int s = 0; s < samples; s++ )
+				for ( int c = 0; c < info->channels; c++ )
+					audio_buffers[ c ][ s ] = *p++;
+			delete resampler;
+		}
+		GetFramePool()->DoneWithFrame( infoFrame );
 	}
-	GetFramePool()->DoneWithFrame( infoFrame );
-	transition->GetFrame( audio, audio_buffers, info->frequency, info->channels, samples, time_info( *info, i ).position(), time_info( *info, i ).frame_delta() );
+	else
+	{
+		samples = locked_samples;
+	}
+	transition->GetFrame( audio, audio_buffers, info->frequency, info->channels, 
+		samples, time_info( *info, i ).position(), time_info( *info, i ).frame_delta() );
 }
 
 /** Info implementation.
@@ -1480,10 +1490,11 @@ void PageMagick::PlayAudio( int16_t *buffers[], int frequency, int channels, boo
 	dv_audio.samples_this_frame = frequency / ( isPAL ? 25 : 30 );
 	dv_audio.num_channels = channels;
 
-	if ( !audio_device_avail && ( audio_sampling_rate = dv_oss_init( &dv_audio, audio_device ) ) != 0 )
+	if ( !audio_device_avail && ( audio_sampling_rate = kino_sound_init( 
+			&dv_audio, audio_device, Preferences::getInstance().audioDevice ) ) != 0 )
 		audio_device_avail = true;
 	if ( audio_device_avail )
-		dv_oss_play( &dv_audio, audio_device, buffers );
+		kino_sound_play( &dv_audio, audio_device, buffers );
 }
 
 /** Show an image in the preview drawing area.
@@ -1510,9 +1521,16 @@ static bool restart = false;
 
 void PageMagick::StartPreview()
 {
-	// Make sure we're not already rendering or previewing.
-	if ( rendering || previewing )
-		return ;
+	// Do not interrupt rendering
+	if ( rendering )
+	{
+		buttonMutex = true;
+		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( lookup_widget( window, "togglebutton_magick_preview" ) ), 0 );
+		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( lookup_widget( window, "togglebutton_magick_start" ) ), 1 );
+		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( lookup_widget( window, "togglebutton_magick_stop" ) ), 0 );
+		buttonMutex = false;
+		return;
+	}
 
 	buttonMutex = true;
 	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( lookup_widget( window, "togglebutton_magick_preview" ) ), 1 );
@@ -1520,6 +1538,10 @@ void PageMagick::StartPreview()
 	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( lookup_widget( window, "togglebutton_magick_stop" ) ), 0 );
 	buttonMutex = false;
 
+	// Make sure we're not already previewing.
+	if ( previewing )
+		return ;
+
 	// Set the page condition
 	previewing = true;
 
@@ -1534,7 +1556,7 @@ void PageMagick::StartPreview()
 	// Generate the info
 	PageMagickInfo *info = new PageMagickInfo( common );
 
-	audio_device = dv_oss_new();
+	audio_device = kino_sound_new();
 	audio_device_avail = false;
 	audio_sampling_rate = 0;
 
@@ -1546,18 +1568,9 @@ void PageMagick::StartPreview()
 	GtkToggleButton *qualityButton = GTK_TOGGLE_BUTTON( lookup_widget( window, "checkbutton_low_quality" ) );
 	GtkEntry *contextSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_preview_context" ) );
 
-	dv_encoder_t *encoder = NULL;
 	int audio_number = 0;
 	Frame* infoFrame = GetFramePool()->GetFrame();
 
-	// Temporary fix - requires modification in libdv
-	if ( info->isPAL )
-		encoder = dv_encoder_new( FALSE, FALSE, FALSE );
-	else
-		encoder = dv_encoder_new( FALSE,
-		                          Preferences::getInstance().dvDecoderClampLuma,
-		                          Preferences::getInstance().dvDecoderClampChroma );
-
 	try
 	{
 		do
@@ -1621,18 +1634,11 @@ void PageMagick::StartPreview()
 				if ( gtk_toggle_button_get_active( audioButton ) )
 				{
 					int samples = info->samples_this_frame;
+					int locked_samples = infoFrame->CalculateNumberSamples( info->frequency, audio_number ++ );
 					if ( samples == 0 )
-					{
-#ifdef LIBDV_HAS_SAMPLE_CALCULATOR
-						samples = dv_calculate_samples( encoder, info->frequency, audio_number ++ );
-#else
+						samples = locked_samples;
 
-						samples = info->frequency / ( info->isPAL ? 25 : 30 );
-#endif
-
-					}
-
-					sound->GetFrame( audio_buffers, frame_number, samples );
+					sound->GetFrame( audio_buffers, frame_number, samples, locked_samples );
 					PlayAudio( audio_buffers, info->frequency, info->channels, info->isPAL );
 				}
 
@@ -1672,17 +1678,14 @@ void PageMagick::StartPreview()
 		modal_message( ( char * ) exc );
 	}
 
-	dv_oss_close( audio_device );
+	kino_sound_close( audio_device );
 
 	previewing = false;
 
-	if ( encoder )
-		free( encoder );
-
 	delete info;
-	delete pixels;
+	delete[] pixels;
 	for ( int n = 0; n < 4; n++ )
-		delete audio_buffers[ n ];
+		delete[] audio_buffers[ n ];
 
     GetFramePool()->DoneWithFrame( infoFrame );
 	
@@ -1695,35 +1698,14 @@ void PageMagick::StartPreview()
 	LoadSplash( );
 }
 
-void dv_encode_full_frame2( dv_encoder_t *encoder, uint8_t *image, uint8_t *data, uint8_t *temp_image )
-{
-	if ( Preferences::getInstance().dvTwoPassEncoder )
-	{
-		Frame * frame = GetFramePool( ) ->GetFrame( );
-		dv_encode_full_frame( encoder, &image, e_dv_color_rgb, frame->data );
-		frame->decoder->quality = DV_QUALITY_BEST;
-		frame->ExtractHeader( );
-		frame->ExtractRGB( temp_image );
-		int size = frame->GetWidth( ) * frame->GetHeight( ) * 3;
-		for ( int i = 0; i < size; i ++ )
-			image[ i ] = std::min( std::max( ( int ) image[ i ] - ( ( int ) temp_image[ i ] - ( int ) image[ i ] ), 0 ), 255 );
-		dv_encode_full_frame( encoder, &image, e_dv_color_rgb, data );
-		GetFramePool( ) ->DoneWithFrame( frame );
-	}
-	else
-	{
-		dv_encode_full_frame( encoder, &image, e_dv_color_rgb, data );
-	}
-}
-
 /** Render the effect.
 */
 
 void PageMagick::StartRender()
 {
-	// Make sure we're not already rendering or previewing already.
-	if ( rendering || previewing )
-		return ;
+	// Allow immediate render from preview
+	if ( previewing )
+		Stop();
 
 	// Show the current button status
 	buttonMutex = true;
@@ -1733,25 +1715,24 @@ void PageMagick::StartRender()
 	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( lookup_widget( window, "togglebutton_magick_stop" ) ), 0 );
 	buttonMutex = false;
 
+	// Make sure we're not already rendering
+	if ( rendering )
+		return ;
+
 	// Set the page condition
 	rendering = true;
 
 	// Create the temporary space
 	uint8_t *pixels = new unsigned char[ FRAME_MAX_WIDTH * FRAME_MAX_HEIGHT * 4 ];
-	uint8_t *temp_image = new unsigned char[ FRAME_MAX_WIDTH * FRAME_MAX_HEIGHT * 4 ];
 	int16_t *audio_buffers[ 4 ];
 	for ( int n = 0; n < 4; n++ )
 		audio_buffers[ n ] = new int16_t [ 2 * DV_AUDIO_MAX_SAMPLES ];
-	unsigned char *dv_buffer = new unsigned char[ 480 * 300 ];
 	unsigned char *dv_pixels[ 3 ];
 	dv_pixels[ 0 ] = pixels;
 
 	// Build the info
 	PageMagickInfo *info = new PageMagickInfo( common );
 
-	// Build the encoder
-	dv_encoder_t *encoder = NULL;
-
 	// Output file
 	FILE *output = NULL;
 
@@ -1769,14 +1750,6 @@ void PageMagick::StartRender()
 
 		int audio_number = 0;
 
-		// Temporary fix - requires modification in libdv
-		if ( info->isPAL )
-			encoder = dv_encoder_new( FALSE, FALSE, FALSE );
-		else
-			encoder = dv_encoder_new( FALSE,
-			                          Preferences::getInstance().dvDecoderClampLuma,
-			                          Preferences::getInstance().dvDecoderClampChroma );
-
 		// Obtain the file name
 		GtkEntry *fileEntry = GTK_ENTRY( lookup_widget( window, "entry_magick_file" ) );
 		const char *filename = gtk_entry_get_text( fileEntry );
@@ -1803,12 +1776,7 @@ void PageMagick::StartRender()
 		}
 		while ( stat( thisfile.c_str(), &stats ) == 0 );
 
-		// Specify the encoder
-		encoder->isPAL = ( info->height == 576 );
-		encoder->is16x9 = info->isWide;
-		encoder->vlc_encode_passes = 3;
-		encoder->static_qno = 0;
-		encoder->force_dct = DV_DCT_AUTO;
+		infoFrame->CreateEncoder( ( info->height == 576 ), info->isWide );
 
 		// Get the source and manipulators
 		PageMagickFrames *frames = info->GetFrameSource();
@@ -1838,40 +1806,32 @@ void PageMagick::StartRender()
 			frames->GetFrame( pixels, audio_buffers, frame_number );
 			image->PreGetFrame( );
 
-			int samples = info->samples_this_frame;
+			int samples = info->samples_this_frame; // set in frames->GetFrame() above
+			int locked_samples = infoFrame->CalculateNumberSamples( info->frequency, audio_number ++ );
 			if ( samples == 0 )
-			{
-#ifdef LIBDV_HAS_SAMPLE_CALCULATOR
-				samples = dv_calculate_samples( encoder, info->frequency, audio_number ++ );
-#else
+				samples = locked_samples;
 
-				samples = info->frequency / ( info->isPAL ? 25 : 30 );
-#endif
-
-			}
-
-			sound->GetFrame( audio_buffers, frame_number, samples );
+			sound->GetFrame( audio_buffers, frame_number, samples, locked_samples );
 
 			if ( ! change_image )
 			{
 				common->getPlayList()->GetFrame( frame_number, *( infoFrame ) );
-				memcpy( dv_buffer, infoFrame->data, ( info->isPAL ? 144000 : 120000 ) );
 			}
 			else
 			{
 				image->GetFrame( pixels, frame_number );
-				dv_encode_full_frame2( encoder, pixels, dv_buffer, temp_image );
+				infoFrame->EncodeRGB( pixels );
 			}
 
-#ifdef LIBDV_HAS_SAMPLE_CALCULATOR
-			encoder->samples_this_frame = samples;
-#endif
+			AudioInfo audioInfo;
+			audioInfo.channels = info->channels;
+			audioInfo.frequency = info->frequency;
+			audioInfo.samples = samples;
+			infoFrame->EncodeAudio( audioInfo, audio_buffers );
+			infoFrame->SetRecordingDate( &datetime, frameNum );
+			infoFrame->SetTimeCode( frameNum++ );
 
-			dv_encode_full_audio( encoder, audio_buffers, info->channels, info->frequency, dv_buffer );
-			dv_encode_metadata( dv_buffer, encoder->isPAL, encoder->is16x9, &datetime, frameNum );
-			dv_encode_timecode( dv_buffer, encoder->isPAL, frameNum++ );
-
-			if ( fwrite( dv_buffer, ( info->isPAL ? 144000 : 120000 ), 1, output ) != 1 )
+			if ( fwrite( infoFrame->data, ( info->isPAL ? 144000 : 120000 ), 1, output ) != 1 )
 				throw _( "Unable to write video - disk full?" );
 
 			if ( info->end != info->begin )
@@ -1910,15 +1870,10 @@ void PageMagick::StartRender()
 	if ( output )
 		fclose( output );
 
-	if ( encoder )
-		dv_encoder_free( encoder );
-
 	delete info;
-	delete dv_buffer;
-	delete pixels;
-	delete temp_image;
+	delete[] pixels;
 	for ( int n = 0; n < 4; n++ )
-		delete audio_buffers[ n ];
+		delete[] audio_buffers[ n ];
 	GetFramePool()->DoneWithFrame( infoFrame );
 }
 
@@ -2022,6 +1977,7 @@ void PageMagick::selectScene( int i )
 		}
 		else if ( page == 1 )
 		{
+/* Commented to simplify UI to always create before current frame
 			GtkToggleButton * rangeToggle = GTK_TOGGLE_BUTTON( lookup_widget( window, "radiobutton_magick_create_before" ) );
 			GtkEntry *startSpin = GTK_ENTRY( lookup_widget( window, "spinbutton_magick_create_before" ) );
 			GtkAdjustment *adjust = gtk_spin_button_get_adjustment( GTK_SPIN_BUTTON( startSpin ) );
@@ -2029,7 +1985,7 @@ void PageMagick::selectScene( int i )
 			adjust->lower = 0;
 			adjust->upper = scene[ scene.size() - 1 ];
 			gtk_spin_button_set_value( GTK_SPIN_BUTTON( startSpin ), begin );
-			g_signal_emit_by_name( adjust, "changed" );
+			g_signal_emit_by_name( adjust, "changed" );*/
 		}
 		if ( previewing )
 		{
@@ -2316,7 +2272,7 @@ protected:
 	double real_start;
 	double real_end;
 	int b_frame_type;
-	guint8 r, g, b, a;
+	GdkColor color;
 
 public:
 	void Initialise( PageMagick *page )
@@ -2399,8 +2355,9 @@ public:
 			range = GTK_RANGE( lookup_widget( page->window, "hscale_transition_end" ) );
 			real_end = range->adjustment->value;
 
-			GnomeColorPicker *colourPicker = GNOME_COLOR_PICKER( lookup_widget( page->window, "colorpicker_magick_transition" ) );
-			gnome_color_picker_get_i8( colourPicker, &r, &g, &b, &a );
+			GtkColorButton *colorButton = GTK_COLOR_BUTTON( lookup_widget( page->window, "colorpicker_magick_transition" ) );
+			gtk_color_button_get_color( colorButton, &color );
+
 			GtkToggleButton *toggle = GTK_TOGGLE_BUTTON( lookup_widget( page->window, "radiobutton_magick_transition_colour" ) );
 
 			if ( !gtk_toggle_button_get_active( toggle ) )
@@ -2507,7 +2464,7 @@ public:
 				g_object_unref( im1 );
 
 				// Delete the temporary space
-				delete temp;
+				delete[] temp;
 			}
 			else
 			{
@@ -2522,9 +2479,9 @@ public:
 			uint8_t *end = image + width * height * 3;
 			for ( uint8_t * p = image; p < end; )
 			{
-				*p ++ = r;
-				*p ++ = g;
-				*p ++ = b;
+				*p ++ = color.red >> 8;
+				*p ++ = color.green >> 8;
+				*p ++ = color.blue >> 8;
 			}
 		}
 	}
@@ -2553,9 +2510,9 @@ public:
 				uint8_t *end = image + width * height * 3;
 				for ( uint8_t * p = image; p < end; )
 				{
-					*p ++ = r;
-					*p ++ = g;
-					*p ++ = b;
+					*p ++ = color.red >> 8;
+					*p ++ = color.green >> 8;
+					*p ++ = color.blue >> 8;
 				}
 			}
 			break;
