@@ -164,7 +164,7 @@ private:
 	PluginAudioTransitionRepository audio_transitions;
 
 	// audio structures
-	dv_oss_t *audio_device;
+	kino_sound_t *audio_device;
 	dv_audio_t dv_audio;
 	bool audio_device_avail;
 	gint audio_sampling_rate;
