@@ -352,12 +352,27 @@ extern "C"
 					case RAW_DV:
 					case QT:
 						if ( common->getPageTrim()->loadFile( filename ) )
+						{
 							common->getPageTrim()->movedToFrame( common->getPageTrim()->getInPoint() );
-						break;
+							break;
+						}
 					default:
+					{
+						const std::string& importedFile = common->importFile( filename );
+						if ( common->getPageTrim()->loadFile( const_cast<char*>( importedFile.c_str() ) ) )
+						{
+							gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( editable ), "entry_trim_clip" ) ), const_cast<char*>( importedFile.c_str() ) );
+							common->getPageTrim()->movedToFrame( common->getPageTrim()->getInPoint() );
+						}
+						else
+						{
+							gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( editable ), "entry_trim_clip" ) ), "" );
+						}
+						break;
+					}
 						// XXX: the following is making gtk abort
 						//modal_message( _( "Invalid file specified." ) );
-						break;
+// 						break;
 				}
 			}
 		}
