@@ -140,6 +140,8 @@ extern EditorBackup *GetEditorBackup();
 class FileMap
 {
 public:
+	virtual ~FileMap()
+	{ }
 	/** The map from file name to handler is here */
 	virtual map<string, FileHandler*> &GetMap() = 0;
 	/** Clears the content of the file map. */
