@@ -24,8 +24,9 @@
 #include "preferences.h"
 #include "kino_common.h"
 
-// #include <string.h>
-#include <libgnome/gnome-config.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <errno.h>
 
 #include <string>
 using std::string;
@@ -33,6 +34,8 @@ using std::make_pair;
 #include <sstream>
 #include <iostream>
 
+#define GKEYFILE_GROUP "general"
+
 /** The global prefs object.
     
     It is accessible to other classes via the getInstance method.
@@ -50,65 +53,209 @@ Preferences *Preferences::instance = NULL;
 Preferences &Preferences::getInstance()
 {
 	if ( instance == NULL )
+	{
+		std::cerr << "> Creating Preferences" << std::endl;
 		instance = new Preferences;
+	}
 	return *instance;
 }
 
+void Preferences::get( int& var, const char* name, const char* def )
+{
+	GError *err = NULL;
+	var = g_key_file_get_integer( config, GKEYFILE_GROUP, name, &err );
+	if ( err != NULL )
+	{
+		var = atoi( def );
+		g_key_file_set_integer( config, GKEYFILE_GROUP, name, var );
+		g_error_free (err);
+	}
+}
+
+void Preferences::get( char *var, int size, const char* name, const char* def )
+{
+	gchar *temp = g_key_file_get_string( config, GKEYFILE_GROUP, name, NULL );
+	if ( temp != NULL )
+	{
+		strncpy( var, temp, size - 1 );
+		g_free( temp );
+	}
+	else
+	{
+		strncpy( var, def, size - 1 );
+		g_key_file_set_string( config, GKEYFILE_GROUP, name, def );
+	}
+}
+
+void Preferences::get( bool& var, const char* name, const char* def )
+{
+	GError *err = NULL;
+	var = g_key_file_get_boolean( config, GKEYFILE_GROUP, name, &err );
+	if ( err != NULL )
+	{
+		var = strcmp( def, "false" );
+		g_key_file_set_boolean( config, GKEYFILE_GROUP, name, var );
+		g_error_free (err);
+	}
+}
+
+
 /** The constructor loads the user preferences.
  
     Since this uses gnome-config, preferences are typically
     loaded from ~/.gnome/kino.
 */
-Preferences::Preferences()
+Preferences::Preferences() : phyID( -1 )
 {
-	gchar key[ 256 ];
-	gchar *tempString;
+	char key[ 256 ];
+	string filename;
+	
+	// Give the new config file priority, but failover to the old gnome-config one
+	filename = string( getenv( "HOME" ) ) + string( "/.kinorc" );
+	FILE *f = fopen( filename.c_str(), "r" );
+	if ( f )
+		fclose( f );
+	else
+		filename = string( getenv( "HOME" ) ) + string( "/.gnome2/kino" );
+	
+	// Read the config file
+	cerr << "Loading preferences from \"" << filename << "\"" << endl;
+	config = g_key_file_new();
+	g_key_file_load_from_file( config, filename.c_str(), G_KEY_FILE_KEEP_COMMENTS, NULL );
 
-	gnome_config_push_prefix( "/kino/general/" );
+	// Put the config entries into member vars with defaults
+	get( file, sizeof(file), "file", "capture" );
+	get( defaultNormalisation, "defaultNormalisation", "0" );
+	get( defaultAudio, "defaultAudio", "0" );
+	get( defaultAspect, "defaultAspect", "0" );
+	snprintf( key, 255, "%d", RAW_FORMAT );
+	get( fileFormat, "fileFormat", key );
+	get( autoSplit, "autoSplit", "true" );
+	get( timeStamp, "timeStamp", "false" );
+	get( frames, "frames", "7000" );
+	get( every, "every", "1" );
+	get( interface, "interface", "0" );
+	get( channel, "channel", "63" );
+	get( avcGUID, sizeof(avcGUID), "avcGUID", "" );
+	snprintf( key, 255, "%d", DISPLAY_XV );
+	get( displayMode, "displayMode", key );
+	get( displayQuality, "displayQuality", "2" );
+	get( displayFixed, "displayFixed", "false" );
+	get( enableAudio, "enableAudio", "true" );
+	get( cip_n, "cip_increment", "0" );
+	get( cip_d, "cip_threshold", "0" );
+	get( syt_offset, "syt_offset", "0" );
+	get( preview_capture, "preview_capture", "false" );
+	get( dropFrame, "dropFrame", "false" );
+	get( audioDevice, sizeof(audioDevice), "audioDevice", "default" );
+	get( enableV4L, "enableV4L", "false" );
+	get( disableKeyRepeat, "disableKeyRepeat", "false" );
+	get( audioRendering, "audioRendering", "0" );
+	get( previewRendering, "previewRendering", "1" );
+	get( maxUndos, "maxUndos", "50" );
+	get( dvCaptureBuffers, "dvCaptureBuffers", "50" );
+	get( dvExportBuffers, "dvExportBuffers", "10" );
+	get( dvDecoderClampLuma, "dvDecoderClampLuma", "false" );
+	get( dvDecoderClampChroma, "dvDecoderClampChroma", "false" );
+	get( maxFileSize, "maxFileSize", "2000" );
+	get( audioScrub, "audioScrub", "false" );
+	get( v4lVideoDevice, sizeof(v4lVideoDevice), "v4lVideoDevice", "/dev/video0" );
+	get( v4lAudioDevice, sizeof(v4lAudioDevice), "v4lAudioDevice", "/dev/dsp" );
+	get( v4lInput, sizeof(v4lInput), "v4lInput", "PAL" );
+	get( v4lAudio, sizeof(v4lAudio), "v4lAudio", "32000" );
+	get( isOpenDML, "isOpenDML", "false" );
+	get( defaultDirectory, sizeof(defaultDirectory), "defaultDirectory", "~/" );
+	get( displayExtract, "displayExtract", "0" );
+	get( relativeSave, "relativeSave", "false" );
+	get( dvCaptureDriver, "dvCaptureDriver", "0" );
+	get( dvCaptureDevice, sizeof(dvCaptureDevice), "dvCaptureDevice", "/dev/ieee1394/dv/host0/PAL/in" );
+	get( dv1394Preview, "dv1394Preview", "false" );
+	get( dvExportDevice, sizeof(dvExportDevice), "dvExportDevice", "/dev/ieee1394/dv/host0/PAL/out" );
+	get( avcPollIntervalMs, "avcPollIntervalMs", "200" );
+	get( dvExportPrerollSec, "dvExportPrerollSec", "4" );
+	get( dvTwoPassEncoder, "dvTwoPassEncoder", "false" );
+	get( windowWidth, "windowWidth", "-1" );
+	get( windowHeight, "windowHeight", "-1" );
+	get( storyboardPosition, "storyboardPosition", "-1" );
+	get( previewSize, "previewSize", "0" );
+	get( timeFormat, "timeFormat", "1" );
+	get( trimModeInsert, "trimModeInsert", "false" );
+	get( enablePublish, "enablePublish", "false" );
+	get( expandStoryboard, "expandStoryboard", "false" );
+	get( newProjectURI, sizeof(newProjectURI), "newProjectURI", "" );
+	get( newProjectXPath, sizeof(newProjectXPath), "newProjectXPath", "" );
+	get( metaNames, sizeof(metaNames), "metaNames", "*title,author,copyright,id,abstract" );
+	get( enableAVC, "enableAVC", "true" );
 
-	tempString = gnome_config_get_string( "file=capture" );
-	if ( tempString )
+	get( exportMjpegFormat, "exportMjpegFormat", "0" );
+	get( exportMjpegAspect, "exportMjpegAspect", "0" );
+	get( exportMjpegDeinterlace, "exportMjpegDeinterlace", "0" );
+	get( exportMjpegSceneSplit, "exportMjpegSceneSplit", "false" );
+	get( exportMjpegCleanup, "exportMjpegCleanup", "true" );
+	get( exportMjpegOutputDVDAuthorXML, "exportMjpegOutputDVDAuthorXML", "false" );
+	get( exportMjpegXMLScript, sizeof(exportMjpegXMLScript), "exportMjpegXMLScript", "" );
+
+	// build a metaValues key for each metaName
+	// metaValues is a range of values to pick from
+	// metaValue * = open-ended, values outside range permitted, can be used alongside values
+	vector< string > metaNamesList;
+	vector< string >::iterator metaNamesIter;
+	
+	string_utils::split( metaNames, ",", metaNamesList );
+	for ( metaNamesIter = metaNamesList.begin(); metaNamesIter != metaNamesList.end(); ++metaNamesIter )
+	
 	{
-		strncpy( file, tempString, 511 );
-		g_free( tempString );
-	}
-	defaultNormalisation = gnome_config_get_int( "defaultNormalisation=0" );
-	defaultAudio = gnome_config_get_int( "defaultAudio=0" );
-	defaultAspect = gnome_config_get_int( "defaultAspect=0" );
-	g_snprintf( key, 255, "fileFormat=%d", RAW_FORMAT );
-	fileFormat = gnome_config_get_int( key );
-	autoSplit = gnome_config_get_bool( "autoSplit=true" );
-	timeStamp = gnome_config_get_bool( "timeStamp=false" );
-	frames = gnome_config_get_int( "frames=7000" );
-	every = gnome_config_get_int( "every=1" );
-	interface = gnome_config_get_int( "interface=0" );
-	channel = gnome_config_get_int( "channel=63" );
-	phyID = -1;
-	tempString = gnome_config_get_string( "avcGUID=" );
-	if ( tempString )
-	{
-		strncpy( avcGUID, tempString, 64 );
-		g_free( tempString );
-	}
-	g_snprintf( key, 255, "displayMode=%d", DISPLAY_XV );
-	displayMode = gnome_config_get_int( key );
-	displayQuality = gnome_config_get_float( "displayQuality=2" );
-	displayFixed = gnome_config_get_bool( "displayFixed=false" );
-	enableAudio = gnome_config_get_bool( "enableAudio=true" );
-	cip_n = gnome_config_get_int( "cip_increment=0" );
-	cip_d = gnome_config_get_int( "cip_threshold=0" );
-	syt_offset = gnome_config_get_int( "syt_offset=0" );
-	preview_capture = gnome_config_get_bool( "preview_capture=false" );
-	dropFrame = gnome_config_get_bool( "dropFrame=false" );
-	tempString = gnome_config_get_string( "audioDevice=/dev/dsp" );
-	if ( tempString )
-	{
-		strncpy( audioDevice, tempString, 511 );
-		g_free( tempString );
+		std::ostringstream str;
+		std::string metaname = *metaNamesIter;
+
+		if ( metaname.at( 0 ) == '*' )
+			metaname.erase( 0, 1 );
+
+		str << "metaValues_" << metaname << "=*";
+		char* tempString = g_key_file_get_string( config, GKEYFILE_GROUP, str.str().c_str(), NULL );
+		if ( tempString )
+		{
+			vector< string > metaValuesSimpleList;
+			vector< string >::iterator iter;
+			vector< pair< string, string > > metaValuesList;
+
+			string_utils::split( tempString, ",", metaValuesSimpleList );
+			for ( iter = metaValuesSimpleList.begin(); iter != metaValuesSimpleList.end(); ++iter )
+			{
+				vector< string > labelValueVector;
+				pair< string, string > labelValuePair;
+				
+				string_utils::split( *iter, "=", labelValueVector );
+				if ( labelValueVector.size() > 1 )
+					labelValuePair = make_pair( labelValueVector[0], labelValueVector[1] );
+				else
+					labelValuePair = make_pair( *iter, *iter );
+				metaValuesList.push_back( labelValuePair );
+			}
+			metaValues.insert( make_pair( metaname, metaValuesList ) );
+		}
 	}
 
+	JogShuttleInit();
+	
+	Save();
+}
+
+
+Preferences::~Preferences()
+{
+	g_key_file_free( config );
+}
+
+/** Initialise JogShuttle bindings
+ 
+    Turns out to be an evil resource hog at compile time. So it was
+    split into several smaller functions to lower the memory footprint.
+ */
+void Preferences::JogShuttleInit(void)
+{
 	/// Jogshuttle stuff
-	enableJogShuttle = gnome_config_get_bool( "enableJogShuttle=false" );
+	get( enableJogShuttle, "enableJogShuttle", "false" );
 	_isGrabbing = false;
 	/* Fill array of actions */
 	/* Element 0 is empty */
@@ -124,9 +271,79 @@ Preferences::Preferences()
 	                       _( "Toggle play" ),
 	                       _( "Toggle between play and pause" ),
 	                       " " ) );
+	
+	JogShuttleInitNavigation(count);
+	JogShuttleInitCut(count);
+	JogShuttleInitCopy(count);
+	JogShuttleInitPaste(count);
+	JogShuttleInitModeSwitching(count);
+	JogShuttleInitGeneral(count);
+	JogShuttleInitTrim(count);
 
-	/* --- NAVIGATION --- */
+	// TODO: Add more actions?
 
+	/* Actually get the preferences */
+	get( count, "jogShuttleNumMappings", "0" );
+	if ( 0 != count )
+	{
+		for ( int i = 0; i < count ; i++ )
+		{
+			char key[ 512 ];
+			sprintf( key, "jogShuttleMappingFirstButton%i", i );
+			int first_code;
+			get( first_code, key, "0" );
+			sprintf( key, "jogShuttleMappingSecondButton%i", i );
+			int second_code;
+			get( second_code, key, "0" );
+			sprintf( key, "jogShuttleMappingAction%i", i );
+			// g_print ( " Key = %s\n", key );
+			get( key, sizeof(key), key, "" );
+
+			// TODO: Free
+			// g_print( "tmpstring Read action %s\n", tempString );
+			string action = string( key );
+			// g_print( "Read action %s\n", action.c_str() );
+			/* Insert */
+			_JogShuttleMappings[ make_pair ( first_code, second_code ) ]
+			= JogShuttleMapping( action );
+		}
+	}
+	else
+	{
+		// Set up defaults manuall, if 0 count
+		// These are my own default mappings
+		_JogShuttleMappings[ make_pair ( 0x100, 0x0 ) ]
+		= JogShuttleMapping( "i" );
+		_JogShuttleMappings[ make_pair ( 0x101, 0x0 ) ]
+		= JogShuttleMapping( "o" );
+		_JogShuttleMappings[ make_pair ( 0x102, 0x0 ) ]
+		= JogShuttleMapping( "h" );
+		_JogShuttleMappings[ make_pair ( 0x103, 0x0 ) ]
+		= JogShuttleMapping( "l" );
+		
+		_JogShuttleMappings[ make_pair ( 0x113, 0x0 ) ]
+		= JogShuttleMapping( "b" );
+		_JogShuttleMappings[ make_pair ( 0x111, 0x0 ) ]
+		= JogShuttleMapping( "w" );
+		_JogShuttleMappings[ make_pair ( 0x110, 0x0 ) ]
+		= JogShuttleMapping( " " );
+		_JogShuttleMappings[ make_pair ( 0x112, 0x0 ) ]
+		= JogShuttleMapping( "k" );
+		_JogShuttleMappings[ make_pair ( 0x114, 0x0 ) ]
+		= JogShuttleMapping( "j" );
+		_JogShuttleMappings[ make_pair ( 0x115, 0x0 ) ]
+		= JogShuttleMapping( "gg" );
+		_JogShuttleMappings[ make_pair ( 0x116, 0x0 ) ]
+		= JogShuttleMapping( "G" );
+		
+		_JogShuttleMappings[ make_pair ( 0x10, 0x0 ) ]
+		= JogShuttleMapping( " " );
+	}
+}
+
+/// Set up JogShuttle navigation bindings
+void Preferences::JogShuttleInitNavigation(int& count)
+{
 	_JogShuttleActions.push_back(
 	    JogShuttleActions( count++, _( "Forward one frame" ),
 	                       _( "Move one frame forward" ),
@@ -197,10 +414,11 @@ Preferences::Preferences()
 	    JogShuttleActions( count++, _( "Back 5 scene" ),
 	                       _( "Move backward 5 scenes" ),
 	                       "5^" ) );
+}
 
-
-	/* --- CUT --- */
-
+/// Set up JogShuttle cut bindings
+void Preferences::JogShuttleInitCut(int& count)
+{
 	_JogShuttleActions.push_back(
 	    JogShuttleActions( count++, _( "Cut current frame" ),
 	                       _( "Cut current frame" ),
@@ -235,9 +453,11 @@ Preferences::Preferences()
 	    JogShuttleActions( count++, _( "Cut from start of movie" ),
 	                       _( "Cut from start of movie" ),
 	                       "dgg" ) );
+}
 
-	/* --- COPY --- */
-
+/// Set up JogShuttle copy bindings
+void Preferences::JogShuttleInitCopy(int& count)
+{
 	_JogShuttleActions.push_back(
 	    JogShuttleActions( count++, _( "Copy current scene" ),
 	                       _( "Copy current scene" ),
@@ -252,9 +472,11 @@ Preferences::Preferences()
 	    JogShuttleActions( count++, _( "Copy from start of scene" ),
 	                       _( "Cut from start of scene" ),
 	                       "y0" ) );
+}
 
-	/* --- PASTE --- */
-
+/// Set up JogShuttle paste bindings
+void Preferences::JogShuttleInitPaste(int& count)
+{
 	_JogShuttleActions.push_back(
 	    JogShuttleActions( count++, _( "Paste after current frame" ),
 	                       _( "Paste after current frame" ),
@@ -264,9 +486,11 @@ Preferences::Preferences()
 	    JogShuttleActions( count++, _( "Paste before current frame" ),
 	                       _( "Paste before current frame" ),
 	                       "P" ) );
+}
 
-	/* --- MODE SWITCHING --- */
-
+/// Set up JogShuttle mode switching bindings
+void Preferences::JogShuttleInitModeSwitching(int& count)
+{
 	_JogShuttleActions.push_back(
 	    JogShuttleActions( count++, _( "Switch to Edit" ),
 	                       _( "Switch to the edit interface" ),
@@ -296,8 +520,11 @@ Preferences::Preferences()
 	    JogShuttleActions( count++, _( "Switch to Trim" ),
 	                       _( "Switch to trim mode" ),
 	                       "t" ) );
-	/* --- GENERAL --- */
+}
 
+/// Set up JogShuttle general bindings
+void Preferences::JogShuttleInitGeneral(int& count)
+{
 	_JogShuttleActions.push_back(
 	    JogShuttleActions( count++, _( "Repeat last command" ),
 	                       _( "Repeat last command" ),
@@ -337,9 +564,11 @@ Preferences::Preferences()
 	    JogShuttleActions( count++, _( "Publish SMIL" ),
 	                       _( "Publish SMIL" ),
 	                       "Ctrl+W" ) );
+}
 
-	/* --- TRIM --- */
-
+/// Set up JogShuttle trim bindings
+void Preferences::JogShuttleInitTrim(int& count)
+{
 	_JogShuttleActions.push_back(
 	    JogShuttleActions( count++, _( "Set In" ),
 	                       _( "Set the In Point to current position" ),
@@ -374,248 +603,57 @@ Preferences::Preferences()
 	    JogShuttleActions( count++, _( "Toggle Link" ),
 	                       _( "Toggle Link" ),
 	                       "=" ) );
-
-	// TODO: Add more actions?
-
-
-	/* Actually get the preferences */
-	count = gnome_config_get_int( "jogShuttleNumMappings=0" );
-	if ( 0 != count )
-	{
-		for ( int i = 0; i < count ; i++ )
-		{
-			char key[ 512 ];
-			sprintf( key, "jogShuttleMappingFirstButton%i=0", i );
-			unsigned int first_code
-			= gnome_config_get_int( key );
-			sprintf( key, "jogShuttleMappingSecondButton%i=0", i );
-			unsigned int second_code
-			= gnome_config_get_int( key );
-			sprintf( key, "jogShuttleMappingAction%i=", i );
-			// g_print ( " Key = %s\n", key );
-			tempString =
-			    gnome_config_get_string( key );
-
-			// TODO: Free
-			// g_print( "tmpstring Read action %s\n", tempString );
-			string action = string( tempString );
-			// g_print( "Read action %s\n", action.c_str() );
-			/* Insert */
-			_JogShuttleMappings[ make_pair ( first_code, second_code ) ]
-			= JogShuttleMapping( action );
-		}
-	}
-	else
-	{
-		// Set up defaults manuall, if 0 count
-		// These are my own default mappings
-		_JogShuttleMappings[ make_pair ( 0x100, 0x0 ) ]
-		= JogShuttleMapping( "i" );
-		_JogShuttleMappings[ make_pair ( 0x101, 0x0 ) ]
-		= JogShuttleMapping( "o" );
-		_JogShuttleMappings[ make_pair ( 0x102, 0x0 ) ]
-		= JogShuttleMapping( "h" );
-		_JogShuttleMappings[ make_pair ( 0x103, 0x0 ) ]
-		= JogShuttleMapping( "l" );
-		
-		_JogShuttleMappings[ make_pair ( 0x113, 0x0 ) ]
-		= JogShuttleMapping( "b" );
-		_JogShuttleMappings[ make_pair ( 0x111, 0x0 ) ]
-		= JogShuttleMapping( "w" );
-		_JogShuttleMappings[ make_pair ( 0x110, 0x0 ) ]
-		= JogShuttleMapping( " " );
-		_JogShuttleMappings[ make_pair ( 0x112, 0x0 ) ]
-		= JogShuttleMapping( "k" );
-		_JogShuttleMappings[ make_pair ( 0x114, 0x0 ) ]
-		= JogShuttleMapping( "j" );
-		_JogShuttleMappings[ make_pair ( 0x115, 0x0 ) ]
-		= JogShuttleMapping( "gg" );
-		_JogShuttleMappings[ make_pair ( 0x116, 0x0 ) ]
-		= JogShuttleMapping( "G" );
-		
-		_JogShuttleMappings[ make_pair ( 0x10, 0x0 ) ]
-		= JogShuttleMapping( " " );
-	}
-
-
-
-
-	enableV4L = gnome_config_get_bool( "enableV4L=false" );
-	disableKeyRepeat = gnome_config_get_bool( "disableKeyRepeat=false" );
-	audioRendering = gnome_config_get_int( "audioRendering=0" );
-	previewRendering = gnome_config_get_int( "previewRendering=1" );
-	maxUndos = gnome_config_get_int( "maxUndos=50" );
-	//tempString = gnome_config_get_string("video1394Device=/dev/video1394");
-	//if (tempString) {
-	//    strncpy( video1394Device, tempString, 511);
-	//    g_free(tempString);
-	//}
-	dvCaptureBuffers = gnome_config_get_int( "dvCaptureBuffers=50" );
-	dvExportBuffers = gnome_config_get_int( "dvExportBuffers=10" );
-	dvDecoderClampLuma = gnome_config_get_bool( "dvDecoderClampLuma=false" );
-	dvDecoderClampChroma = gnome_config_get_bool( "dvDecoderClampChroma=false" );
-	maxFileSize = gnome_config_get_int( "maxFileSize=2000" );
-	audioScrub = gnome_config_get_bool( "audioScrub=false" );
-	tempString = gnome_config_get_string( "v4lVideoDevice=/dev/video0" );
-	if ( tempString )
-	{
-		strncpy( v4lVideoDevice, tempString, 511 );
-		g_free( tempString );
-	}
-	tempString = gnome_config_get_string( "v4lAudioDevice=/dev/dsp" );
-	if ( tempString )
-	{
-		strncpy( v4lAudioDevice, tempString, 511 );
-		g_free( tempString );
-	}
-	tempString = gnome_config_get_string( "v4lInput=PAL" );
-	if ( tempString )
-	{
-		strncpy( v4lInput, tempString, 31 );
-		g_free( tempString );
-	}
-	tempString = gnome_config_get_string( "v4lAudio=32000" );
-	if ( tempString )
-	{
-		strncpy( v4lAudio, tempString, 31 );
-		g_free( tempString );
-	}
-	isOpenDML = gnome_config_get_bool( "isOpenDML=false" );
-	tempString = gnome_config_get_string( "defaultDirectory=~/" );
-	if ( tempString )
-	{
-		strncpy( defaultDirectory, tempString, 511 );
-		g_free( tempString );
-	}
-	displayExtract = gnome_config_get_int( "displayExtract=0" );
-	relativeSave = gnome_config_get_bool( "relativeSave=false" );
-
-	dvCaptureDriver = gnome_config_get_int( "dvCaptureDriver=0" );
-	tempString = gnome_config_get_string( "dvCaptureDevice=/dev/raw1394" );
-	if ( tempString )
-	{
-		strncpy( dvCaptureDevice, tempString, 511 );
-		g_free( tempString );
-	}
-	dv1394Preview = gnome_config_get_bool( "dv1394Preview=false" );
-	tempString = gnome_config_get_string( "dvExportDevice=/dev/ieee1394/dv/host0/PAL/out" );
-	if ( tempString )
-	{
-		strncpy( dvExportDevice, tempString, 511 );
-		g_free( tempString );
-	}
-	avcPollIntervalMs = gnome_config_get_int( "avcPollIntervalMs=200" );
-	dvExportPrerollSec = gnome_config_get_int( "dvExportPrerollSec=4" );
-	dvTwoPassEncoder = gnome_config_get_bool( "dvTwoPassEncoder=false" );
-	windowWidth = gnome_config_get_int( "windowWidth=-1" );
-	windowHeight = gnome_config_get_int( "windowHeight=-1" );
-	storyboardPosition = gnome_config_get_int( "storyboardPosition=-1" );
-	previewSize = gnome_config_get_float( "previewSize=0.0" );
-	timeFormat = gnome_config_get_int( "timeFormat=1" );
-	
-	tempString = gnome_config_get_string( "metaNames=*title,author,copyright,id,abstract" );
-	if ( tempString )
-	{
-		strncpy( metaNames, tempString, 511 );
-		g_free( tempString );
-	}
-	
-	vector< string > metaNamesList;
-	vector< string >::iterator metaNamesIter;
-
-	// build a metaValues key for each metaName
-	// metaValues is a range of values to pick from
-	// metaValue * = open-ended, values outside range permitted, can be used alongside values
-	string_utils::split( metaNames, ",", metaNamesList );
-	for ( metaNamesIter = metaNamesList.begin(); metaNamesIter != metaNamesList.end(); ++metaNamesIter )
-	{
-		std::ostringstream str;
-		std::string metaname = *metaNamesIter;
-
-		if ( metaname.at( 0 ) == '*' )
-			metaname.erase( 0, 1 );
-
-		str << "metaValues_" << metaname << "=*";
-		tempString = gnome_config_get_string( str.str().c_str() );
-		if ( tempString )
-		{
-			vector< string > metaValuesSimpleList;
-			vector< string >::iterator iter;
-			vector< pair< string, string > > metaValuesList;
-
-			string_utils::split( tempString, ",", metaValuesSimpleList );
-			for ( iter = metaValuesSimpleList.begin(); iter != metaValuesSimpleList.end(); ++iter )
-			{
-				vector< string > labelValueVector;
-				pair< string, string > labelValuePair;
-				
-				string_utils::split( *iter, "=", labelValueVector );
-				if ( labelValueVector.size() > 1 )
-					labelValuePair = make_pair( labelValueVector[0], labelValueVector[1] );
-				else
-					labelValuePair = make_pair( *iter, *iter );
-				metaValuesList.push_back( labelValuePair );
-			}
-			metaValues.insert( make_pair( metaname, metaValuesList ) );
-			g_free( tempString );
-		}
-	}
-
-	enablePublish = gnome_config_get_bool( "enablePublish=false" );
-	expandStoryboard = gnome_config_get_bool( "expandStoryboard=false" );
-	tempString = gnome_config_get_string( "newProjectURI=" );
-	if ( tempString )
-	{
-		strncpy( newProjectURI, tempString, 511 );
-		g_free( tempString );
-	}
-	tempString = gnome_config_get_string( "newProjectXPath=" );
-	if ( tempString )
-	{
-		strncpy( newProjectXPath, tempString, 511 );
-		g_free( tempString );
-	}
-
-	trimModeInsert = gnome_config_get_bool( "trimModeInsert=false" );
-	
-	gnome_config_pop_prefix();
 }
-
 /** Save the user preferences.
 */
 
+void Preferences::set( const char *name, const char* value )
+{
+	g_key_file_set_string( config, GKEYFILE_GROUP, name, value );
+}
+
+void Preferences::set( const char *name, int value )
+{
+	g_key_file_set_integer( config, GKEYFILE_GROUP, name, value );
+}
+
+void Preferences::set( const char *name, bool value )
+{
+	g_key_file_set_boolean( config, GKEYFILE_GROUP, name, value );
+}
+
 /// Save the user preferences.
 void
 Preferences::Save()
 {
-	gnome_config_push_prefix( "/kino/general/" );
+	cerr << "Saving preferences." << endl;
 
-	gnome_config_set_int( "defaultNormalisation", defaultNormalisation );
-	gnome_config_set_int( "defaultAudio", defaultAudio );
-	gnome_config_set_int( "defaultAspect", defaultAspect );
-	gnome_config_set_string( "file", file );
-	gnome_config_set_int( "fileFormat", fileFormat );
-	gnome_config_set_bool( "autoSplit", autoSplit );
-	gnome_config_set_bool( "timeStamp", timeStamp );
-	gnome_config_set_int( "frames", frames );
-	gnome_config_set_int( "every", every );
-	gnome_config_set_int( "interface", interface );
-	gnome_config_set_int( "channel", channel );
-	gnome_config_set_string( "avcGUID", avcGUID );
-	gnome_config_set_int( "displayMode", displayMode );
-	gnome_config_set_float( "displayQuality", displayQuality );
-	gnome_config_set_bool( "displayFixed", displayFixed );
-	gnome_config_set_bool( "enableAudio", enableAudio );
-	gnome_config_set_int( "cip_increment", cip_n );
-	gnome_config_set_int( "cip_threshold", cip_d );
-	gnome_config_set_int( "syt_offset", syt_offset );
-	gnome_config_set_bool( "preview_capture", preview_capture );
-	gnome_config_set_bool( "dropFrame", dropFrame );
-	gnome_config_set_string( "audioDevice", audioDevice );
+	set( "defaultNormalisation", defaultNormalisation );
+	set( "defaultAudio", defaultAudio );
+	set( "defaultAspect", defaultAspect );
+	set( "file", file );
+	set( "fileFormat", fileFormat );
+	set( "autoSplit", autoSplit );
+	set( "timeStamp", timeStamp );
+	set( "frames", frames );
+	set( "every", every );
+	set( "interface", interface );
+	set( "channel", channel );
+	set( "avcGUID", avcGUID );
+	set( "displayMode", displayMode );
+	set( "displayQuality", displayQuality );
+	set( "displayFixed", displayFixed );
+	set( "enableAudio", enableAudio );
+	set( "cip_increment", cip_n );
+	set( "cip_threshold", cip_d );
+	set( "syt_offset", syt_offset );
+	set( "preview_capture", preview_capture );
+	set( "dropFrame", dropFrame );
+	set( "audioDevice", audioDevice );
 
 	/* JogShuttle Stuff */
-	gnome_config_set_bool( "enableJogShuttle", enableJogShuttle );
-	gnome_config_set_int( "jogShuttleNumMappings", _JogShuttleMappings.size() );
+	set( "enableJogShuttle", enableJogShuttle );
+	set( "jogShuttleNumMappings", static_cast< int >( _JogShuttleMappings.size() ) );
 	int count = 0;
 	map<pair<unsigned short, unsigned short>, JogShuttleMapping>::iterator i;
 	pair<unsigned short, unsigned short> map_key;
@@ -625,60 +663,75 @@ Preferences::Save()
 		map_key = ( *i ).first;
 		char key[ 512 ];
 		sprintf( key, "jogShuttleMappingFirstButton%i", count );
-		gnome_config_set_int( key, map_key.first );
+		set( key, map_key.first );
 		sprintf( key, "jogShuttleMappingSecondButton%i", count );
-		gnome_config_set_int( key, map_key.second );
+		set( key, map_key.second );
 		sprintf( key, "jogShuttleMappingAction%i", count );
-		gnome_config_set_string( key, ( *i ).second._action.c_str() );
+		set( key, ( *i ).second._action.c_str() );
 	}
 
-	gnome_config_set_bool( "enableV4L", enableV4L );
-	gnome_config_set_bool( "disableKeyRepeat", disableKeyRepeat );
-	gnome_config_set_int( "audioRendering", audioRendering );
-	gnome_config_set_int( "previewRendering", previewRendering );
-	gnome_config_set_int( "maxUndos", maxUndos );
-	gnome_config_set_string( "video1394Device", video1394Device );
-	gnome_config_set_int( "dvCaptureBuffers", dvCaptureBuffers );
-	gnome_config_set_int( "dvExportBuffers", dvExportBuffers );
-	gnome_config_set_bool( "dvDecoderClampLuma", dvDecoderClampLuma );
-	gnome_config_set_bool( "dvDecoderClampChroma", dvDecoderClampChroma );
-	gnome_config_set_int( "maxFileSize", maxFileSize );
-	gnome_config_set_bool( "audioScrub", audioScrub );
-	gnome_config_set_string( "v4lVideoDevice", v4lVideoDevice );
-	gnome_config_set_string( "v4lAudioDevice", v4lAudioDevice );
-	gnome_config_set_string( "v4lInput", v4lInput );
-	gnome_config_set_string( "v4lAudio", v4lAudio );
-	gnome_config_set_bool( "isOpenDML", isOpenDML );
-	gnome_config_set_string( "defaultDirectory", defaultDirectory );
-	gnome_config_set_int( "displayExtract", displayExtract );
-	gnome_config_set_bool( "relativeSave", relativeSave );
+	set( "enableV4L", enableV4L );
+	set( "disableKeyRepeat", disableKeyRepeat );
+	set( "audioRendering", audioRendering );
+	set( "previewRendering", previewRendering );
+	set( "maxUndos", maxUndos );
+	set( "dvCaptureBuffers", dvCaptureBuffers );
+	set( "dvExportBuffers", dvExportBuffers );
+	set( "dvDecoderClampLuma", dvDecoderClampLuma );
+	set( "dvDecoderClampChroma", dvDecoderClampChroma );
+	set( "maxFileSize", maxFileSize );
+	set( "audioScrub", audioScrub );
+	set( "v4lVideoDevice", v4lVideoDevice );
+	set( "v4lAudioDevice", v4lAudioDevice );
+	set( "v4lInput", v4lInput );
+	set( "v4lAudio", v4lAudio );
+	set( "isOpenDML", isOpenDML );
+	set( "defaultDirectory", defaultDirectory );
+	set( "displayExtract", displayExtract );
+	set( "relativeSave", relativeSave );
 
-	gnome_config_set_int( "dvCaptureDriver", dvCaptureDriver );
-	gnome_config_set_string( "dvCaptureDevice", dvCaptureDevice );
-	gnome_config_set_bool( "dv1394Preview", dv1394Preview );
-	gnome_config_set_string( "dvExportDevice", dvExportDevice );
-	gnome_config_set_int( "avcPollIntervalMs", avcPollIntervalMs );
-	gnome_config_set_int( "dvExportPrerollSec", dvExportPrerollSec );
-	gnome_config_set_bool( "dvTwoPassEncoder", dvTwoPassEncoder );
-	gnome_config_set_int( "windowWidth", windowWidth );
-	gnome_config_set_int( "windowHeight", windowHeight );
-	gnome_config_set_int( "storyboardPosition", storyboardPosition );
-	gnome_config_set_float( "previewSize", previewSize );
-	gnome_config_set_int( "timeFormat", timeFormat );
-	gnome_config_set_string( "metaNames", metaNames );
-	gnome_config_set_bool( "enablePublish", enablePublish );
-	gnome_config_set_bool( "expandStoryboard", expandStoryboard );
-	gnome_config_set_string( "newProjectURI", newProjectURI );
-	gnome_config_set_string( "newProjectXPath", newProjectXPath );
-	gnome_config_set_bool( "trimModeInsert", trimModeInsert );
+	set( "dvCaptureDriver", dvCaptureDriver );
+	set( "dvCaptureDevice", dvCaptureDevice );
+	set( "dv1394Preview", dv1394Preview );
+	set( "dvExportDevice", dvExportDevice );
+	set( "avcPollIntervalMs", avcPollIntervalMs );
+	set( "dvExportPrerollSec", dvExportPrerollSec );
+	set( "dvTwoPassEncoder", dvTwoPassEncoder );
+	set( "windowWidth", windowWidth );
+	set( "windowHeight", windowHeight );
+	set( "storyboardPosition", storyboardPosition );
+	set( "previewSize", previewSize );
+	set( "timeFormat", timeFormat );
+	set( "metaNames", metaNames );
+	set( "enablePublish", enablePublish );
+	set( "expandStoryboard", expandStoryboard );
+	set( "newProjectURI", newProjectURI );
+	set( "newProjectXPath", newProjectXPath );
+	set( "trimModeInsert", trimModeInsert );
+	set( "enableAVC", enableAVC );
+	
+	set( "exportMjpegFormat", exportMjpegFormat );
+	set( "exportMjpegDeinterlace", exportMjpegDeinterlace );
+	set( "exportMjpegAspect", exportMjpegAspect );
+	set( "exportMjpegSceneSplit", exportMjpegSceneSplit );
+	set( "exportMjpegCleanup", exportMjpegCleanup );
+	set( "exportMjpegOutputDVDAuthorXML", exportMjpegOutputDVDAuthorXML );
+	set( "exportMjpegXMLScript", exportMjpegXMLScript );
 
-	gnome_config_pop_prefix();
-
-	gnome_config_sync();
-}
-
-/// Provide access to the audioDevice propery from C modules.
-gchar *Preferences_getAudioDevice( void )
-{
-	return Preferences::getInstance().audioDevice;
+	// Persist
+	string filename = string( getenv( "HOME" ) ) + string( "/.kinorc" );
+	FILE *f = fopen( filename.c_str(), "w" );
+	if ( f )
+	{
+		gsize data_size = 0;
+		gchar *data = g_key_file_to_data( config, &data_size, NULL );
+		fwrite( data, data_size, 1, f );
+		fclose( f );
+		g_free( data );
+	}
+	
+	// Delete the old file if it exists (ignore error)
+	filename = string( getenv( "HOME" ) ) + string( "/.gnome2/kino" );
+	unlink( filename.c_str() );
+	errno = 0;
 }
