@@ -19,8 +19,6 @@
 #ifndef PREFERENCES_H
 #define PREFERENCES_H 1
 
-#include <glib.h>
-
 enum { AVI, PLAYLIST, RAW_DV, QT, UNKNOWN_FORMAT };
 enum { PAL_FORMAT, NTSC_FORMAT, AVI_DV1_FORMAT, AVI_DV2_FORMAT, QT_FORMAT, RAW_FORMAT, TEST_FORMAT, UNDEFINED };
 enum { DISPLAY_XX, DISPLAY_GDKRGB, DISPLAY_GDKRGB32, DISPLAY_XV, DISPLAY_SDL };
@@ -39,6 +37,9 @@ using std::map;
 using std::pair;
 using std::make_pair;
 using std::vector;
+
+#include <glib.h>
+
 class JogShuttleActions
 {
 public:
@@ -72,84 +73,102 @@ class Preferences
 {
 private:
 	static Preferences *instance;
+	GKeyFile *config;
+
+	/* Helper functions to initialise JogShuttle bindings. */
+	void JogShuttleInit(void);
+	void JogShuttleInitNavigation(int& count);
+	void JogShuttleInitCut(int& count);
+	void JogShuttleInitCopy(int& count);
+	void JogShuttleInitPaste(int& count);
+	void JogShuttleInitModeSwitching(int& count);
+	void JogShuttleInitGeneral(int& count);
+	void JogShuttleInitTrim(int& count);
 
 protected:
 	Preferences();
+	~Preferences();
 
 public:
 	static Preferences &getInstance();
 
-	gint defaultNormalisation;
-	gint defaultAudio;
-	gint defaultAspect;
-	gchar file[ 512 ];
-	gint fileFormat;
-	gboolean autoSplit;
-	gboolean timeStamp;
-	gint frames;
-	gint every;
-	gint interface;
-	gint channel;
-	gint phyID;
-	gchar avcGUID[ 65 ];
-	gint displayMode;
-	gfloat displayQuality;
-	gboolean displayFixed;
-	gboolean enableAudio;
-	guint cip_n;
-	guint cip_d;
-	guint syt_offset;
-	gboolean preview_capture;
-	gboolean dropFrame;
-	gchar audioDevice[ 512 ];
+	void get( int& var, const char* name, const char* def );
+	void get( char *var, int size, const char* name, const char* def );
+	void get( bool& var, const char* name, const char* def );
+	void set( const char *name, const char* value );
+	void set( const char *name, int value );
+	void set( const char *name, bool value );
+
+	int defaultNormalisation;
+	int defaultAudio;
+	int defaultAspect;
+	char file[ 512 ];
+	int fileFormat;
+	bool autoSplit;
+	bool timeStamp;
+	int frames;
+	int every;
+	int interface;
+	int channel;
+	int phyID;
+	char avcGUID[ 65 ];
+	int displayMode;
+	int displayQuality;
+	bool displayFixed;
+	bool enableAudio;
+	int cip_n;
+	int cip_d;
+	int syt_offset;
+	bool preview_capture;
+	bool dropFrame;
+	char audioDevice[ 512 ];
 
 	/* JogShuttle stuff */
-	gboolean enableJogShuttle;
-	gboolean _isGrabbing;
+	bool enableJogShuttle;
+	bool _isGrabbing;
 	/* Mappings for the jogShuttle */
 	map<pair<unsigned short, unsigned short>, JogShuttleMapping>
 	_JogShuttleMappings;
 	vector<JogShuttleActions> _JogShuttleActions;
 
 
-	gboolean enableV4L;
-	gboolean disableKeyRepeat;
-	gint audioRendering;
-	gint previewRendering;
-	gint maxUndos;
-	gchar video1394Device[ 512 ];
-	gint dvCaptureBuffers;
-	gint dvExportBuffers;
-	gboolean dvDecoderClampLuma;
-	gboolean dvDecoderClampChroma;
-	gint maxFileSize;
-	gboolean audioScrub;
-	gchar v4lVideoDevice[ 512 ];
-	gchar v4lAudioDevice[ 512 ];
-	gchar v4lInput[ 32 ];
-	gchar v4lAudio[ 32 ];
-	gboolean isOpenDML;
-	gchar defaultDirectory[ 512 ];
-	gint displayExtract;
-	gboolean relativeSave;
+	bool enableV4L;
+	bool disableKeyRepeat;
+	int audioRendering;
+	int previewRendering;
+	int maxUndos;
+	int dvCaptureBuffers;
+	int dvExportBuffers;
+	bool dvDecoderClampLuma;
+	bool dvDecoderClampChroma;
+	int maxFileSize;
+	bool audioScrub;
+	char v4lVideoDevice[ 512 ];
+	char v4lAudioDevice[ 512 ];
+	char v4lInput[ 32 ];
+	char v4lAudio[ 32 ];
+	bool isOpenDML;
+	char defaultDirectory[ 512 ];
+	int displayExtract;
+	bool relativeSave;
 
-	gint dvCaptureDriver;
-	gchar dvCaptureDevice[ 512 ];
-	gboolean dv1394Preview;
-	gchar dvExportDevice[ 512 ];
-	gint avcPollIntervalMs;
-	gint dvExportPrerollSec;
-	gboolean dvTwoPassEncoder;
-	gint windowWidth;
-	gint windowHeight;
-	gint storyboardPosition;
-	gfloat previewSize;
-	gint timeFormat;
+	int dvCaptureDriver;
+	char dvCaptureDevice[ 512 ];
+	bool dv1394Preview;
+	char dvExportDevice[ 512 ];
+	int avcPollIntervalMs;
+	int dvExportPrerollSec;
+	bool dvTwoPassEncoder;
+	int windowWidth;
+	int windowHeight;
+	int storyboardPosition;
+	int previewSize;
+	int timeFormat;
 	
 	/// metaNames is a comma-delimited list of xml attribute names.
 	/// Preface name with a '*' to make it required.
 	// added for tagesschau.de
-	gchar metaNames[512];
+	char metaNames[512];
 	
 	/// metaValues is mapped to each metaName.
 	/// Each metaValue is a comma-delimited list of permissable values.
@@ -166,9 +185,9 @@ public:
 
 	/// enablePublish shows the Publish SMIL and Still menu items and toolbar icons.
 	// added for tagesschaue.de
-	gboolean enablePublish;
+	bool enablePublish;
 
-	gboolean expandStoryboard;
+	bool expandStoryboard;
 
 	/// If newProjectURI is not empty, then a prompt is displayed on startup when no
 	/// files on command line or File/New selected. The user is prompted for a
@@ -177,19 +196,27 @@ public:
 	/// a well-formed XML document in the body of the response, which is parsed by
 	/// libxml2.
 	// added for tagesschau.de
-	gchar newProjectURI[512];
+	char newProjectURI[512];
 
 	/// newProjectXPath is the XPath expression to locate the project id in the
 	/// XML response from newProjectURI. The value is put into the id attribute
 	/// value on the smil element.
 	// added for tagesschau.de
-	gchar newProjectXPath[512];
+	char newProjectXPath[512];
 
-	gboolean trimModeInsert;
+	bool trimModeInsert;
+
+	// "Sticky" Export/MJPEG options
+	int exportMjpegAspect;
+	int exportMjpegDeinterlace;
+	int exportMjpegFormat;
+	char exportMjpegXMLScript[512];
+	bool exportMjpegSceneSplit;
+	bool exportMjpegCleanup;
+	bool exportMjpegOutputDVDAuthorXML;
+	bool enableAVC;
 
 	void Save();
 };
 
-extern "C" gchar *Preferences_getAudioDevice( void );
-
 #endif
