@@ -399,6 +399,8 @@ extern "C"
 
 		widget = lookup_widget( dialog, "optionmenu_dvcapture_driver" );
 		gtk_option_menu_set_history( GTK_OPTION_MENU( widget ), prefs.dvCaptureDriver );
+		menuitem = GTK_MENU_ITEM ( gtk_menu_get_active ( GTK_MENU ( gtk_option_menu_get_menu( GTK_OPTION_MENU ( widget ) ) ) ) );
+		on_optionmenu_dvcapture_driver_activate( menuitem, NULL );
 		widget = lookup_widget( dialog, "entry_dvcapture_device" );
 		gtk_entry_set_text( GTK_ENTRY( widget ), prefs.dvCaptureDevice );
 		widget = lookup_widget( dialog, "entry_dvexport_device" );
@@ -413,6 +415,11 @@ extern "C"
 		widget = lookup_widget( dialog, "checkbutton_trim_mode_insert" );
 		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( widget ), prefs.trimModeInsert );
 
+#ifdef HAVE_LIBAVCODEC
+		gtk_widget_hide( lookup_widget( dialog, "vbox_display_decoder" ) );
+		gtk_widget_hide( lookup_widget( dialog, "checkbutton_two_pass" ) );
+#endif
+
 		gtk_widget_show( dialog );
 	}
 
@@ -420,7 +427,7 @@ extern "C"
 	void
 	on_avc_phyid_activate( GtkMenuItem * menu_item, gpointer user_data )
 	{
-		int currentNode = ( int ) user_data;
+		nodeid_t currentNode = ( nodeid_t )( long )user_data;
 		static raw1394handle_t handle;
 #ifdef LIBRAW1394_OLD
 
@@ -759,9 +766,9 @@ extern "C"
 		GtkAdjustment *displayQualityValue;
 		widget = lookup_widget( dialog, "hscale_display_quality" );
 		displayQualityValue = gtk_range_get_adjustment( GTK_RANGE( widget ) );
-		if ( displayQualityValue->value != prefs.displayQuality )
+		if ( int( gtk_adjustment_get_value( displayQualityValue ) ) != prefs.displayQuality )
 		{
-			prefs.displayQuality = displayQualityValue->value;
+			prefs.displayQuality = int( gtk_adjustment_get_value( displayQualityValue ) );
 			common->moveToFrame();
 		}
 		widget = lookup_widget( dialog, "entry_timing" );
@@ -860,4 +867,34 @@ extern "C"
 		gtk_widget_hide( dialog );
 	}
 
+
+	void
+	on_optionmenu_dvcapture_driver_activate ( GtkMenuItem *menuitem, gpointer user_data )
+	{
+		GtkEntry *device;
+		gboolean activate = 1;
+
+		if ( GTK_WIDGET ( menuitem ) ==
+		     lookup_widget( GTK_WIDGET ( menuitem ),
+		                    "optionmenu_dvcapture_driver_raw1394") )
+			activate = 0;
+		
+		device = GTK_ENTRY ( lookup_widget( GTK_WIDGET ( menuitem ),
+		                     "entry_dvcapture_device") );
+		gtk_entry_set_editable( device, activate );
+		gtk_widget_set_child_visible( GTK_WIDGET ( device ), activate );
+	}
+
+	void
+	on_button_capture_open_clicked( GtkButton       *button,
+	                                gpointer         user_data )
+	{
+		char *filename = common->getFileToOpen( _("Choose a DV file") );
+		if ( filename && strcmp( filename, "" ) )
+		{
+			gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_file" ) ),
+				filename );
+		}
+	}
+
 }
