@@ -19,7 +19,7 @@
 #ifndef _PREFERENCES_DIALOG_H
 #define _PREFERENCES_DIALOG_H 1
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -68,6 +68,14 @@ extern "C"
 	on_radiobutton_XV_clicked ( GtkButton * button,
 	                            gpointer user_data );
 
+	void
+	on_optionmenu_dvcapture_driver_activate ( GtkMenuItem * menuitem,
+	                                          gpointer user_data );
+
+	void
+	on_button_capture_open_clicked( GtkButton       *button,
+	                                gpointer         user_data );
+
 	/* JogShuttle stuff */
 	gboolean
 	on_frame_jogshuttle_grab_frame_enter_notify_event
