@@ -63,7 +63,6 @@ enum
 };
 
 enum SceneStatus showScenesRunning = SCENE_INIT;
-enum SceneStatus updateScenesRunning = SCENE_INIT;
 
 static std::vector< GdkPixbuf * > *backup = NULL;
 static pthread_mutex_t scene_mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -450,6 +449,7 @@ Storyboard::Storyboard( KinoCommon *common ) :
 	view = GTK_TREE_VIEW( lookup_widget( common->getWidget(), "treeview_storyboard" ) );
 	g_signal_connect( G_OBJECT( view ), "button-release-event", G_CALLBACK( tree_view_row_select ), this );
 	g_signal_connect( G_OBJECT( view ), "row-activated", G_CALLBACK( tree_view_row_activated ), this );
+	gtk_tree_view_set_enable_search( view, FALSE );
 
 	// Store the current scene
 	selection = common->getCurrentScene();
@@ -586,7 +586,7 @@ void *showScenesThread( void *arg )
 			                                  NULL, NULL );
 
 			// create the thumbnail
-			// TODO: apply PAL aspect ratio factor
+			// TODO: properly support widescreen
 			thumbnail = gdk_pixbuf_scale_simple( image, 80, 60, GDK_INTERP_NEAREST );
 			icons->push_back( thumbnail );
 			g_object_unref( image );
@@ -643,7 +643,8 @@ void *showScenesThread( void *arg )
 					{
 						vector< std::pair< std::string, std::string > >& metaValues = Preferences::getInstance().metaValues[ metaname ];
 						vector< std::pair< std::string, std::string > >::iterator metaValuesIter;
-						char *label = const_cast< char* >( common->getPlayList()->GetSeqAttribute( frameNum, metaname.c_str() ).c_str() );
+						std::string labelString = common->getPlayList()->GetSeqAttribute( frameNum, metaname.c_str() );
+						char *label = const_cast< char* >( labelString.c_str() );
 	
 						// See if a label exists for the value
 						for ( metaValuesIter = metaValues.begin(); metaValuesIter != metaValues.end(); ++metaValuesIter )
@@ -712,7 +713,7 @@ void *showScenesThread( void *arg )
 	}
 	GetFramePool( ) ->DoneWithFrame( &frame );
 
-	delete pixels;
+	delete[] pixels;
 	return NULL;
 }
 
