@@ -726,7 +726,7 @@ EncoderFrame::EncoderFrame()
 
 EncoderFrame::~EncoderFrame()
 {
-	delete image;
+	delete[] image;
 }
 
 void EncoderFrame::setVideo( void *image, int width, int height )
